/***************************** FILE HEADER *********************************/
/*!
*  \file      cpdfreport.cpp
*
*  \brief     This file implements the pdf export of the configuration.
*
*  \note
*
*  \author    L&T Technology Services Limited
*  \copyright Copyright (c) 2018 Hirschmann Automation & Control GmbH
*
*
*  \version 1a 2018-07-06 Julia Greiss standard header added to file.
*
*//**************************** FILE HEADER *********************************/

/******************************************************************************
 * Includes
 ******************************************************************************/
#include "cpdfreport.h"
#include "globaldata.h"
#include "portdata.h"

/******************************************************************************
 * Globals
 ******************************************************************************/
extern configData SwitchConfiguration;
extern QString serialNumber;
productInfo g_CurrentProductInfo1;
/****************************************************************************************
Function Name			:	CPdfReport
Function/DLD ID 		:   SWR_CPDFR_01
Purpose of Function		:   Constructor
Author/Date     		: 	<Dalton A ? 22\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   int, QString
Return                  :   Void
Remarks                 :
*****************************************************************************************/
CPdfReport::CPdfReport(int index, QString path)
{
   oQTextCharFormatHeader1.setFont(QFont("Arial",14, QFont::Bold));
    oQTextCharFormatHeader2.setFont(QFont("Arial",11, QFont::Bold));
    oQTextCharFormatHeader3.setFont(QFont("Arial",11));
    oQTextCharFormatHeader4.setFont(QFont("Arial",8));
    oQTextCharFormatTableHeader.setFont(QFont("Arial",9, QFont::Bold));
    oQTextCharFormatTableData.setFont(QFont("Arial",8));
    oQTextCharFormatSpacing.setFont(QFont("Arial",6));

    oQTextBlockFormatCenterAlignment.setAlignment(Qt::AlignCenter);
    oQTextBlockFormatRightAlignment.setAlignment(Qt::AlignRight);

    oQTextCharFormatGrey.setBackground(QBrush(QColor(217,217,217,255)));
    oQTextCharFormatWhite.setBackground(QBrush(QColor(Qt::white)));

    filePath = path;
    modelIndex = index;
    ucNumberOfPorts = stProductData[index].m_ucNumberOfPorts;//stModelNoBuffer[index].noOfPort;//24;           //modify
    ucPageNumber = 1;
}
/****************************************************************************************
Function Name			:	~CPdfReport
Function/DLD ID 		:   SWR_CPDFR_02
Purpose of Function		:   Set editor data
Author/Date     		: 	<Dalton A 22\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
CPdfReport::~CPdfReport()
{
    delete pQTextCursorReport;
}
/****************************************************************************************
Function Name			:	generatePdfReport
Function/DLD ID 		:   SWR_CPDFR_03
Purpose of Function		:   Generate report template
Author/Date     		: 	<Dalton A 22\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void CPdfReport::generatePdfReport(void)
{
    QPrinter oQPrinterPdfReport(QPrinter::ScreenResolution);
    oQPrinterPdfReport.setColorMode(QPrinter::Color);
    oQPrinterPdfReport.setPageSize(QPrinter::A4);
    oQPrinterPdfReport.setOrientation(QPrinter::Landscape);
    oQPrinterPdfReport.setPageMargins (20,10,20,10,QPrinter::Millimeter);
    oQPrinterPdfReport.setResolution(120);
    oQPrinterPdfReport.setFullPage(true);
    oQPrinterPdfReport.setOutputFileName(filePath);     //Modify
    oQPrinterPdfReport.setOutputFormat(QPrinter::PdfFormat);

    QTextDocument oQTextDocumentReport;
    oQTextDocumentReport.setPageSize(oQPrinterPdfReport.paperSize(QPrinter::Point));

    pQTextFrameRoot = oQTextDocumentReport.rootFrame();

    const qreal PT_MM = 25.4/72.0;
    oQTextDocumentReport.setDocumentMargin(10.0/PT_MM); // (X/PT_MM) sets margin to Xmm

    ucPageNumber = 1;
    pQTextCursorReport = new QTextCursor(&oQTextDocumentReport);
    pageLayoutTableCreate();
    pageLayoutTableCreate();
    if(ucNumberOfPorts > 16)
    {
        pageLayoutTableCreate();
    }
    oQTextDocumentReport.print(&oQPrinterPdfReport);
}
/****************************************************************************************
Function Name			:	pageLayoutTableCreate
Function/DLD ID 		:   SWR_CPDFR_04
Purpose of Function		:   Create page layout for report
Author/Date     		: 	<Dalton A 23\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void CPdfReport::pageLayoutTableCreate(void)
{
    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(0);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(1);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr;
    constr.push_back(QTextLength(QTextLength::PercentageLength, 97));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr);

    *pQTextCursorReport = pQTextFrameRoot->lastCursorPosition();
    headerLayoutTableCreate();
    if(ucPageNumber == 1)
    {
        *pQTextCursorReport = pQTextFrameRoot->lastCursorPosition();
        page1BodyLayoutTable();
    }
    else
    {
        *pQTextCursorReport = pQTextFrameRoot->lastCursorPosition();
        page2BodyLayoutTable();
    }
    *pQTextCursorReport = pQTextFrameRoot->lastCursorPosition();
    footerLayoutTableCreate();
}
/****************************************************************************************
Function Name			:	headerLayoutTableCreate
Function/DLD ID 		:   SWR_CPDFR_05
Purpose of Function		:   Create header for report
Author/Date     		: 	<Dalton A 23\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void CPdfReport::headerLayoutTableCreate(void)
{
    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(0);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(1);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr1;
    constr1.push_back(QTextLength(QTextLength::PercentageLength, 25));
    constr1.push_back(QTextLength(QTextLength::PercentageLength, 45));
    constr1.push_back(QTextLength(QTextLength::PercentageLength, 25));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr1);

    QTextTable * oQTextTableHeaderComponentsLayout = pQTextCursorReport->insertTable(1,3,oQQTextTableFormatReport);

    *pQTextCursorReport = oQTextTableHeaderComponentsLayout->cellAt(0, 0).firstCursorPosition();
    QDate date = QDate::currentDate();
    pQTextCursorReport->insertText("Date:" + date.toString("dd.MM.yyyy"),oQTextCharFormatHeader4);      //modify

    *pQTextCursorReport = oQTextTableHeaderComponentsLayout->cellAt(0, 1).lastCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    pQTextCursorReport->insertText("Switch Configuration Report\n",oQTextCharFormatHeader1);
    pQTextCursorReport->insertText(stProductData[modelIndex].m_qsProductName,oQTextCharFormatHeader3);

    *pQTextCursorReport = oQTextTableHeaderComponentsLayout->cellAt(0, 2).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatRightAlignment);

    QImage logo(QString().append(":/Image/").append(REPORT_LOGO_FILE_NAME));
    pQTextCursorReport->insertImage(logo.scaled(200,200, Qt::KeepAspectRatio));

    *pQTextCursorReport = pQTextFrameRoot->lastCursorPosition();

    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(0);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(1);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr2;
    constr2.push_back(QTextLength(QTextLength::PercentageLength, 95));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr2);

    QTextTable * oQTextTableHeaderLineLayout = pQTextCursorReport->insertTable(1,1,oQQTextTableFormatReport);

    *pQTextCursorReport = oQTextTableHeaderLineLayout->cellAt(0, 0).firstCursorPosition();

    QTextCharFormat oQTextCharFormatAdjustSpacing;
    oQTextCharFormatAdjustSpacing.setFont(QFont("Arial",2));

    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    for(int i =0; i<372; i++)
    {
      pQTextCursorReport->insertText("_",oQTextCharFormatAdjustSpacing);
    }
    *pQTextCursorReport = pQTextFrameRoot->lastCursorPosition();
}
/****************************************************************************************
Function Name			:	footerLayoutTableCreate
Function/DLD ID 		:   SWR_CPDFR_06
Purpose of Function		:   Create footer for report
Author/Date     		: 	<Dalton A 23\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void CPdfReport::footerLayoutTableCreate(void)
{
    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(0);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(1);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr2;
    constr2.push_back(QTextLength(QTextLength::PercentageLength, 95));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr2);

    QTextTable * oQTextTableFooterLayout = pQTextCursorReport->insertTable(1,1,oQQTextTableFormatReport);

    *pQTextCursorReport = oQTextTableFooterLayout->cellAt(0, 0).firstCursorPosition();

    unsigned char ucTotalNumberOfPages;
    if (ucNumberOfPorts > 17)
    {
        ucTotalNumberOfPages = 3;
    }
    else
    {
        ucTotalNumberOfPages = 2;
    }
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    pQTextCursorReport->insertText("Page " + QString::number(ucPageNumber) + " of " + QString::number(ucTotalNumberOfPages),oQTextCharFormatHeader4);
    ucPageNumber++;
}
/****************************************************************************************
Function Name			:	page1BodyLayoutTable
Function/DLD ID 		:   SWR_CPDFR_07
Purpose of Function		:   Create body of page1 for report
Author/Date     		: 	<Dalton A 23\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void CPdfReport::page1BodyLayoutTable(void)
{
    *pQTextCursorReport = pQTextFrameRoot->lastCursorPosition();
    generalInformationLayoutTable();
    *pQTextCursorReport = pQTextFrameRoot->lastCursorPosition();

    globalParametersLayoutTable();
}
/****************************************************************************************
Function Name			:	generalInformationLayoutTable
Function/DLD ID 		:   SWR_CPDFR_08
Purpose of Function		:   Create layout for general information for report
Author/Date     		: 	<Dalton A 23\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void CPdfReport::generalInformationLayoutTable(void)
{
    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(0);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(1);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr;
    constr.push_back(QTextLength(QTextLength::PercentageLength, 15));
    constr.push_back(QTextLength(QTextLength::PercentageLength, 12));
    constr.push_back(QTextLength(QTextLength::PercentageLength, 2));
    constr.push_back(QTextLength(QTextLength::PercentageLength, 27));
    constr.push_back(QTextLength(QTextLength::PercentageLength, 12));
    constr.push_back(QTextLength(QTextLength::PercentageLength, 2));
    constr.push_back(QTextLength(QTextLength::PercentageLength, 27));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr);


    QTextTable * oQTextTableGeneralInformationLayout = pQTextCursorReport->insertTable(11,7,oQQTextTableFormatReport);
    oQTextTableGeneralInformationLayout->mergeCells(0, 0, 1, 7);
    oQTextTableGeneralInformationLayout->mergeCells(1, 0, 1, 7);
    oQTextTableGeneralInformationLayout->mergeCells(2, 0, 1, 7);
    oQTextTableGeneralInformationLayout->mergeCells(10, 0, 1, 7);
    oQTextTableGeneralInformationLayout->mergeCells(3, 0, 7, 1);

    QTextCharFormat oQTextCharFormatAdjustSpacing;
    oQTextCharFormatAdjustSpacing.setFont(QFont("Arial",1));

    oQTextTableCellCopy = oQTextTableGeneralInformationLayout->cellAt(0, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatAdjustSpacing);
    oQTextTableCellCopy = oQTextTableGeneralInformationLayout->cellAt(2, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatSpacing);
    oQTextTableCellCopy = oQTextTableGeneralInformationLayout->cellAt(10, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatSpacing);

    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(1, 0).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    pQTextCursorReport->insertText("General Information",oQTextCharFormatHeader2);

    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(3, 0).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);

    QImage image(stProductData[modelIndex].productImagePath);


    pQTextCursorReport->insertImage(image.scaled(125, 125, Qt::KeepAspectRatio));

//    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(5, 1).firstCursorPosition();
//    pQTextCursorReport->insertText("Product Code",oQTextCharFormatTableHeader);

//    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(5, 2).firstCursorPosition();
//    pQTextCursorReport->insertText(":",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(3, 1).firstCursorPosition();
    pQTextCursorReport->insertText("Serial Number",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(3, 2).firstCursorPosition();
    pQTextCursorReport->insertText(":",oQTextCharFormatTableHeader);

//    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(7, 1).firstCursorPosition();
//    pQTextCursorReport->insertText("File Release",oQTextCharFormatTableHeader);

//    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(7, 2).firstCursorPosition();
//    pQTextCursorReport->insertText(":",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(3, 4).firstCursorPosition();
    pQTextCursorReport->insertText("Contact Person",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(3, 5).firstCursorPosition();
    pQTextCursorReport->insertText(":",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(5, 4).firstCursorPosition();
    pQTextCursorReport->insertText("Location",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(5, 5).firstCursorPosition();
    pQTextCursorReport->insertText(":",oQTextCharFormatTableHeader);


//    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(7, 4).firstCursorPosition();
//    pQTextCursorReport->insertText("Component Id",oQTextCharFormatTableHeader);

//    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(7, 5).firstCursorPosition();
//    pQTextCursorReport->insertText(":",oQTextCharFormatTableHeader);


    //Data
//    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(5, 3).firstCursorPosition();
//    pQTextCursorReport->insertText(QString::number(SwitchConfiguration.aucproductid),oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(3, 3).firstCursorPosition();
    pQTextCursorReport->insertText(serialNumber,oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(7, 3).firstCursorPosition();
    pQTextCursorReport->insertText(QString::fromLocal8Bit((char*)(SwitchConfiguration.aucreleaseNo)),oQTextCharFormatTableHeader);

    QString tempName = QString::fromLocal8Bit((char*)(SwitchConfiguration.auccontactname));
    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(3, 6).firstCursorPosition();
    pQTextCursorReport->insertText(tempName.left(20),oQTextCharFormatTableHeader);
    if(tempName.length() > 20)
    {
        *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(4, 6).firstCursorPosition();
        pQTextCursorReport->insertText(tempName.mid(20),oQTextCharFormatTableHeader);
    }

    QString tempLocation = QString::fromLocal8Bit((char*)(SwitchConfiguration.auclocation));

    *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(5, 6).firstCursorPosition();
    pQTextCursorReport->insertText(tempLocation.left(20),oQTextCharFormatTableHeader);

    if(tempLocation.length() > 20)
    {
        *pQTextCursorReport = oQTextTableGeneralInformationLayout->cellAt(6, 6).firstCursorPosition();
        pQTextCursorReport->insertText(tempLocation.mid(20),oQTextCharFormatTableHeader);
    }

}
/****************************************************************************************
Function Name			:	globalParametersLayoutTable
Function/DLD ID 		:   SWR_CPDFR_09
Purpose of Function		:   Create layout for global parameters for report
Author/Date     		: 	<Dalton A 24\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void CPdfReport::globalParametersLayoutTable(void)
{
    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(0);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(1);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr;
    constr.push_back(QTextLength(QTextLength::PercentageLength, 95));

    oQQTextTableFormatReport.setColumnWidthConstraints(constr);

    QTextTable * oQTextTableGlobalParametersLayout = pQTextCursorReport->insertTable(2,1,oQQTextTableFormatReport);

    oQTextTableCellCopy = oQTextTableGlobalParametersLayout->cellAt(1, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatSpacing);

    *pQTextCursorReport = oQTextTableGlobalParametersLayout->cellAt(0, 0).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    pQTextCursorReport->insertText("Global Parameters",oQTextCharFormatHeader2);

    *pQTextCursorReport = pQTextFrameRoot->lastCursorPosition();


    alarmPswAndQoSVlanLayoutTable();

    *pQTextCursorReport = pQTextFrameRoot->lastCursorPosition();
    qoSDscpLayoutTable();
}
/****************************************************************************************
Function Name			:	alarmPswAndQoSVlanLayoutTable
Function/DLD ID 		:   SWR_CPDFR_10
Purpose of Function		:   Create layout for alarm and mapping parameters for report
Author/Date     		: 	<Dalton A 24\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void CPdfReport::alarmPswAndQoSVlanLayoutTable(void)
{
    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(0);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(1);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr;
    constr.push_back(QTextLength(QTextLength::PercentageLength, 50));
    constr.push_back(QTextLength(QTextLength::PercentageLength, 2));
    constr.push_back(QTextLength(QTextLength::PercentageLength, 38));
    constr.push_back(QTextLength(QTextLength::PercentageLength, 5));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr);

    QTextTable * oQTextTableAlarmPswAndQoSVlanLayout = pQTextCursorReport->insertTable(4,4,oQQTextTableFormatReport);

    oQTextTableAlarmPswAndQoSVlanLayout->mergeCells(1, 0, 1, 4);
    oQTextTableAlarmPswAndQoSVlanLayout->mergeCells(3, 0, 1, 4);

    oQTextTableCellCopy = oQTextTableAlarmPswAndQoSVlanLayout->cellAt(1, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatSpacing);
    oQTextTableCellCopy = oQTextTableAlarmPswAndQoSVlanLayout->cellAt(3, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatSpacing);


    *pQTextCursorReport = oQTextTableAlarmPswAndQoSVlanLayout->cellAt(0, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Alarm PSU / Aging Time / QoS Trust Mode",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableAlarmPswAndQoSVlanLayout->cellAt(0, 2).firstCursorPosition();
    pQTextCursorReport->insertText("QoS 802.1p Mapping",oQTextCharFormatTableHeader);


    oQQTextTableFormatReport.setAlignment(Qt::AlignLeft);
    oQQTextTableFormatReport.setCellPadding(1);
    oQQTextTableFormatReport.setCellSpacing(-1);
	oQQTextTableFormatReport.setBorder(1.25);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_Solid);
    oQQTextTableFormatReport.setBorderBrush(QBrush(Qt::black));
    QVector<QTextLength> constr1;
    constr1.push_back(QTextLength(QTextLength::PercentageLength, 100));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr1);


    *pQTextCursorReport = oQTextTableAlarmPswAndQoSVlanLayout->cellAt(2, 0).firstCursorPosition();
    QTextTable * oQTextTableOuterAlarmPswLayout = pQTextCursorReport->insertTable(1,1,oQQTextTableFormatReport);

    *pQTextCursorReport = oQTextTableAlarmPswAndQoSVlanLayout->cellAt(2, 2).firstCursorPosition();
    QTextTable * oQTextTableOuterQoSVlanLayout = pQTextCursorReport->insertTable(1,1,oQQTextTableFormatReport);

    oQTextTableCellCopy = oQTextTableOuterAlarmPswLayout->cellAt(0, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatGrey);

    oQTextTableCellCopy = oQTextTableOuterQoSVlanLayout->cellAt(0, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatGrey);

    *pQTextCursorReport = oQTextTableOuterAlarmPswLayout->cellAt(0, 0).firstCursorPosition();

    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(1);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(0);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr2;
    constr2.push_back(QTextLength(QTextLength::PercentageLength, 25));
    constr2.push_back(QTextLength(QTextLength::PercentageLength, 16));
    constr2.push_back(QTextLength(QTextLength::PercentageLength, 16));
    constr2.push_back(QTextLength(QTextLength::PercentageLength, 21));
    constr2.push_back(QTextLength(QTextLength::PercentageLength, 22));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr2);

    QTextTable * oQTextTableInnerAlarmPswLayout = pQTextCursorReport->insertTable(2,5,oQQTextTableFormatReport);


    for(int i = 1; i < 5 ; i++)
    {
        oQTextTableCellCopy = oQTextTableInnerAlarmPswLayout->cellAt(1, i);
        oQTextTableCellCopy.setFormat(oQTextCharFormatWhite);
    }

    *pQTextCursorReport = oQTextTableInnerAlarmPswLayout->cellAt(0, 0).firstCursorPosition();
    pQTextCursorReport->insertText("\nParameter",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerAlarmPswLayout->cellAt(1, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Value",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerAlarmPswLayout->cellAt(0, 1).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    pQTextCursorReport->insertText("Alarm PSU 1",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerAlarmPswLayout->cellAt(0, 2).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    pQTextCursorReport->insertText("Alarm PSU 2",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerAlarmPswLayout->cellAt(0, 3).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    pQTextCursorReport->insertText("Aging Time [s]",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerAlarmPswLayout->cellAt(0, 4).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    pQTextCursorReport->insertText("QoS Trust Mode",oQTextCharFormatTableHeader);


    *pQTextCursorReport = oQTextTableOuterQoSVlanLayout->cellAt(0, 0).firstCursorPosition();

    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(1);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(0);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr3;
    constr3.push_back(QTextLength(QTextLength::PercentageLength, 36));
    for(int i = 0; i < 8; i++)
    {
        constr3.push_back(QTextLength(QTextLength::PercentageLength, 8));
    }

    oQQTextTableFormatReport.setColumnWidthConstraints(constr3);

    QTextTable * oQTextTableInnerQoSVlanLayout = pQTextCursorReport->insertTable(2,9,oQQTextTableFormatReport);

    for(int i = 1; i < 9 ; i++)
    {
        oQTextTableCellCopy = oQTextTableInnerQoSVlanLayout->cellAt(1, i);
        oQTextTableCellCopy.setFormat(oQTextCharFormatWhite);
    }

    *pQTextCursorReport = oQTextTableInnerQoSVlanLayout->cellAt(0, 0).firstCursorPosition();
    pQTextCursorReport->insertText("VLAN Priority",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerQoSVlanLayout->cellAt(1, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Traffic Class",oQTextCharFormatTableHeader);

    for(int i = 1; i < 9 ; i++)
    {
        *pQTextCursorReport = oQTextTableInnerQoSVlanLayout->cellAt(0, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        pQTextCursorReport->insertText(QString::number(i - 1),oQTextCharFormatTableHeader);
    }


    //Data
    *pQTextCursorReport = oQTextTableInnerAlarmPswLayout->cellAt(1, 1).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    if( SwitchConfiguration.aucalarmPsu[0] == 1)
        pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
    else
        pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);

    *pQTextCursorReport = oQTextTableInnerAlarmPswLayout->cellAt(1, 2).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    if( SwitchConfiguration.aucalarmPsu[1] == 1)
        pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
    else
        pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);

    *pQTextCursorReport = oQTextTableInnerAlarmPswLayout->cellAt(1, 3).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    pQTextCursorReport->insertText(QString::number(SwitchConfiguration.agingTime),oQTextCharFormatTableData);

    *pQTextCursorReport = oQTextTableInnerAlarmPswLayout->cellAt(1, 4).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    if(SwitchConfiguration.globalTrustMode == 0)
        pQTextCursorReport->insertText("Untrusted",oQTextCharFormatTableData);
    else if (SwitchConfiguration.globalTrustMode == 1)
        pQTextCursorReport->insertText("TrustDot1p",oQTextCharFormatTableData);
    else if (SwitchConfiguration.globalTrustMode == 2)
        pQTextCursorReport->insertText("TrustIpDscp",oQTextCharFormatTableData);


    for(int i = 1; i < 9 ; i++)
    {
        *pQTextCursorReport = oQTextTableInnerQoSVlanLayout->cellAt(1, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        pQTextCursorReport->insertText(QString::number(SwitchConfiguration.aucdotp1PcpToTc[i-1]),oQTextCharFormatTableData);
    }
}
/****************************************************************************************
Function Name			:	qoSDscpLayoutTable
Function/DLD ID 		:   SWR_CPDFR_11
Purpose of Function		:   Create layout for qoS and DSCP for report
Author/Date     		: 	<Dalton A 24\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void CPdfReport::qoSDscpLayoutTable(void)
{
    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(0);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(1);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr;
    constr.push_back(QTextLength(QTextLength::PercentageLength, 90));
    constr.push_back(QTextLength(QTextLength::PercentageLength, 5));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr);

    QTextTable * oQTextTableQoSDscpLayout = pQTextCursorReport->insertTable(8,2,oQQTextTableFormatReport);

    oQTextTableQoSDscpLayout->mergeCells(1, 0, 1, 2);
    oQTextTableQoSDscpLayout->mergeCells(3, 0, 1, 2);
    oQTextTableQoSDscpLayout->mergeCells(5, 0, 1, 2);
    oQTextTableQoSDscpLayout->mergeCells(7, 0, 1, 2);

    oQTextTableCellCopy = oQTextTableQoSDscpLayout->cellAt(1, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatSpacing);
    oQTextTableCellCopy = oQTextTableQoSDscpLayout->cellAt(3, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatSpacing);
    oQTextTableCellCopy = oQTextTableQoSDscpLayout->cellAt(5, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatSpacing);

    QTextCharFormat oQTextCharFormatAdjustSpacing;
    oQTextCharFormatAdjustSpacing.setFont(QFont("Arial",12));
    oQTextTableCellCopy = oQTextTableQoSDscpLayout->cellAt(7, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatAdjustSpacing);

    *pQTextCursorReport = oQTextTableQoSDscpLayout->cellAt(0, 0).firstCursorPosition();
    pQTextCursorReport->insertText("QoS DSCP Mapping",oQTextCharFormatTableHeader);

    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(1);
    oQQTextTableFormatReport.setCellSpacing(-1);
	oQQTextTableFormatReport.setBorder(1.25);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_Solid);
    oQQTextTableFormatReport.setBorderBrush(QBrush(Qt::black));
    QVector<QTextLength> constr2;
    constr2.push_back(QTextLength(QTextLength::PercentageLength, 100));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr2);

    *pQTextCursorReport = oQTextTableQoSDscpLayout->cellAt(2, 0).firstCursorPosition();
    QTextTable * oQTextTableOuterQoSDscpFirstSetLayout = pQTextCursorReport->insertTable(1,1,oQQTextTableFormatReport);

    *pQTextCursorReport = oQTextTableQoSDscpLayout->cellAt(4, 0).firstCursorPosition();
    QTextTable * oQTextTableOuterQoSDscpSecondSetLayout = pQTextCursorReport->insertTable(1,1,oQQTextTableFormatReport);


    oQQTextTableFormatReport.setAlignment(Qt::AlignLeft);
    oQQTextTableFormatReport.setCellPadding(1);
    oQQTextTableFormatReport.setCellSpacing(-1);
	oQQTextTableFormatReport.setBorder(1.25);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_Solid);
    oQQTextTableFormatReport.setBorderBrush(QBrush(Qt::black));
    QVector<QTextLength> constr3;
    constr3.push_back(QTextLength(QTextLength::PercentageLength, 71.2));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr3);

    *pQTextCursorReport = oQTextTableQoSDscpLayout->cellAt(6, 0).firstCursorPosition();
    QTextTable * oQTextTableOuterQoSDscpThirdSetLayout = pQTextCursorReport->insertTable(1,1,oQQTextTableFormatReport);

    oQTextTableCellCopy = oQTextTableOuterQoSDscpFirstSetLayout->cellAt(0, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatGrey);

    oQTextTableCellCopy = oQTextTableOuterQoSDscpSecondSetLayout->cellAt(0, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatGrey);

    oQTextTableCellCopy = oQTextTableOuterQoSDscpThirdSetLayout->cellAt(0, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatGrey);

    oQQTextTableFormatReport.setBorder(0);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr4;
    constr4.push_back(QTextLength(QTextLength::PercentageLength, 13.6));
    for(int i = 0; i < 24; i++)
    {
        constr4.push_back(QTextLength(QTextLength::PercentageLength, 3.6));
    }
    oQQTextTableFormatReport.setColumnWidthConstraints(constr4);

    *pQTextCursorReport = oQTextTableOuterQoSDscpFirstSetLayout->cellAt(0, 0).firstCursorPosition();
    QTextTable * oQTextTableInnerQoSDscpFirstSetLayout = pQTextCursorReport->insertTable(2,25,oQQTextTableFormatReport);

    *pQTextCursorReport = oQTextTableOuterQoSDscpSecondSetLayout->cellAt(0, 0).firstCursorPosition();
    QTextTable * oQTextTableInnerQoSDscpSecondSetLayout = pQTextCursorReport->insertTable(2,25,oQQTextTableFormatReport);

    QVector<QTextLength> constr5;
    constr5.push_back(QTextLength(QTextLength::PercentageLength, 19.04));
    for(int i = 0; i < 16; i++)
    {
        constr5.push_back(QTextLength(QTextLength::PercentageLength, 5.06));
    }
    oQQTextTableFormatReport.setColumnWidthConstraints(constr5);

    *pQTextCursorReport = oQTextTableOuterQoSDscpThirdSetLayout->cellAt(0, 0).firstCursorPosition();
    QTextTable * oQTextTableInnerQoSDscpThirdSetLayout = pQTextCursorReport->insertTable(2,17,oQQTextTableFormatReport);


    for(int i = 1; i < 25 ; i++)
    {
        oQTextTableCellCopy = oQTextTableInnerQoSDscpFirstSetLayout->cellAt(1, i);
        oQTextTableCellCopy.setFormat(oQTextCharFormatWhite);
        oQTextTableCellCopy = oQTextTableInnerQoSDscpSecondSetLayout->cellAt(1, i);
        oQTextTableCellCopy.setFormat(oQTextCharFormatWhite);
    }

    for(int i = 1; i < 17 ; i++)
    {
        oQTextTableCellCopy = oQTextTableInnerQoSDscpThirdSetLayout->cellAt(1, i);
        oQTextTableCellCopy.setFormat(oQTextCharFormatWhite);
    }

    *pQTextCursorReport = oQTextTableInnerQoSDscpFirstSetLayout->cellAt(0, 0).firstCursorPosition();
    pQTextCursorReport->insertText("DSCP Value",oQTextCharFormatTableHeader);
    *pQTextCursorReport = oQTextTableInnerQoSDscpFirstSetLayout->cellAt(1, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Traffic Class",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerQoSDscpSecondSetLayout->cellAt(0, 0).firstCursorPosition();
    pQTextCursorReport->insertText("DSCP Value",oQTextCharFormatTableHeader);
    *pQTextCursorReport = oQTextTableInnerQoSDscpSecondSetLayout->cellAt(1, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Traffic Class",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerQoSDscpThirdSetLayout->cellAt(0, 0).firstCursorPosition();
    pQTextCursorReport->insertText("DSCP Value",oQTextCharFormatTableHeader);
    *pQTextCursorReport = oQTextTableInnerQoSDscpThirdSetLayout->cellAt(1, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Traffic Class",oQTextCharFormatTableHeader);

    for(int i = 1; i < 25; i++)
    {
        *pQTextCursorReport = oQTextTableInnerQoSDscpFirstSetLayout->cellAt(0, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        pQTextCursorReport->insertText(QString::number(i - 1),oQTextCharFormatTableHeader);

        *pQTextCursorReport = oQTextTableInnerQoSDscpSecondSetLayout->cellAt(0, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        pQTextCursorReport->insertText(QString::number(i + 23),oQTextCharFormatTableHeader);
    }

    for(int i = 1; i < 17; i++)
    {
        *pQTextCursorReport = oQTextTableInnerQoSDscpThirdSetLayout->cellAt(0, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        pQTextCursorReport->insertText(QString::number(i + 47),oQTextCharFormatTableHeader);
    }
    //Data
    for(int i = 1; i < 25; i++)
    {
        *pQTextCursorReport = oQTextTableInnerQoSDscpFirstSetLayout->cellAt(1, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        pQTextCursorReport->insertText(QString::number(SwitchConfiguration.aucdscpD1D2[i-1]),oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerQoSDscpSecondSetLayout->cellAt(1, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        pQTextCursorReport->insertText(QString::number(SwitchConfiguration.aucdscpD1D2[i+23]),oQTextCharFormatTableData);
    }

    for(int i = 1; i < 17; i++)
    {
        *pQTextCursorReport = oQTextTableInnerQoSDscpThirdSetLayout->cellAt(1, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        pQTextCursorReport->insertText(QString::number(SwitchConfiguration.aucdscpD1D2[i+47]),oQTextCharFormatTableData);
    }
}
/****************************************************************************************
Function Name			:	page2BodyLayoutTable
Function/DLD ID 		:   SWR_CPDFR_12
Purpose of Function		:   Create layout for page 2 for report
Author/Date     		: 	<Dalton A 25\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void CPdfReport::page2BodyLayoutTable(void)
{
    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(0);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(1);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    QVector<QTextLength> constr;
    constr.push_back(QTextLength(QTextLength::PercentageLength, 95));
    oQQTextTableFormatReport.setColumnWidthConstraints(constr);

    QTextTable * oQTextTablePage2BodyLayout = pQTextCursorReport->insertTable(1,1,oQQTextTableFormatReport);

    QTextCharFormat oQTextCharFormatAdjustSpacing;
    oQTextCharFormatAdjustSpacing.setFont(QFont("Arial",3));

    oQTextCharFormatAdjustSpacing.setFont(QFont("Arial",4));

    *pQTextCursorReport = oQTextTablePage2BodyLayout->cellAt(0, 0).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
    pQTextCursorReport->insertText("\nPort Parameters",oQTextCharFormatHeader2);
    portParametersLayoutTable();

    //inserting Space in order to have a similar layout to Page1
    *pQTextCursorReport = pQTextFrameRoot->lastCursorPosition();
    pQTextCursorReport->insertText(" \n \n \n");
}
/****************************************************************************************
Function Name			:	portParametersLayoutTable
Function/DLD ID 		:   SWR_CPDFR_12
Purpose of Function		:   Create layout for port parameter on page 2 for report
Author/Date     		: 	<Dalton A 24\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void CPdfReport::portParametersLayoutTable(void)
{
    unsigned char ucNumberOfPortsToShow =0;

    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(0);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(2);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_None);
    oQQTextTableFormatReport.setBorderBrush(QBrush(Qt::black));
    QVector<QTextLength> constr2;
    constr2.push_back(QTextLength(QTextLength::PercentageLength,95));

    oQQTextTableFormatReport.setColumnWidthConstraints(constr2);

    QTextTable * oQTextTableAlignmentLayout = pQTextCursorReport->insertTable(1,1,oQQTextTableFormatReport);
    *pQTextCursorReport = oQTextTableAlignmentLayout->cellAt(0, 0).firstCursorPosition();

    oQQTextTableFormatReport.setAlignment(Qt::AlignLeft);
    oQQTextTableFormatReport.setCellPadding(0);
    oQQTextTableFormatReport.setCellSpacing(-1);
	oQQTextTableFormatReport.setBorder(1);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_Solid);
    oQQTextTableFormatReport.setBorderBrush(QBrush(Qt::black));
    QVector<QTextLength> constr;
    constr.push_back(QTextLength(QTextLength::VariableLength,100));

    oQQTextTableFormatReport.setColumnWidthConstraints(constr);

    QTextTable * oQTextTableOuterPortParametersLayout = pQTextCursorReport->insertTable(1,1,oQQTextTableFormatReport);
    *pQTextCursorReport = oQTextTableOuterPortParametersLayout->cellAt(0, 0).firstCursorPosition();

    oQQTextTableFormatReport.setAlignment(Qt::AlignCenter);
    oQQTextTableFormatReport.setCellPadding(0.7);
    oQQTextTableFormatReport.setCellSpacing(-1);
    oQQTextTableFormatReport.setBorder(1);
    oQQTextTableFormatReport.setBorderStyle(QTextFrameFormat::BorderStyle_Solid);
    oQQTextTableFormatReport.setBorderBrush(QBrush(Qt::black));

    QVector<QTextLength> constr1;
    constr1.push_back(QTextLength(QTextLength::FixedLength, 170));

    if(ucPageNumber == 2)
    {
        if(ucNumberOfPorts < 17)
        {
            ucNumberOfPortsToShow =  ucNumberOfPorts;
        }
        else
        {
            ucNumberOfPortsToShow =  16;
        }
    }
    else if(ucPageNumber == 3)
    {
        ucNumberOfPortsToShow = ucNumberOfPorts - 16;
    }

    for(int i = 1 ; i <= 16 ; i++)
    {
        constr1.push_back(QTextLength(QTextLength::FixedLength, 35));
    }

    oQQTextTableFormatReport.setColumnWidthConstraints(constr1);
    QTextTable * oQTextTableInnerPortParametersLayout = pQTextCursorReport->insertTable(25,(ucNumberOfPortsToShow + 1),oQQTextTableFormatReport);

    oQTextTableInnerPortParametersLayout->mergeCells(4, 0, 1, (ucNumberOfPortsToShow + 1));
    oQTextTableInnerPortParametersLayout->mergeCells(10, 0, 1, (ucNumberOfPortsToShow + 1));
    oQTextTableInnerPortParametersLayout->mergeCells(14, 0, 1, (ucNumberOfPortsToShow + 1));
    oQTextTableInnerPortParametersLayout->mergeCells(20, 0, 1, (ucNumberOfPortsToShow + 1));

    for(int i = 1 ; i <= ucNumberOfPortsToShow; i++)
    {
        oQTextTableInnerPortParametersLayout->mergeCells(0, i, 2, 1);
    }

    for(int i = 1; i <= ucNumberOfPortsToShow ; i++)
    {
        oQTextTableCellCopy = oQTextTableInnerPortParametersLayout->cellAt(0, i);
        oQTextTableCellCopy.setFormat(oQTextCharFormatGrey);
        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(0, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
       if(ucPageNumber == 2)
       {
           pQTextCursorReport->insertText(QString::number(i),oQTextCharFormatTableHeader);
       }
       else if(ucPageNumber == 3)
       {
           pQTextCursorReport->insertText(QString::number(i + 16),oQTextCharFormatTableHeader);
       }
    }
    oQTextTableCellCopy = oQTextTableInnerPortParametersLayout->cellAt(0, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatGrey);
    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(0, 0).firstCursorPosition();
    pQTextCursorReport->setBlockFormat(oQTextBlockFormatRightAlignment);
    for(int i = 1 ; i < 25; i++)
    {
        oQTextTableCellCopy = oQTextTableInnerPortParametersLayout->cellAt(i, 0);
        oQTextTableCellCopy.setFormat(oQTextCharFormatGrey);
    }

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(0, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Port",oQTextCharFormatTableHeader);
    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(1, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Parameter",oQTextCharFormatTableHeader);
    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(2, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Port State",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(3, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Link Alarm",oQTextCharFormatTableHeader);       //should this be Link Alarm??? JG 12.8.2016

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(5, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Speed [Mbit/s]",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(6, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Auto-negotiation",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(7, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Auto-crossing",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(8, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Duplex Mode",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(9, 0).firstCursorPosition();
    pQTextCursorReport->insertText("MDI State",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(11, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Jumbo Frames",oQTextCharFormatTableHeader);

//    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(12, 0).firstCursorPosition();
//    pQTextCursorReport->insertText("QoS Trust Mode",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(12, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Port Priority",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(13, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Energy Efficient Ethernet",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(15, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Flow Control",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(16, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Broadcast Storm Protection",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(17, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Broadcast Storm Thld. [%]",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(18, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Multicast Storm Protection",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(19, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Multicast Storm Thld. [%]",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(21, 0).firstCursorPosition();
    pQTextCursorReport->insertText("PoE Admin State",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(22, 0).firstCursorPosition();
    pQTextCursorReport->insertText("PoE Priority",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(23, 0).firstCursorPosition();
    pQTextCursorReport->insertText("Allowed PoE classes",oQTextCharFormatTableHeader);

    *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(24, 0).firstCursorPosition();
    pQTextCursorReport->insertText("PoE User Set Limit",oQTextCharFormatTableHeader);

    //Data
    for(int i = 1; i <= ucNumberOfPortsToShow; i++)
    {
        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(2, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucadminState[i-1] == 1)
            pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(3, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.auclinkAlarmStatus[i-1] == 1)
            pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(5, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucspeed[i-1] == 1)
            pQTextCursorReport->insertText("10\nMbps",oQTextCharFormatTableData);
        else if(SwitchConfiguration.aucspeed[i-1] == 2)
            pQTextCursorReport->insertText("100\nMbps",oQTextCharFormatTableData);
        else if(SwitchConfiguration.aucspeed[i-1] == 3)
            pQTextCursorReport->insertText("-",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(6, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucautonegStatus[i-1] == 1)
            pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(7, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucautoCrossingstatus[i-1] == 1)
            pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(8, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucduplexMode[i-1] == 1)
            pQTextCursorReport->insertText("HDX",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("FDX",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(9, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucMdistatus[i-1] == 1)
            pQTextCursorReport->insertText("MDI",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("MDIX",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(11, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucjumboFrameStatus[i-1] == 1)
            pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);

//        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(12, i).firstCursorPosition();
//        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
//        if(SwitchConfiguration.aucTrustMode[i-1] == 0)
//            pQTextCursorReport->insertText("Untru\nsted",oQTextCharFormatTableData);
//        else if (SwitchConfiguration.aucTrustMode[i-1] == 1)
//            pQTextCursorReport->insertText("Trust\nDot1p",oQTextCharFormatTableData);
//        else if (SwitchConfiguration.aucTrustMode[i-1] == 2)
//            pQTextCursorReport->insertText("Trust\nDSCP",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(12, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucportBasedQoS[i-1] == 0)
            pQTextCursorReport->insertText("0",oQTextCharFormatTableData);
        else if (SwitchConfiguration.aucportBasedQoS[i-1] == 1)
            pQTextCursorReport->insertText("1",oQTextCharFormatTableData);
        else if (SwitchConfiguration.aucportBasedQoS[i-1] == 2)
            pQTextCursorReport->insertText("2",oQTextCharFormatTableData);
        else if (SwitchConfiguration.aucportBasedQoS[i-1] == 3)
            pQTextCursorReport->insertText("3",oQTextCharFormatTableData);
        else if (SwitchConfiguration.aucportBasedQoS[i-1] == 4)
            pQTextCursorReport->insertText("4",oQTextCharFormatTableData);
        else if (SwitchConfiguration.aucportBasedQoS[i-1] == 5)
            pQTextCursorReport->insertText("5",oQTextCharFormatTableData);
        else if (SwitchConfiguration.aucportBasedQoS[i-1] == 6)
            pQTextCursorReport->insertText("6",oQTextCharFormatTableData);
        else if (SwitchConfiguration.aucportBasedQoS[i-1] == 7)
            pQTextCursorReport->insertText("7",oQTextCharFormatTableData);


        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(13, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucEEEStatus[i-1] == 1)
            pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(15, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucflowControlStatus[i-1] == 1)
            pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(16, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucbcStormStatus[i-1] == 1)
            pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(17, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        pQTextCursorReport->insertText(QString::number(SwitchConfiguration.aucbcStormThresold[i-1]),oQTextCharFormatTableData);


        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(18, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucmcStormStatus[i-1] == 1)
            pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(19, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        pQTextCursorReport->insertText(QString::number(SwitchConfiguration.aucmcStormThresold[i-1]),oQTextCharFormatTableData);




        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(21, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if((g_CurrentProductInfo1.m_ucproductLine & PRODUCT_LINE_POE) == 0)
        {
            pQTextCursorReport->insertText("-",oQTextCharFormatTableData);
        }
        else
        {
        if(SwitchConfiguration.aucpoeStatus[i-1] == 1)
            pQTextCursorReport->insertText("On",oQTextCharFormatTableData);
        else
            pQTextCursorReport->insertText("Off",oQTextCharFormatTableData);
        }

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(22, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if((g_CurrentProductInfo1.m_ucproductLine & PRODUCT_LINE_POE) == 0)
        {
            pQTextCursorReport->insertText("-",oQTextCharFormatTableData);

        }
        else
        {
            if(SwitchConfiguration.aucpoePriority[i-1] == 1)
                pQTextCursorReport->insertText("Low",oQTextCharFormatTableData);
            else if (SwitchConfiguration.aucpoePriority[i-1] == 2)
                pQTextCursorReport->insertText("High",oQTextCharFormatTableData);
            else if (SwitchConfiguration.aucpoePriority[i-1] == 3)
                pQTextCursorReport->insertText("Critical",oQTextCharFormatTableData);
        }

        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(23, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        QString temp;
        if((g_CurrentProductInfo1.m_ucproductLine & PRODUCT_LINE_POE) == 0)
        {
            temp.append("-");
        }
        else
        {
            if(SwitchConfiguration.aucpoeAllowedClasses[i-1][0] != 0xFF)
                temp.append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i-1][0]));
            if(SwitchConfiguration.aucpoeAllowedClasses[i-1][1] != 0xFF)
                temp.append(",").append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i-1][1]));
            if(SwitchConfiguration.aucpoeAllowedClasses[i-1][2] != 0xFF)
                temp.append(",").append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i-1][2]));
            if(SwitchConfiguration.aucpoeAllowedClasses[i-1][3] != 0xFF)
                temp.append(",").append("\n").append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i-1][3]));
            if(SwitchConfiguration.aucpoeAllowedClasses[i-1][4] != 0xFF)
                temp.append(",").append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i-1][4]));
        }
        pQTextCursorReport->insertText(temp,oQTextCharFormatTableData);


        *pQTextCursorReport = oQTextTableInnerPortParametersLayout->cellAt(24, i).firstCursorPosition();
        pQTextCursorReport->setBlockFormat(oQTextBlockFormatCenterAlignment);
        if(SwitchConfiguration.aucpoeAllowedConsumptionOverride[i-1] == 0)
            pQTextCursorReport->insertText("-",oQTextCharFormatTableData);
        else
        {
            QString temp = QString::number(SwitchConfiguration.aucpoeAllowedConsumptionOverride[i-1]);
            pQTextCursorReport->insertText(temp,oQTextCharFormatTableData);
        }

    }

    QTextCharFormat oQTextCharFormatHeightAndColor;
    oQTextCharFormatHeightAndColor.setBackground(QBrush(QColor(217,217,217,255)));
    oQTextCharFormatHeightAndColor.setFontPointSize(2);

    oQTextTableCellCopy = oQTextTableInnerPortParametersLayout->cellAt(4, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatHeightAndColor);
    oQTextTableCellCopy = oQTextTableInnerPortParametersLayout->cellAt(10, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatHeightAndColor);
    oQTextTableCellCopy = oQTextTableInnerPortParametersLayout->cellAt(14, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatHeightAndColor);
    oQTextTableCellCopy = oQTextTableInnerPortParametersLayout->cellAt(20, 0);
    oQTextTableCellCopy.setFormat(oQTextCharFormatHeightAndColor);

}
