/***************************** FILE HEADER *********************************/
/*!
*  \file      dialog8021p.cpp
*
*  \brief     This file implements the Dialog for the QoS 802.1 D/p Mapping
*
*  \note
*
*  \author    L&T Technology Services Limited
*  \copyright Copyright (c) 2018 Hirschmann Automation & Control GmbH
*
*
*  \version 1a 2018-07-06 Julia Greiss standard header added to file.
*
*//**************************** FILE HEADER *********************************/

/******************************************************************************
 * Includes
 ******************************************************************************/
#include "dialog8021p.h"
#include "ui_dialog8021p.h"
#include "globaldata.h"

/******************************************************************************
 * Globals
 ******************************************************************************/
// Global data of switch which is share between classes
extern configData SwitchConfiguration;

/****************************************************************************************
Function Name			:	Dialog8021p
Function/DLD ID 		:   SWR_DQoSp_01
Purpose of Function		:   Constructor of dialog box for QoS 8021p mapping
Author/Date     		: 	<Manu Singh 15\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget
Return                  :   Void
Remarks                 :
*****************************************************************************************/
Dialog8021p::Dialog8021p(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Dialog8021p)
{
    ui->setupUi(this);
    //Setting up name of the dialog box
    this->setWindowTitle("QoS 802.1 D/p Mapping");

    //Diableing extra buttons
    setWindowFlags(Qt::WindowTitleHint | Qt::Dialog | Qt::WindowCloseButtonHint | Qt::CustomizeWindowHint);

    //updating QoS mapping values from configuration buffer
    for(int i=0;i <8;i++)
    {
        QComboBox *dot1pCombo = findChild<QComboBox *>("comboBox_tcVlan" + QString::number(i));
        if(dot1pCombo)
            dot1pCombo->setCurrentIndex(SwitchConfiguration.aucdotp1PcpToTc[i]);
    }

}
/****************************************************************************************
Function Name			:	~Dialog8021p
Function/DLD ID 		:   SWR_DQoSp_02
Purpose of Function		:   Deconstructor of dialog box for QoS 8021p mapping
Author/Date     		: 	<Manu Singh 15\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
Dialog8021p::~Dialog8021p()
{
    delete ui;
}
/****************************************************************************************
Function Name			:	on_buttonBox_accepted
Function/DLD ID 		:   SWR_DQoSp_03
Purpose of Function		:   Slot called when ok button pressed which trigger saving QoS new values
Author/Date     		: 	<Manu Singh 15\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void Dialog8021p::on_buttonBox_accepted()
{
    //update Buffer
    for(int i=0;i <8;i++)
    {
        QComboBox *dot1pCombo = findChild<QComboBox *>("comboBox_tcVlan" + QString::number(i));
        if(dot1pCombo)
            SwitchConfiguration.aucdotp1PcpToTc[i] = dot1pCombo->currentIndex();
    }
}
/****************************************************************************************
Function Name			:	on_buttonBox_rejected
Function/DLD ID 		:   SWR_DQoSp_04
Purpose of Function		:   Slot called when cancel
Author/Date     		: 	<Manu Singh 15\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void Dialog8021p::on_buttonBox_rejected()
{
    //close();
}
