/***************************** FILE HEADER *********************************/
/*!
*  \file      dialogdscp.cpp
*
*  \brief     This file implements the dialog for IP DSCP Mapping.
*
*  \note
*
*  \author    L&T Technology Services Limited
*  \copyright Copyright (c) 2018 Hirschmann Automation & Control GmbH
*
*
*  \version 1a 2018-07-06 Julia Greiss standard header added to file.
*
*//**************************** FILE HEADER *********************************/

/******************************************************************************
 * Includes
 ******************************************************************************/
#include "dialogdscp.h"
#include "ui_dialogdscp.h"
#include "globaldata.h"

/******************************************************************************
 * Globals
 ******************************************************************************/
// Global data of switch which is share between classes
extern configData SwitchConfiguration;

/****************************************************************************************
Function Name			:	DialogDSCP
Function/DLD ID 		:   SWR_DDSCP_01
Purpose of Function		:   Constructor of dialog box for DSCP mapping
Author/Date     		: 	<Manu Singh 16\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget
Return                  :   Void
Remarks                 :
*****************************************************************************************/
DialogDSCP::DialogDSCP(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::DialogDSCP)
{
    ui->setupUi(this);

    // Setting name of dialogbox
    this->setWindowTitle("IP DSCP Mapping");

    // Disabling extra button
    setWindowFlags(Qt::WindowTitleHint | Qt::Dialog | Qt::WindowCloseButtonHint | Qt::CustomizeWindowHint);

    //Updating ui with configuration values of DSCP
    for(int i=0;i <64;i++)
    {
        QComboBox *dscpCombo = findChild<QComboBox *>("comboBox_tc" + QString::number(i));
        if(dscpCombo)
            dscpCombo->setCurrentIndex(SwitchConfiguration.aucdscpD1D2[i]);
    }
}
/****************************************************************************************
Function Name			:	~DialogDSCP
Function/DLD ID 		:   SWR_DDSCP_02
Purpose of Function		:   Deconstructor of dialog box for DSCP mapping
Author/Date     		: 	<Manu Singh 16\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
DialogDSCP::~DialogDSCP()
{
    delete ui;
}
/****************************************************************************************
Function Name			:	on_buttonBox_accepted
Function/DLD ID 		:   SWR_DDSCP_03
Purpose of Function		:   Slot called when ok button pressed which trigger saving DSCP new values
Author/Date     		: 	<Manu Singh 16\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void DialogDSCP::on_buttonBox_accepted()
{
    for(int i=0;i <64;i++)
    {
        QComboBox *dscpCombo = findChild<QComboBox *>("comboBox_tc" + QString::number(i));
        if(dscpCombo)
            SwitchConfiguration.aucdscpD1D2[i] = dscpCombo->currentIndex();
    }

}
