/***************************** FILE HEADER *********************************/
/*!
*  \file      lineeditdelegate.cpp
*
*  \brief     This file implements the LineEdit elements in the property table.
*
*  \author    L&T Technology Services Limited
*  \copyright Copyright (c) 2018 Hirschmann Automation & Control GmbH
*
*
*  \version 1a 2018-07-06 Julia Greiss standard header added to file.
*
*//**************************** FILE HEADER *********************************/

/******************************************************************************
 * Includes
 ******************************************************************************/
#include "lineeditdelegate.h"


/******************************************************************************
 * Globals
 ******************************************************************************/
// Table click flag
extern bool boolTableClickflag;

/****************************************************************************************
Function Name			:	LineEditDelegate
Function/DLD ID 		:   SWR_LED_01
Purpose of Function		:   Constructor for lineedit delegate used in Table
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QObject
Return                  :   Void
Remarks                 :
*****************************************************************************************/
LineEditDelegate::LineEditDelegate(QObject *parent)
    : QStyledItemDelegate (parent)
{

}
/****************************************************************************************
Function Name			:	createEditor
Function/DLD ID 		:   SWR_LED_02
Purpose of Function		:   create editor for lind edit
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget, QStyleOptionViewItem, QModelIndex
Return                  :   Void
Remarks                 :
*****************************************************************************************/
QWidget *LineEditDelegate::createEditor(QWidget *parent,
    const QStyleOptionViewItem &/* option */,
    const QModelIndex & QModelIndexIndex) const
{
    QLineEdit *editor = new QLineEdit(parent);

    QRegExp poeClassValidate("[0-4,]{0,9}");
    QRegExpValidator *poeValidator = new QRegExpValidator( poeClassValidate );

    switch(QModelIndexIndex.column())
    {
    case 18:                //ui->lineEdit_allowedPoEClasses
        // Set validator for lineedit
        editor->setValidator(poeValidator);
        //Set lineedit length
        editor->setMaxLength(9);
        break;
    default:
        break;
    }
    connect(editor,SIGNAL(textChanged(QString)),this,SLOT(valueChanged(QString)));

    //To prevent modification when TAB is pressed
    if(boolTableClickflag)
        boolTableClickflag = false;
    return editor;
}
/****************************************************************************************
Function Name			:	setEditorData
Function/DLD ID 		:   SWR_LED_03
Purpose of Function		:   create editor for lind edit
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget, QModelIndex
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void LineEditDelegate::setEditorData(QWidget *QWidgetEditor,
                                    const QModelIndex &QModelIndexIndex) const
{
    QString value = QModelIndexIndex.model()->data(QModelIndexIndex, Qt::EditRole).toString();
    QLineEdit *lineEdit = static_cast<QLineEdit*>(QWidgetEditor);
    lineEdit->setText(value);
}
/****************************************************************************************
Function Name			:	setModelData
Function/DLD ID 		:   SWR_LED_04
Purpose of Function		:   Set model data read from indec
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget, QAbstractItemModel, QModelIndex
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void LineEditDelegate::setModelData(QWidget *QWidgetEditor, QAbstractItemModel *QAbstractItemModelModel,
                                   const QModelIndex &QModelIndexIndex) const
{
    QLineEdit *lineEdit = static_cast<QLineEdit*>(QWidgetEditor);
    if(boolTableClickflag)
    {
        boolTableClickflag = false;
        QAbstractItemModelModel->setData(QModelIndexIndex, lineEdit->text(), Qt::EditRole);
    }
}
/****************************************************************************************
Function Name			:	updateEditorGeometry
Function/DLD ID 		:   SWR_LED_05
Purpose of Function		:   Update lineedit geometry
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget, QStyleOptionViewItem, QModelIndex
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void LineEditDelegate::updateEditorGeometry(QWidget *QWidgetEditor,
    const QStyleOptionViewItem &QStyleOptionViewItemOption, const QModelIndex &/* index */) const
{
    QWidgetEditor->setGeometry(QStyleOptionViewItemOption.rect);
}
/****************************************************************************************
Function Name			:	valueChanged
Function/DLD ID 		:   SWR_LED_06
Purpose of Function		:   Validate, update and emit lineedit value
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QString
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void LineEditDelegate::valueChanged(QString QStringCurrentValue)
{
    QString tempString = QStringCurrentValue;
    unsigned char length = tempString.length();
    QChar  tempChar;
    static QString previousString;
    bool validString = true;
    if(length > 2)
    {
        for(int i = 1; i < (length-1); i= i+2)
        {
            if(tempString.at(i) != ',')
            {
              validString = false;
            }
        }
        if(validString == false)
        {
            tempString = previousString;
        }
    }
    if(length && (validString == true))
    {
        tempChar = tempString.at(length -1);
        if(length > 9)
        {
            tempString.chop(1);
        }
        else
        {
            if((tempChar == '0') || (tempChar == '1') ||(tempChar == '2') ||(tempChar == '3') ||(tempChar == '4'))
            {
                if(length > 1 && ((length %2) == 0))
                {
                    tempString.chop(1);
                    if(!tempString.contains(tempChar))
                        tempString.append(",").append(tempChar);
                    else
                        tempString = previousString;
                }
            }
            else if(tempChar == ',')
            {
                if((length %2) == 0 || (length == 1))
                {
                    tempString.chop(1);
                }
            }
            else
            {
                tempString.chop(1);
            }
        }
        previousString = tempString;
    }
    QLineEdit* line=(QLineEdit*) QObject::sender();
    line->setText(tempString);

    emit currentValueChanged(tempString);
}
