/***************************** FILE HEADER *********************************/
/*!
*  \file      spinboxdelegate.cpp
*
*  \brief     This file implements the SpinBox elements main window in the property table.
*
*  \note
*
*  \author    L&T Technology Services Limited
*  \copyright Copyright (c) 2018 Hirschmann Automation & Control GmbH
*
*
*  \version 1a 2018-07-06 Julia Greiss standard header added to file.
*
*//**************************** FILE HEADER *********************************/

/******************************************************************************
 * Includes
 ******************************************************************************/
#include "spinboxdelegate.h"

/******************************************************************************
 * Globals
 ******************************************************************************/
// Table click flag
extern bool boolTableClickflag;

/****************************************************************************************
Function Name			:	SpinBoxDelegate
Function/DLD ID 		:   SWR_SBD_01
Purpose of Function		:   Constructor for spin box delegate used in Table
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QObject
Return                  :   Void
Remarks                 :
*****************************************************************************************/
SpinBoxDelegate::SpinBoxDelegate(QObject *parent)
    : QStyledItemDelegate(parent)
{
}
/****************************************************************************************
Function Name			:	createEditor
Function/DLD ID 		:   SWR_SBD_02
Purpose of Function		:   create editor for wpin box
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget, QStyleOptionViewItem, QModelIndex
Return                  :   Void
Remarks                 :
*****************************************************************************************/
QWidget *SpinBoxDelegate::createEditor(QWidget *parent,
    const QStyleOptionViewItem &/* option */,
    const QModelIndex &QModelIndexIndex) const
{
    QSpinBox *editor = new QSpinBox(parent);
    switch(QModelIndexIndex.column())
    {
    case 9:                 //ui->spinBox_broadcastStormThreshold
    case 11:                //ui->spinBox_multicastStormThreshold
        editor->setMinimum(0);
        editor->setMaximum(100);
        break;
    case 19:                //ui->spinBox_allowedPoEOverride
        editor->setMinimum(0);
        editor->setMaximum(13);
        break;
    default:
        break;
    }
    connect(editor,SIGNAL(valueChanged(QString)),this,SLOT(valueChanged(QString)));
    //To prevent modification when TAB is pressed
    if(boolTableClickflag)
        boolTableClickflag = false;
    return editor;
}
/****************************************************************************************
Function Name			:	setEditorData
Function/DLD ID 		:   SWR_SBD_03
Purpose of Function		:   Set editor data for spin box
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget, QModelIndex
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void SpinBoxDelegate::setEditorData(QWidget *QWidgetEditor,
                                    const QModelIndex &QModelIndexIndex) const
{
    int value = QModelIndexIndex.model()->data(QModelIndexIndex, Qt::EditRole).toInt();
    QSpinBox *spinBox = static_cast<QSpinBox*>(QWidgetEditor);
    spinBox->setValue(value);
}
/****************************************************************************************
Function Name			:	setModelData
Function/DLD ID 		:   SWR_SBD_04
Purpose of Function		:   Set model data read from index
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget, QAbstractItemModel, QModelIndex
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void SpinBoxDelegate::setModelData(QWidget *QWidgetEditor, QAbstractItemModel *QAbstractItemModelModel,
                                   const QModelIndex &QModelIndexIndex) const
{
    QSpinBox *QSpinBoxSpinBox = static_cast<QSpinBox*>(QWidgetEditor);
    if(boolTableClickflag)
    {
        boolTableClickflag = false;
        QSpinBoxSpinBox->interpretText();
        int value = QSpinBoxSpinBox->value();
        QAbstractItemModelModel->setData(QModelIndexIndex, value, Qt::EditRole);
    }
}
/****************************************************************************************
Function Name			:	updateEditorGeometry
Function/DLD ID 		:   SWR_SBD_05
Purpose of Function		:   Update spinbox geometry
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QWidget, QStyleOptionViewItem, QModelIndex
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void SpinBoxDelegate::updateEditorGeometry(QWidget *QWidgetEditor,
    const QStyleOptionViewItem &QStyleOptionViewItemOption, const QModelIndex &/* index */) const
{
    QWidgetEditor->setGeometry(QStyleOptionViewItemOption.rect);
}
/****************************************************************************************
Function Name			:	valueChanged
Function/DLD ID 		:   SWR_SBD_06
Purpose of Function		:   Emit signal for value change
Author/Date     		: 	<Manu Singh 18\04\15>
Modified by/Date		:
Calls                   :
Inputs                  :   QString
Return                  :   Void
Remarks                 :
*****************************************************************************************/
void SpinBoxDelegate::valueChanged(QString QStringCurrentValue)
{
    emit currentValueChanged(QStringCurrentValue);
}
