/***************************** FILE HEADER *********************************/
/*!
*  \file      mainwindow.cpp
*
*  \brief     This file implements the main window.
*
*  \note
*
*  \author    L&T Technology Services Limited
*  \copyright Copyright (c) 2018 Hirschmann Automation & Control GmbH
*
*
*  \version 1a 2018-07-06 Julia Greiss standard header added to file.
*
*//**************************** FILE HEADER *********************************/

/******************************************************************************
 * Includes
 ******************************************************************************/
#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "ui_dialogconfigid.h"
#include "globaldata.h"
#include "dialogconfigid.h"


#include <QWindow>
#include <QSignalMapper>
#include <QFileDialog>
#include <QMessageBox>

#include <QDate>
#include <QObject>
#include <QBuffer>
#include <QDesktopServices>

#include "portdata.h"
//#include <QWebView>
#include <QDesktopWidget>

/******************************************************************************
 * Globals
 ******************************************************************************/
int CurrentLine;
char special_global_qos_done = 0;

QStringList errorList;
QVariant oldValue;
QString serialNumber;
bool boolTableClickflag;
bool errorcsv;
QString temptext;
static int errorReason;
unsigned char configIdfromcsv;
extern unsigned char prodindex;


bool bConfigFileTypeIsDefault=false;
bool bValidConfigFileTypeRec=false;
configData SwitchConfiguration;
productInfo g_CurrentProductInfo;
defaultdata g_DefaultData;
POEInfo g_POEDataInfo;


/***********************************************************************
Function Name			:   MainWindow
Function/DLD ID 		:   SWR_MW_01
Purpose of Function		:   Display product image
Author/Date     		: 	MANU SINGH - 20/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    CenterOfScreen();
    MainWindowSettings();

    CreateActions();
    CreateMenus();
    ui->menuBar->actions();

    /** Read encrypted client logo and display on MainWindow **/
    readLogo();

    // Updating product selection combobox
    for(int i=0;i< MAX_PRODUCT_NUMBERS;i++ )
        ui->comboBox_productSelection->addItem(stProductData[i].m_qsProductName);
    connect(ui->comboBox_productSelection,SIGNAL(currentIndexChanged(int)),this,SLOT(modelselection(int)));

    //Setting validation for different widget
    validatorSettingForUI();

    // Creating table for 24 ports
    createNewTable(24);

    ui->tableView_portSettings->setFocusPolicy(Qt::ClickFocus);
    ui->tableView_portSettings->setDragEnabled(false);
    ui->tableView_portSettings->setAutoScroll(false);

    // Setting tool tips
    toolTips();
    ui->label_componentId->hide();
    ui->lineEdit_componentId->hide();
    ui->label_fileRelease->hide();
    ui->lineEdit_fileRelease->hide();

    // Setting up tp & fiber ports
    for(int i = 0; i < MAX_NO_OF_PORTS; i++)
    {
        clickQlabelQLabelPort[i] = new clickQlabel(ui->label_productImage);
        clickQlabelQLabelPort[i]->hide();
        QString temp = "<font color='White'>";
        temp.append(QString::number(i+1));
        temp.append("</font>");
        clickQlabelQLabelPort[i]->setFont(QFont("Arial Narrow",8,QFont::Bold));
        clickQlabelQLabelPort[i]->setText(temp);
        clickQlabelQLabelPort[i]->setStyleSheet(STYLESHEET_PORTDEFAULT);
        clickQlabelQLabelPort[i]->setAlignment(Qt::AlignCenter);
        clickQlabelQLabelPort[i]->setGeometry(0,0,MIN_PORT_LABEL_SIZE,MIN_PORT_LABEL_SIZE);
    }

    /** Left Click & Right Click Signal Initilization and Mapping **/
    QSignalMapper* leftclicksignalMapper = new QSignalMapper (this) ;
    QSignalMapper* leftcontrolclicksignalMapper = new QSignalMapper (this) ;
    for(int i= 0;i<MAX_NO_OF_PORTS/*MAX_TP_PORTS*/;i++)
    {
        connect(clickQlabelQLabelPort[i], SIGNAL(leftbuttonclick()), leftclicksignalMapper, SLOT(map())) ;
        leftclicksignalMapper->setMapping (clickQlabelQLabelPort[i], i) ;

        connect(clickQlabelQLabelPort[i], SIGNAL(leftcontrolbuttonclick()), leftcontrolclicksignalMapper, SLOT(map())) ;
        leftcontrolclicksignalMapper->setMapping (clickQlabelQLabelPort[i], i) ;
    }
    connect(leftclicksignalMapper, SIGNAL(mapped(int)), this, SLOT(label_singleclick(int)));
    connect(leftcontrolclicksignalMapper, SIGNAL(mapped(int)), this, SLOT(label_controlclick(int)));

    setupGreyedOutParameters(NO_PORT_SELECTED);

    // Display 1st product on list when software starts
    modelselection(0);

    // Initilizing variables
    siUpdatePara = 0;
    siLanguageSelection = 0;
    boolTableClickflag = false;
    this->setFocus();

    connect(ui->comboBox_adminState,SIGNAL(activated(int)),this,SLOT(on_comboBox_adminState_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_alarmLink,SIGNAL(activated(int)),this,SLOT(on_comboBox_alarmLink_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_speed,SIGNAL(activated(int)),this,SLOT(on_comboBox_speed_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_autoNeg,SIGNAL(activated(int)),this,SLOT(on_comboBox_autoNeg_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_autoCrossing,SIGNAL(activated(int)),this,SLOT(on_comboBox_autoCrossing_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_duplexMode,SIGNAL(activated(int)),this,SLOT(on_comboBox_duplexMode_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_mdiState,SIGNAL(activated(int)),this,SLOT(on_comboBox_mdiState_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_flowControl,SIGNAL(activated(int)),this,SLOT(on_comboBox_flowControl_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_broadcastStormProtection,SIGNAL(activated(int)),this,SLOT(on_comboBox_broadcastStormProtection_currentIndexChanged(int)),Qt::UniqueConnection);

    connect(ui->comboBox_multicastStormProtection,SIGNAL(activated(int)),this,SLOT(on_comboBox_multicastStormProtection_currentIndexChanged(int)),Qt::UniqueConnection);

    connect(ui->comboBox_jumboFrames,SIGNAL(activated(int)),this,SLOT(on_comboBox_jumboFrames_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_qosTrustMode,SIGNAL(activated(int)),this,SLOT(on_comboBox_qosTrustMode_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_portpriority,SIGNAL(activated(int)),this,SLOT(on_comboBox_portpriority_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_eee,SIGNAL(activated(int)),this,SLOT(on_comboBox_eee_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_poeAdminState,SIGNAL(activated(int)),this,SLOT(on_comboBox_poeAdminState_currentIndexChanged(int)),Qt::UniqueConnection);
    connect(ui->comboBox_poePriority,SIGNAL(activated(int)),this,SLOT(on_comboBox_poePriority_currentIndexChanged(int)),Qt::UniqueConnection);
}

/***********************************************************************
Function Name			:	MainWindow::toolTips
Function/DLD ID 		:   SWR_MW_02
Purpose of Function		:   Set tool tips
Author/Date     		: 	MANU SINGH - 01/05/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :   MainWindow
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::toolTips()
{
    ui->comboBox_productSelection->setToolTip(TT_PRODUCTSELECTION);
    ui->lineEdit_componentId->setToolTip(TT_COMPONENTID);
    ui->lineEdit_serialFix->setToolTip(TT_SERIALFIX);
    ui->lineEdit_serialNumber->setToolTip(TT_SERIALNUMBER);
    ui->lineEdit_fileRelease->setToolTip(TT_FILERELEASE);
    ui->lineEdit_contactName->setToolTip(TT_CONTACTNAME);
    ui->lineEdit_location->setToolTip(TT_LOCATION);
    ui->comboBox_psuAlarm1->setToolTip(TT_PSUALARM1);
    ui->comboBox_psuAlarm2->setToolTip(TT_PSUALARM2);
    ui->lineEdit_agingTime->setToolTip(TT_AGEINGTIME);
    ui->pushButton_qosPMapping->setToolTip(TT_QOSMAPPING);
    ui->pushButton_qosDscpMapping->setToolTip(TT_QOSDSCPMAPPING);
    ui->comboBox_adminState->setToolTip(TT_ADMINSTATE);
    ui->comboBox_alarmLink->setToolTip(TT_ADMINLINK);
    ui->comboBox_speed->setToolTip(TT_SPEED);
    ui->comboBox_autoNeg->setToolTip(TT_AUTONEG);
    ui->comboBox_autoCrossing->setToolTip(TT_AUTOCROSSING);
    ui->comboBox_duplexMode->setToolTip(TT_DUPLEXMODE);
    ui->comboBox_flowControl->setToolTip(TT_FLOWCONTROL);
    ui->comboBox_broadcastStormProtection->setToolTip(TT_BCPROTECTION);
    ui->spinBox_broadcastStormThreshold->setToolTip(TT_BCTHRESHOLD);
    ui->comboBox_multicastStormProtection->setToolTip(TT_MCPROTECTION);
    ui->spinBox_multicastStormThreshold->setToolTip(TT_MCTHRESHOLD);
    ui->comboBox_jumboFrames->setToolTip(TT_JUMBOFRAME);
    ui->comboBox_qosTrustMode->setToolTip(TT_QOSTRUST);
    ui->comboBox_portpriority->setToolTip(TT_PORTPRIORITY);
    ui->comboBox_eee->setToolTip(TT_EEE);
    ui->comboBox_poeAdminState->setToolTip(TT_POEADMINSTATE);
    ui->comboBox_poePriority->setToolTip(TT_POEPRIORITY);
    ui->lineEdit_allowedPoEClasses->setToolTip(TT_ALLOWEDPOE);
    ui->radioButton_deselectAll->setToolTip(TT_SELECTALL);
    ui->comboBox_mdiState->setToolTip(TT_DESELECTALL);
    ui->spinBox_allowedPoEOverride->setToolTip(TT_OVERRIDEPOE);
}
/***********************************************************************
Function Name			:	MainWindow::CenterOfScreen
Function/DLD ID 		:   SWR_MW_03
Purpose of Function		:   Relocate application to center of the screen
Author/Date     		: 	MANU SINGH - 15/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :   MainWindow
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::CenterOfScreen()
{
    QDesktopWidget QDesktopWidgetScreen;
    QRect QRectScreenGeom = QDesktopWidgetScreen.screenGeometry(this);
    int siScreenCenterX = QRectScreenGeom.center().x();
    int siScreenCenterY = QRectScreenGeom.center().y();
    move(siScreenCenterX - width () / 2,siScreenCenterY - height() / 2);
}
/***********************************************************************
Function Name			:	MainWindow::displayProductImage
Function/DLD ID         :   SWR_MW_04
Purpose of Function		:   Display product image
Author/Date     		: 	MANU SINGH - 20/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :   MainWindow
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::displayProductImage(int siIndex)
{
    QPixmap productImage(stProductData[siIndex].productImagePath);
    ui->label_productImage->setPixmap(productImage.scaled(600,300, Qt::KeepAspectRatio));
    ui->label_productImage->setStyleSheet(STYLESHEET_TRASPARENT);
    ui->label_productImage->show();
}
/***********************************************************************
Function Name			:	MainWindow::MainWindowSettings()
Function/DLD ID         :   SWR_MW_05
Purpose of Function		:   Initilize main window
Author/Date     		: 	MANU SINGH - 20/03/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :   MainWindow
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::MainWindowSettings()
{
    /** Setting of Icon **/
    QPixmap QPixmapIcon(QString().append(":/Image/").append(ICON_FILE_NAME));
    this->setWindowIcon(QPixmapIcon.scaled(20,20));

    this->setWindowTitle(APPLICATION_SOFTWARE_NAME);

    QPalette QPalettePal = this->palette();
    QPalettePal.setColor(QPalette::Window, SOFTWARE_BACKGROUND);
    this->setPalette(QPalettePal);

    ui->label_productImage->setAlignment(Qt::AlignCenter);
    ui->groupBox_productOutline->hide();

    QString border = "QGroupBox{border: 2px solid ";
    ui->groupBox_sketch->setStyleSheet(border + SKETCH_BORDER_COLOR + ";}");

    ui->gridGroupBox->setStyleSheet(STYLESHEET_GROUPBOX);
    ui->groupBox_globalParameters->setStyleSheet(STYLESHEET_GROUPBOX);
    ui->groupBox_configurePortParameters->setStyleSheet(STYLESHEET_GROUPBOX);
    ui->groupBox_portSettings->setStyleSheet(STYLESHEET_GROUPBOX);

    ui->groupBox_sketch->setStyleSheet(STYLESHEET_PRODUCTIMAGE);

    ui->lineEdit_serialFix->setDisabled(true);

    ui->radioButton_selectAll->setStyleSheet(STYLESHEET_RADIOBUTTON);
    ui->radioButton_deselectAll->setStyleSheet(STYLESHEET_RADIOBUTTON);
    ui->label_selectAll->setStyleSheet(STYLESHEET_TRASPARENT);
    ui->label_deselectAll->setStyleSheet(STYLESHEET_TRASPARENT);

    boolCtrlFlag = false;


#if LINUX
    ui->label->setMinimumSize(155,20);
    ui->label->setMaximumSize(155,16777215);
    ui->label_2->setMinimumSize(155,20);
    ui->label_2->setMaximumSize(155,16777215);

    ui->lineEdit_serialFix->setMinimumSize(80,20);
    ui->lineEdit_serialFix->setMinimumSize(80,16777215);
    ui->lineEdit_serialFix->setMaximumSize(80,20);
    ui->lineEdit_serialFix->setMaximumSize(80,16777215);
#endif

}
/***********************************************************************
Function Name			:	MainWindow::CreateActions()
Function/DLD ID         :   SWR_MW_06
Purpose of Function		:   Create actions for menu items
Author/Date     		: 	MANU SINGH - 20/04/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :   MainWindow
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::CreateActions()
{
    QActionNewAct = new QAction(tr("&New"), this);
    QActionNewAct->setShortcuts(QKeySequence::New);
    QActionNewAct->setStatusTip(tr("Create a new file"));
    connect(QActionNewAct, SIGNAL(triggered()), this, SLOT(newFile()), Qt::UniqueConnection);

    QActionLoadAct = new QAction(tr("&Open"), this);
    QActionLoadAct->setShortcuts(QKeySequence::Open);
    QActionLoadAct->setStatusTip(tr("Open an existing file"));
    connect(QActionLoadAct, SIGNAL(triggered()), this, SLOT(open()), Qt::UniqueConnection);

    QActionSaveAct = new QAction(tr("&Save"), this);
    QActionSaveAct->setShortcuts(QKeySequence::Save);
    QActionSaveAct->setStatusTip(tr("Save the document to disk"));
    connect(QActionSaveAct, SIGNAL(triggered()), this, SLOT(save()), Qt::UniqueConnection);

    QActionSaveAsAct = new QAction(tr("&SaveAs"), this);
    QActionSaveAsAct->setShortcuts(QKeySequence::SaveAs);
    QActionSaveAsAct->setStatusTip(tr("SaveAs the document"));
    connect(QActionSaveAsAct, SIGNAL(triggered()), this, SLOT(saveAs()), Qt::UniqueConnection);

    QActionSaveToUsbAct = new QAction(tr("&Save to USB"), this);
    QActionSaveToUsbAct->setShortcuts(QKeySequence::SaveAs);
    QActionSaveToUsbAct->setStatusTip(tr("Save to USb the document"));
    connect(QActionSaveToUsbAct, SIGNAL(triggered()), this, SLOT(saveToUsb()), Qt::UniqueConnection);

    QActionExitAct = new QAction(tr("E&xit"), this);
    QActionExitAct->setShortcuts(QKeySequence::Quit);
    QActionExitAct->setStatusTip(tr("Exit the application"));
    connect(QActionExitAct, SIGNAL(triggered()), this, SLOT(exit()), Qt::UniqueConnection);

    QActionExportAct = new QAction(tr("&Export"), this);
    QActionExportAct->setStatusTip(tr("Export"));
    connect(QActionExportAct, SIGNAL(triggered()), this, SLOT(exportReport()), Qt::UniqueConnection);

    QActionEngLanAct = new QAction(tr("&English"), this);
    QActionEngLanAct->setCheckable(true);
    QActionEngLanAct->setChecked(true);
    QActionEngLanAct->setStatusTip(tr(""));
    connect(QActionEngLanAct, SIGNAL(triggered()), this, SLOT(engLan()), Qt::UniqueConnection);

    QActionGerLanAct = new QAction(tr("&German"), this);
    QActionGerLanAct->setCheckable(true);
    QActionGerLanAct->setChecked(false);
    QActionGerLanAct->setStatusTip(tr(""));
    connect(QActionGerLanAct, SIGNAL(triggered()), this, SLOT(gerLan()), Qt::UniqueConnection);

    QActionOnlineHelpAct = new QAction(tr("&Online Help"), this);
    QActionOnlineHelpAct->setShortcuts(QKeySequence::HelpContents);
    QActionOnlineHelpAct->setStatusTip(tr("Online Help"));
    connect(QActionOnlineHelpAct, SIGNAL(triggered()), this, SLOT(onlineHelp()), Qt::UniqueConnection);

    QActionWebSiteAct = new QAction(tr("Webs&ite"), this);
    QActionWebSiteAct->setStatusTip(tr("Open website"));
    connect(QActionWebSiteAct, SIGNAL(triggered()), this, SLOT(webSite()), Qt::UniqueConnection);

    QActionAboutAct = new QAction(tr("&About"), this);
    QActionAboutAct->setStatusTip(tr("Show the application's About box"));
    connect(QActionAboutAct, SIGNAL(triggered()), this, SLOT(about()), Qt::UniqueConnection);

}
/***********************************************************************
Function Name			:	MainWindow::CreateMenus()
Function/DLD ID         :   SWR_MW_07
Purpose of Function		:   Create menu items in menu bar
Author/Date     		: 	MANU SINGH - 20/04/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :   MainWindow
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::CreateMenus()
{
    QMenuFileMenu = menuBar()->addMenu(tr("&File"));
    QMenuFileMenu->addAction(QActionNewAct);
    QMenuFileMenu->addAction(QActionLoadAct);
    QMenuFileMenu->addAction(QActionSaveAct);
    QMenuFileMenu->addAction(QActionSaveAsAct);
    //QMenuFileMenu->addAction(QActionSaveToUsbAct);
    QMenuFileMenu->addAction(QActionExitAct);

    QMenuDocumentationMenu = menuBar()->addMenu(tr("&Documentation"));
    QMenuDocumentationMenu->addAction(QActionExportAct);

    QMenuLanguageMenu = new QMenu(tr("&Language"));
    QMenuLanguageMenu->addAction(QActionEngLanAct);
    QMenuLanguageMenu->addAction(QActionGerLanAct);

    QMenuHelpMenu = menuBar()->addMenu(tr("&Help"));
    QMenuHelpMenu->addMenu(QMenuLanguageMenu);
    QMenuHelpMenu->addAction(QActionOnlineHelpAct);
    QMenuHelpMenu->addAction(QActionWebSiteAct);
    QMenuHelpMenu->addAction(QActionAboutAct);
}
/***********************************************************************
Function Name			:	MainWindow::validatorSettingForUI()
Function/DLD ID         :   SWR_MW_08
Purpose of Function		:   Set validator for UI items
Author/Date     		: 	MANU SINGH - 20/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::validatorSettingForUI()
{
    QRegExp contactNameValidation("[A-Za-z ]{0,40}");
    QRegExpValidator *contactNameValidator = new QRegExpValidator( contactNameValidation, this );
    ui->lineEdit_contactName->setValidator(contactNameValidator);

    QRegExp locationValidation("[0-9A-Za-z ()/-]{0,40}");
    QRegExpValidator *locationValidator = new QRegExpValidator( locationValidation, this );
    ui->lineEdit_location->setValidator(locationValidator);

    QRegExp fileReleaseValidation("[0-9]{1,2}\\.[0-9]{1,1}\\.[0-9]{1,2}"); //"[0-9.]{0,4}"); //
    QRegExpValidator *fileReleaseValidator = new QRegExpValidator( fileReleaseValidation, this );
    ui->lineEdit_fileRelease->setValidator(fileReleaseValidator);

    QRegExp serialNumberValidation("[0-9]{0,9}");
    QRegExpValidator *serialNumberValidator = new QRegExpValidator( serialNumberValidation, this );
    ui->lineEdit_serialNumber->setValidator(serialNumberValidator);

    QRegExp componentIdValidation("[A-Za-z0-9]{0,9}");
    QRegExpValidator *componentIdValidator = new QRegExpValidator( componentIdValidation, this );
    ui->lineEdit_componentId->setValidator(componentIdValidator);


    QRegExp poeClassValidation("[0-4,-]{0,9}");//added "-"
    //QRegExp poeClassValidation("[-]{1,1}");

    QRegExpValidator *poeClassValidator = new QRegExpValidator( poeClassValidation, this );
    ui->lineEdit_allowedPoEClasses->setValidator(poeClassValidator);

    ui->lineEdit_agingTime->setValidator(new QIntValidator(0, 1048575, this));

    ui->spinBox_broadcastStormThreshold->setRange(0,100);
    ui->spinBox_multicastStormThreshold->setRange(0,100);
    ui->spinBox_allowedPoEOverride->setRange(0,13);
}
/***********************************************************************
Function Name			:	MainWindow::readLogo
Function/DLD ID         :   SWR_MW_09
Purpose of Function		:   Read logo file and place on screen
Author/Date     		: 	MANU SINGH - 25/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :   MainWindow
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::readLogo()
{
    QPixmap logo(QString().append(":/Image/").append(LOGO_FILE_NAME));
    ui->label_oemLogo->setFixedSize(150,50);
    ui->label_oemLogo->setPixmap(logo.scaled(150,50,Qt::KeepAspectRatio,Qt::SmoothTransformation));
    ui->label_oemLogo->setStyleSheet(STYLESHEET_TRASPARENT);
}
/***********************************************************************
Function Name			:	MainWindow::~MainWindow
Function/DLD ID         :   SWR_MW_10
Purpose of Function		:   Destructor of main window
Author/Date     		: 	MANU SINGH - 25/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
MainWindow::~MainWindow()
{
    if(ComboBoxDelegateComboBox)
        ComboBoxDelegateComboBox = NULL;
    if(SpinBoxDelegateSpinBox)
        SpinBoxDelegateSpinBox = NULL;
    if(LineEditDelegateLineEdit)
        LineEditDelegateLineEdit = NULL;
    if(ptrDialog8021p)
        ptrDialog8021p = NULL;
    if(ptrDialogdscp)
        ptrDialogdscp = NULL;
    if(ptrDialogErrorLog)
        ptrDialogErrorLog = NULL;
    if(ptrAbout)
        ptrAbout = NULL;
    if(QMenuFileMenu)
        QMenuFileMenu = NULL;
    if(QMenuSettingsMenu)
        QMenuSettingsMenu = NULL;
    if(QMenuDocumentationMenu)
        QMenuDocumentationMenu = NULL;
    if(QMenuHelpMenu)
        QMenuHelpMenu = NULL;
    if(QMenuLanguageMenu)
        QMenuLanguageMenu = NULL;
    if(QActionGroupAlignmentGroup)
        QActionGroupAlignmentGroup = NULL;
    if(QActionNewAct)
        QActionNewAct = NULL;
    if(QActionLoadAct)
        QActionLoadAct = NULL;
    if(QActionSaveAct)
        QActionSaveAct = NULL;
    if(QActionSaveAsAct)
        QActionSaveAsAct = NULL;
    if(QActionSaveToUsbAct)
        QActionSaveToUsbAct = NULL;
    if(QActionExitAct)
        QActionExitAct = NULL;
    if(QActionExportAct)
        QActionExportAct = NULL;
    if(QActionEngLanAct)
        QActionEngLanAct = NULL;
    if(QActionGerLanAct)
        QActionGerLanAct = NULL;
    if(QActionOnlineHelpAct)
        QActionOnlineHelpAct = NULL;
    if(QActionWebSiteAct)
        QActionWebSiteAct = NULL;
    if(QActionAboutAct)
        QActionAboutAct = NULL;
    if(QStandardItemModelModels)
        QStandardItemModelModels = NULL;

    delete ui;
}
/***********************************************************************
Function Name			:	MainWindow::label_singleclick(int label_number)
Function/DLD ID         :   SWR_MW_11
Purpose of Function		:   Detect when port is selected
Author/Date     		: 	MANU SINGH - 27/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :	label_number
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::label_singleclick(int siLabel_number)
{
    this->setFocus();
    if(siLabel_number >= g_CurrentProductInfo.m_ucnoOfPort)
        return;

    QString str2 = clickQlabelQLabelPort[siLabel_number]->styleSheet();
    if(str2.contains("1px"))
    {
        if(siLabel_number < MAX_NO_OF_PORTS)
        {
            portUpdate(siLabel_number);
        }
    }
    else
    {
        if(siLabel_number < MAX_NO_OF_PORTS)
        {
            clearPortBorder();
            radioDeselectAll(true);
            setupGreyedOutParameters(NO_PORT_SELECTED);
        }
        if(ui->radioButton_selectAll->isChecked())
        {
            radioDeselectAll(false);
            radioSelectAll(false);
            label_singleclick(siLabel_number);
        }
    }
}
/***********************************************************************
Function Name			:	MainWindow::clearPortBorder()
Function/DLD ID         :   SWR_MW_12
Purpose of Function		:   Clear the selected porst
Author/Date     		: 	MANU SINGH - 27/03/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :
Return                  :
Remarks                 :   Clear border of all ports
************************************************************************/
void MainWindow::clearPortBorder()
{
    for(int i = 0;i<MAX_NO_OF_PORTS;i++)
        clickQlabelQLabelPort[i]->setStyleSheet(STYLESHEET_PORTDEFAULT);
}
/***********************************************************************
Function Name			:	MainWindow::label_controlclick(int label_number)
Function/DLD ID         :   SWR_MW_13
Purpose of Function		:   Detect and do settings on control+mouse click
Author/Date     		: 	MANU SINGH - 27/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :	label_number
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::label_controlclick(int siLabel_number)
{
    if(siLabel_number >= g_CurrentProductInfo.m_ucnoOfPort)
        return;

    int oldporttype = 0;
    for(int i=0;i<MAX_NO_OF_PORTS;i++)
    {
        QString l_strlabelport = clickQlabelQLabelPort[i]->styleSheet();
        if(l_strlabelport.contains("2px"))
            oldporttype = checkTypeofPort(i);
    }
    int newporttype = checkTypeofPort(siLabel_number);

    // When ctrl is pressed and no other port is selected then need to do manupulation
    if(oldporttype == 0)
    {
        oldporttype = newporttype;
        setupGreyedOutParameters(checkTypeofPort(siLabel_number));
    }
    /** End Verify once again Modified on 08/05/2015 **/
    QString l_strlabelport2 = clickQlabelQLabelPort[siLabel_number]->styleSheet();
    if(newporttype == oldporttype)
    {
        // De-selection of ports
        if(l_strlabelport2.contains("2px"))
            clickQlabelQLabelPort[siLabel_number]->setStyleSheet(STYLESHEET_PORTDEFAULT);
        else
            clickQlabelQLabelPort[siLabel_number]->setStyleSheet(STYLESHEET_PORTSELECT);
    }

    unsigned char flagSelectAll;
    unsigned char flagDeSelectAll = 1;
    flagSelectAll = true;

    for(int i=0;i<(g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
    {
        QString l_strlabelport = clickQlabelQLabelPort[i]->styleSheet();
        if(l_strlabelport.contains("1px"))
        {
            flagSelectAll = 0;
        }
    }
    if(flagSelectAll)
    {
        radioSelectAll(true);
    }
    else
    {
        radioSelectAll(false);
    }

    for(int i=0;i<(g_CurrentProductInfo.m_ucnoOfPort);i++)
    {
        QString l_strlabelport = clickQlabelQLabelPort[i]->styleSheet();
        if(l_strlabelport.contains("2px"))
        {
            flagDeSelectAll = 0;
        }
    }
    if(flagDeSelectAll==1)
    {
        radioDeselectAll(true);
        setupGreyedOutParameters(NO_PORT_SELECTED);
    }
    else
    {
        radioDeselectAll(false);
    }
}
/***********************************************************************
Function Name			:	MainWindow::checkTypeofPort(int label_number)
Function/DLD ID         :   SWR_MW_14
Purpose of Function		:
Author/Date     		: 	MANU SINGH - 20/04/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :	label_number
Return                  :   SELECTED_PORT_TYPE
Remarks                 :   Check type of port(TP or Fiber)
************************************************************************/
SELECTED_PORT_TYPE MainWindow::checkTypeofPort(int siLabel_number)
{
    int no_of_port = stProductData[ui->comboBox_productSelection->currentIndex()].m_ucNumberOfPorts;
    int no_of_fiber = stProductData[ui->comboBox_productSelection->currentIndex()].m_ucNumberOfFiberPorts;
    SELECTED_PORT_TYPE portType = NO_PORT_SELECTED;

    if((siLabel_number >= 0) && (siLabel_number < (no_of_port-no_of_fiber)))
    {
        if(g_CurrentProductInfo.m_ucproductLine & PRODUCT_LINE_PL)
        {
            if(g_CurrentProductInfo.m_ucproductType & PRODUCT_TYPE_FE)
                portType = TP_FE_PORT_SELECTED;
            else if(g_CurrentProductInfo.m_ucproductType & PRODUCT_TYPE_GE)
                portType = TP_GE_PORT_SELECTED;

        }
        if(g_CurrentProductInfo.m_ucproductLine & PRODUCT_LINE_POE)
        {
            if(g_CurrentProductInfo.m_ucproductType & PRODUCT_TYPE_FE)
            {
                //qDebug() << "Total TP Port " << no_of_port-no_of_fiber;
                if(((no_of_port-no_of_fiber) == 5)&&(siLabel_number == 4))
                    portType = TP_FE_PORT_SELECTED;
                else
                    portType = TP_FE_POE_PORT_SELECTED;
            }
            else if(g_CurrentProductInfo.m_ucproductType & PRODUCT_TYPE_GE)
            {
                if(((no_of_port-no_of_fiber) == 5)&&(siLabel_number == 4))
                    portType = TP_GE_PORT_SELECTED;
                else
                    portType = TP_GE_POE_PORT_SELECTED;
            }

            if(g_CurrentProductInfo.m_ucproductId == 101)   //Octopus 8Tx PoE: Port1 is no PoE Port
            {
                if(!siLabel_number)     //siLabel_number = 0 means Port1
                    portType = TP_FE_PORT_SELECTED;
            }
        }
    }
    else if(siLabel_number < no_of_port )
    {
        //portType = FIBER_FE_PORT_SELECTED;
        if(g_CurrentProductInfo.m_ucproductType & PRODUCT_TYPE_FE)
        {
            portType = FIBER_FE_PORT_SELECTED;
        }
        else if(g_CurrentProductInfo.m_ucproductType & PRODUCT_TYPE_GE)
        {
            portType = FIBER_GE_PORT_SELECTED;
        }
    }
    else
    {
        //qDebug() << "Wrong Lable Clicked: " << label_number;
        portType = NO_PORT_SELECTED;
    }

    //qDebug() << "Port No : " <<label_number << " return :" << portType;
    return portType;
}
/***********************************************************************
Function Name			:	MainWindow::setActive()
Function/DLD ID         :   SWR_MW_15
Purpose of Function		:   Set main window as active window
Author/Date     		: 	MANU SINGH - 27/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::setActive()
{
    this->activateWindow();
}

/***********************************************************************
Function Name			:	MainWindow::modelselection(int index)
Function/DLD ID         :   SWR_MW_16
Purpose of Function		:   Selection of product
Author/Date     		: 	MANU SINGH - 27/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :	Selected product model index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::modelselection(int siIndex)
{
    boolErrorLog = 0;
    CurrentLine = 0;

    g_CurrentProductInfo.m_ucproductLine = stProductData[siIndex].m_ucProductLine;
    g_CurrentProductInfo.m_ucproductType = stProductData[siIndex].m_ucProductType;

    g_CurrentProductInfo.m_ucnoOfFiberPort = stProductData[siIndex].m_ucNumberOfFiberPorts;
    g_CurrentProductInfo.m_ucnoOfPort = stProductData[siIndex].m_ucNumberOfPorts;

    ui->lineEdit_contactName->setText("");
    ui->lineEdit_location->setText("");
    ui->lineEdit_fileRelease->setText("");
    ui->lineEdit_componentId->setText("");
    ui->lineEdit_serialNumber->setText("");

    g_CurrentProductInfo.m_ucproductId = stProductData[siIndex].m_ucProductId;
    SwitchConfiguration.aucproductid = stProductData[siIndex].m_ucProductId;

    for(int i=0; i<MAX_NO_OF_PORTS;i++)
        clickQlabelQLabelPort[i]->hide();

    for(int i=0;i<(stProductData[siIndex].m_ucNumberOfPorts);i++)
    {
        clickQlabelQLabelPort[i]->setGeometry(stProductData[siIndex].m_oQRectPortGeometry[i]);
        clickQlabelQLabelPort[i]->setStyleSheet(STYLESHEET_PORTDEFAULT);
        clickQlabelQLabelPort[i]->show();
    }

    radioSelectAll(false);
    radioDeselectAll(true);
    createNewTable(g_CurrentProductInfo.m_ucnoOfPort);
    displayProductImage(siIndex);

    serialNumber.clear();
    ui->lineEdit_serialFix->setText(fix_serial[siIndex]);
    serialNumber.append(ui->lineEdit_serialFix->text()).append("-");

    updateBufferfromDefault();
    updateGlobalParaUserInterface();
    updatePortTableUserInterface();
    label_singleclick(0);
    label_singleclick(0);
    setupGreyedOutParameters(NO_PORT_SELECTED);

    if(g_CurrentProductInfo.m_ucproductId == 101)
    {
        ui->label_selectAll->setText("Select All\n PoE Ports");
        ui->label_deselectAll->setText("Deselect All\n PoE Ports");
        ui->label_allowedPoEOverride_info->setVisible(true);
        ui->label_allowedPoEOverride_info2->setVisible(true);
        ui->toolButton_allowedPoEOverride_info->setVisible(true);
        ui->toolButton_allowedPoEOverride_info->setEnabled(true);
    }
    else
    {
        ui->label_selectAll->setText("Select All\n TP Ports");
        ui->label_deselectAll->setText("Deselect All\n TP Ports");
    }


}
/***********************************************************************
Function Name			:	MainWindow::readCSVFile(QString filename)
Function/DLD ID         :   SWR_MW_17
Purpose of Function		:   read CSV file
Author/Date     		: 	MANU SINGH - 27/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :	Qstring
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::readCSVFile(QString QStringFilename)
{
    //qDebug() << filename;
    QFile file(QStringFilename);

    // Read product id first which can be anywhere in CSV file
    if (file.open(QIODevice::ReadOnly | QIODevice::Text))
    {
        special_global_qos_done = 0;
        int productIdFlag = 0;
        while(!file.atEnd())
        {
            QString line = file.readLine();
            if(line.contains("file.configID"))
            {
                QStringList temp = line.split(",");
                for(int i=0;i<MAX_PRODUCT_NUMBERS;i++)
                {
                    if(stProductData[i].m_ucProductId == temp[2].toInt())
                    {
                        productIdFlag = 1;
                        onOpencsvfileCsvpopup(temp[2].toInt());
                        ui->comboBox_productSelection->setCurrentIndex(i+prodindex);
                        break;
                    }
                }
            }

        }
        file.close();
        if(productIdFlag == 0)
            return;
    }

    //qDebug() << "Reopen";
    updateBufferfromDefault();
    CurrentLine = 0;
    if (file.open(QIODevice::ReadOnly | QIODevice::Text))
    {
        errorList.clear();
        while (!file.atEnd())
        {
            QString line = file.readLine();
            // qDebug() <<"Line:" <<line;
            processLineFromCSV(line);
            ++CurrentLine;
        }
        file.close();

    }
    else
        qDebug() << "Error in file opening";

    displayErrorLog();
}
/***********************************************************************
Function Name			:	ValidateFileLine (char  *punParameter, char  *pucIndex, char  *pucValue)
Function/DLD ID         :   SWR_MW_75
Purpose of Function		:   Validate parameters
Author/Date     		: 	ANKIT C
Modified by/Date		:	MANU SINGH - 27/04/2015
Calls                   :
Inputs                  :	Parameter,Index, Value
Return                  :
Remarks                 :
************************************************************************/
bool ValidateFileLine (char  *punParameter, char  *pucIndex, char  *pucValue)
{
    bool bRetValue;

    /* Search for the given string in punParameter */
    bRetValue = false;
    unsigned char ucIndex;
    unsigned char  ucMinValue, ucMinIndex,ucRecdIndex;
    unsigned int ucMaxValue, ucMaxIndex, ucRecdValue;

    /*check whether the parameter field is matching with any of the field of validate structure*/
    for(ucIndex = 0; ucIndex< MAX_ENTRIES_VALIDATE_CONFIG; ++ucIndex)
    {
        if(strcmp(punParameter,validateConfigDB[ucIndex].pucconfigParameter) == 0)
        {
            //qDebug() <<"Valid Parameter == " << punParameter << ":" << pucIndex << ":" << pucValue;
            if(validateConfigDB[ucIndex].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
            {
                //qDebug() <<"Valid Line;
                if(validateConfigDB[ucIndex].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
                {
                    //qDebug() << "Valid Type :" << punParameter;
                    /** new **/
                    if((validateConfigDB[ucIndex].flags & FILE_VALID_FLAG_IS_STRING) && strcmp(punParameter,"port.poe.allowed-classes"))
                    {
                        if(!atoi(pucIndex))
                        {
                            bRetValue = true;
                            return bRetValue;
                        }
                    }
                    /** end new **/

                    /* Check to see if the value is depending on no. of ports if yes then max index value will depend on
                    no of ports*/
                    if(validateConfigDB[ucIndex].ucDependsOnProductId == 1)
                    {
                        ucMinIndex = validateConfigDB[ucIndex].ucMinIndex;
                        ucMaxIndex = g_CurrentProductInfo.m_ucnoOfPort;
                    }
                    else
                    {
                        ucMinIndex = validateConfigDB[ucIndex].ucMinIndex;
                        ucMaxIndex = validateConfigDB[ucIndex].ucMaxIndex;
                    }

                    ucMinValue = validateConfigDB[ucIndex].ucMinValue;
                    ucMaxValue = validateConfigDB[ucIndex].ucMaxValue;

                    /** new **/
                    /*check if any of the field is not present */
                    if(!strlen(pucIndex) || !strlen(pucValue))
                    {
                        bRetValue = false;
                        errorReason = 4;
                        //qDebug() << "ret from In & Val";
                        return bRetValue;
                    }

                    /** check wherther index and value are numeric or not **/

                    /** end new **/
                    if((validateConfigDB[ucIndex].flags & FILE_VALID_FLAG_IS_STRING) == 0)
                    {
                        // Assuming index and value are numeric
                        bool ok;
                        QString index = QString::fromLatin1(pucIndex);
                        ucRecdIndex = (unsigned char)index.toInt(&ok);
                        if(!ok || (index.length()>2))
                        {
                            errorReason = 4;
                            //qDebug() << "ret from In";
                            return false;
                        }

                        QString value = QString::fromLatin1(pucValue);
                        ucRecdValue = (unsigned char)value.toInt(&ok);
                        if(!ok)
                        {
                            errorReason = 5;
                            //qDebug() << "ret from Val";
                            return false;
                        }

                        //qDebug() << punParameter << " - " << value.length();
                        if((ucMaxValue<9)&&(value.length()>2))
                        {
                            errorReason = 5;
                            //qDebug() << "ret from Val2";
                            return false;
                        }

                        if((ucMaxValue<=100)&&(value.length()>4))
                        {
                            errorReason =5;
                            //qDebug() << "ret from Val3";
                            return false;
                        }

                        if((ucMaxValue<=1048575)&&(value.length()>8))
                        {
                            errorReason = 5;
                            //qDebug() << "ret from Val4";
                            return false;
                        }

                        /* Check for index */
                        if(ucRecdIndex >= ucMinIndex && ucRecdIndex<= ucMaxIndex)
                        {
                            if(ucRecdValue >= ucMinValue && ucRecdValue <= ucMaxValue)
                            {
                                bRetValue = true;
                            }
                        }
                    }
                    else if((validateConfigDB[ucIndex].flags & FILE_VALID_FLAG_IS_STRING))
                    {
                        if(!strcmp(punParameter,"port.poe.allowed-classes"))
                        {
                            QString temp;
                            temp = QString(pucValue);
                            if((temp.length()-1)>5)
                            {
                                errorReason = 5;
                                //qDebug() << "ret from Val5";
                                return false;
                            }
                            for(int k=0;k<(temp.length()-1);k++)
                            {
                                if(((temp.at(k).digitValue() >=0)&&(temp.at(k).digitValue() <= 4)))
                                    bRetValue = true;
                                else
                                {
                                    errorReason = 5;
                                    //qDebug() << "ret from Val6";
                                    bRetValue = false;
                                }
                            }
                        }
                    }
                }
                else
                {
                    //qDebug() << "ret from Type";
                    errorReason = 3; //Product Type
                }
            }
            else
            {
                //qDebug() << "ret from Line";
                errorReason = 2; //Product Line
            }
        }
        else
        {
            //qDebug() <<"Invalid - " << punParameter << ":" << validateConfigDB[ucIndex].pucconfigParameter;
            //qDebug() << "ret from name";
        }
    }
    return bRetValue;
}
/***********************************************************************
Function Name			:	checkConfigFileType (char  *pucParameter)
Function/DLD ID         :   SWR_MW_76
Purpose of Function		:   Check configuration file type
Author/Date     		: 	ANKIT C
Modified by/Date		:
Calls                   :
Inputs                  :	Parameter
Return                  :
Remarks                 :
************************************************************************/
bool checkConfigFileType (char  *pucParameter)
{
    bool bRetValue = false;
    if(atoi(pucParameter) != 0)
        bRetValue = true;
    return bRetValue;
}
/***********************************************************************
Function Name			:	StoreConfigurationParameterValueInBuffer (char *pucParameter, char *pucIndex, char *pucValue, configData* configDataRamBuffer)
Function/DLD ID         :   SWR_MW_77
Purpose of Function		:
Author/Date     		: 	ANKIT C
Modified by/Date		:
Calls                   :
Inputs                  :	char *pucParameter, char *pucIndex, char *pucValue, configData* configDataRamBuffer)
Return                  :
Remarks                 :
************************************************************************/
// NOT reading New parameters added in CSV file
void StoreConfigurationParameterValueInBuffer (char *pucParameter, char *pucIndex, char *pucValue, configData* configDataRamBuffer)
{
    unsigned char ucIndex, unSrcIndex, i;
    unsigned char *Dest;
    unsigned int unSrcValue=0;
    unsigned int unJumpAddr;
    int decreaseIndex=0;

    /* Check whether the parameter is applicable to this product */
    for(ucIndex = 0; ucIndex< MAX_ENTRIES_VALIDATE_CONFIG; ++ucIndex)
    {
        if(strcmp(pucParameter,validateConfigDB[ucIndex].pucconfigParameter) == 0)
        {
            if(validateConfigDB[ucIndex].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
            {
                if(validateConfigDB[ucIndex].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
                {
                    Dest = (unsigned char *)configDataRamBuffer;

                    /*identify the config structure member where the specific parameter
                    should be stored*/
                    unJumpAddr = validateConfigDB[ucIndex].ucOffsetOfParaInConfigStruct;

                    /* find out if we have to decrease the index by one element size */
                    decreaseIndex = (validateConfigDB[ucIndex].ucMakeIndexMinus1 != 0);

                    /* Check if its a port type, if not we can store right away */
                    if(strcmp(pucParameter, "port.poe.allowed-classes") || ((validateConfigDB[ucIndex].flags & FILE_VALID_FLAG_SPECIAL_QOS_PORT)!=0))
                    {
                        unSrcIndex = atoi(pucIndex);
                        unSrcValue = atoi(pucValue);
                        /*the aging time, vlan ID and poe override value take the value more than 256 */

                        if(strcmp(pucParameter,"switch.aging-time") == 0)
                        {
                            configDataRamBuffer->agingTime = unSrcValue;
                        }
                        else if(strcmp(pucParameter,"port.vlan.id") == 0)
                        {
                            configDataRamBuffer->aucportVLANID[unSrcIndex - decreaseIndex] = unSrcValue;
                        }
                        else if(strcmp(pucParameter,"port.poe.override") == 0)
                        {
                            configDataRamBuffer->aucpoeAllowedConsumptionOverride[unSrcIndex - decreaseIndex] = unSrcValue;
                        }
                        //Fixing Appearance when importing a csv. When Autoneg is enabled "-" has to show.
                        else if(strcmp(pucParameter,"port.speed") == 0)
                        {
                            if(SwitchConfiguration.aucautonegStatus[unSrcIndex - decreaseIndex] == 1)
                            {
                               *(Dest + unJumpAddr + unSrcIndex - decreaseIndex) = (uint8_t)unSrcValue+1;
                            }
                            else
                                *(Dest + unJumpAddr + unSrcIndex - decreaseIndex) = (uint8_t)unSrcValue;
                        }
                        else
                        {
                            *(Dest + unJumpAddr + unSrcIndex - decreaseIndex) = (uint8_t)unSrcValue;
                        }
                    }
                    else if(!strcmp(pucParameter, "port.poe.allowed-classes"))
                    {

                        /*bit 0: class 0 supported
                        bit 1: class 1 supported
                        bit 2: class 2 supported
                        bit 3: class 3 supported
                        bit 4: class 4 supported
                        */

                        unSrcIndex = atoi(pucIndex);
                        char *pcuDummyValue = pucValue;
                        uint8_t ucDummy = *(Dest + unJumpAddr + unSrcIndex - 1);
                        ucDummy = 0;
                        while(*pcuDummyValue != '\0')
                        {
                            switch(*pcuDummyValue)
                            {
                                case '0':
                                ucDummy |=1;
                                break;

                                case '1':
                                ucDummy |=2;
                                break;

                                case '2':
                                ucDummy |=4;
                                break;

                                case '3':
                                ucDummy |=8;
                                break;

                                case '4':
                                ucDummy |=16;
                                break;
                            }

                            pcuDummyValue++;
                            *(Dest + unJumpAddr + unSrcIndex - 1) = ucDummy;
                        }
                    }

                    if (validateConfigDB[ucIndex].flags & FILE_VALID_FLAG_SPECIAL_QOS_PORT)
                    {
                        /* for compatibility reasons, we take the first port setting here and copy it to the global parameter */
                        if (!special_global_qos_done)
                        {
                            configDataRamBuffer->globalTrustMode = unSrcValue;
                            special_global_qos_done = 1;
                            //updating port table
                            for(i=0; i<32 ;i++){
                                SwitchConfiguration.aucTrustMode[i] = unSrcValue;
                            }
                        }
                    }
                }
            }
            break;
        }
    }
}


/***********************************************************************
Function Name			:	MainWindow::processLineFromCSV(QString line)
Function/DLD ID         :   SWR_MW_18
Purpose of Function		:   Process line read from readCSV finction
Author/Date     		: 	MANU SINGH - 3/2/2015
Modified by/Date		:
Calls                   :   readCSVFile
Inputs                  :	QString
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::processLineFromCSV(QString QStringLine)
{
    //qDebug() << line.toLatin1().toHex();
    if(QStringLine.count(",") <2)
    {
        return;
    }

    QStringList strings = QStringLine.split(",");
    //qDebug() << line;
    bool result = ValidateFileLine (strings[0].toLatin1().data(), strings[1].toLatin1().data(), strings[2].toLatin1().data());

    if(true == result)
    {
        if(strcmp(strings[0].toLatin1().data(), "file.configID") && strcmp(strings[0].toLatin1().data(), "creation-date") && strcmp(strings[0].toLatin1().data(), "file.end"))
        {
            StoreConfigurationParameterValueInBuffer (strings[0].toLatin1().data(),strings[1].toLatin1().data(), strings[2].toLatin1().data(), &SwitchConfiguration);
        }
    }
    else
    {
        //qDebug()<< "Error : " << line;
        /*generate the error message*/
        if(QStringLine.isNull())
            return;
        QString l_strtemp;
        l_strtemp.append(QString::number(CurrentLine));
        l_strtemp.append(",");
        l_strtemp.append(QStringLine);
        //qDebug() << errorReason;
        l_strtemp.append(",").append(QString::number(errorReason));
        errorList << l_strtemp;
        boolErrorLog = 1;
        QFile file("errorLog.txt");
        if (!file.open(QIODevice::WriteOnly))
        {
            QMessageBox::information(this, tr("Unable to open file"), file.errorString());
            return;
        }
        // Write content to *.txt file
        QTextStream stream(&file);

        for(int i=0;i<errorList.length();i++)
            stream << errorList[i];
        stream.flush();
        file.close();

    }
}

/***********************************************************************
Function Name			:	MainWindow::saveCSVFile()
Function/DLD ID         :   SWR_MW_19
Purpose of Function		:   Save configuration file
Author/Date     		: 	MANU SINGH - 3/2/2015
Modified by/Date		:
Calls                   :   save, save as, save to usb
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::saveCSVFile(QString QStringFileName)
{
    int totalLine = 0;
    if (QStringFileName.isEmpty())
        return;
    else
    {
        if(!QStringFileName.contains(".csv"))
            QStringFileName.append(".csv");
        QFile file(QStringFileName);
        if (!file.open(QIODevice::WriteOnly))
        {
            QMessageBox::information(this, tr("Unable to open file"), file.errorString());
            return;
        }
        // Write content to *.csv file

        QTextStream stream(&file);

        QString l_csvline;

        if((QString::number(stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId))=="23"
                ||(QString::number(stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId))=="25"
                ||(QString::number(stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId))=="29"
                ||(QString::number(stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId))=="31"
                ||(QString::number(stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId))=="38")

        {
            l_csvline.append("file.configID").append(",").append("0").append(",").append(QString::number(stProductData[ui->comboBox_productSelection->currentIndex()-1].m_ucProductId)).append("\n");
        }

        else if((QString::number(stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId))=="26")
        {
            l_csvline.append("file.configID").append(",").append("0").append(",").append(QString::number(stProductData[ui->comboBox_productSelection->currentIndex()-2].m_ucProductId)).append("\n");
        }
        else
        {
            //qDebug()<<QString::number(stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId);
            l_csvline.append("file.configID").append(",").append("0").append(",").append(QString::number(stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId));
            stream << l_csvline + "\n";
            totalLine++;
            l_csvline.clear();
        }

        l_csvline.append("file.creation-date").append(",").append("0").append(",").append(QDate::currentDate().toString("dd/MM/yyyy"));
        //l_csvline.append("\n");
        stream << l_csvline + "\n";
        totalLine++;
        l_csvline.clear();
        //l_csvline.append("\n");
        l_csvline.append("file.contactname").append(",").append("0").append(",").append(ui->lineEdit_contactName->text());
        stream << l_csvline + "\n";
        totalLine++;
        l_csvline.clear();

        l_csvline.append("file.location").append(",").append("0").append(",").append(ui->lineEdit_location->text());
        stream << l_csvline + "\n";
        totalLine++;
        l_csvline.clear();

        for(int i=1;i<=2;i++)
        {
            l_csvline.append("alarm.psu").append(",").append(QString::number(i)).append(",");
            l_csvline.append(QString::number(SwitchConfiguration.aucalarmPsu[i-1]));
            stream << l_csvline + "\n";
            totalLine++;
            l_csvline.clear();
        }

        l_csvline.append("switch.aging-time").append(",").append("0").append(",").append(QString::number(SwitchConfiguration.agingTime));
        stream << l_csvline + "\n";
        totalLine++;
        l_csvline.clear();

        // insert global qos trust mode setting Fix issue 30072
        l_csvline.append("qos.trust-mode").append(",").append("0").append(",");
        l_csvline.append(QString::number(SwitchConfiguration.globalTrustMode));
        stream << l_csvline + "\n";
        totalLine++;
        l_csvline.clear();


        for(int i=0;i<=3;i++)
        {
            l_csvline.append("traffic-class.priority-scheme").append(",").append(QString::number(i)).append(",");
            l_csvline.append(QString::number(SwitchConfiguration.aucpriority[i]));
            stream << l_csvline +"\n";
            totalLine++;
            l_csvline.clear();
        }

        for(int i=0;i<=7;i++)
        {
            l_csvline.append("dot1p.traffic-class").append(",").append(QString::number(i)).append(",");
            l_csvline.append(QString::number(SwitchConfiguration.aucdotp1PcpToTc[i]));
            stream << l_csvline +"\n";
            totalLine++;
            l_csvline.clear();
        }

        for(int i=0;i<=63;i++)
        {
            l_csvline.append("dscp.traffic-class").append(",").append(QString::number(i)).append(",");
            l_csvline.append(QString::number(SwitchConfiguration.aucdscpD1D2[i]));
            stream << l_csvline + "\n";
            totalLine++;
            l_csvline.clear();
        }


        if(validateConfigDB[8].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[8].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.flow-control").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucflowControlStatus[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[9].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[9].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.admin-state").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucadminState[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[10].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[10].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.jumbo").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucjumboFrameStatus[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[11].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[11].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.bc-storm.protection").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucbcStormStatus[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }
        if(validateConfigDB[12].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[12].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.bc-storm.threshold").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucbcStormThresold[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[13].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[13].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.mc-storm.protection").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucmcStormStatus[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[14].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[14].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.mc-storm.threshold").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucmcStormThresold[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        // Test Fix Issue 30072 - making QoS Trust Mode a global setting
//        if(validateConfigDB[15].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
//        {
//            if(validateConfigDB[15].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
//            {
//                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
//                {
//                    l_csvline.append("port.qos.trust-mode").append(",").append(QString::number(i+1)).append(",");
//                    l_csvline.append(QString::number(SwitchConfiguration.aucTrustMode[i]));
//                    stream << l_csvline + "\n";
//                    totalLine++;
//                    l_csvline.clear();
//                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
//                        break;
//                }
//            }
//        }

        if(validateConfigDB[30].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[30].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.qos.port-based").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucportBasedQoS[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[16].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[16].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.alarm.link").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.auclinkAlarmStatus[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[17].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[17].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.autoneg").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucautonegStatus[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[18].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[18].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.speed").append(",").append(QString::number(i+1)).append(",");
                    if(SwitchConfiguration.aucspeed[i]==3)
                        l_csvline.append(QString::number(SwitchConfiguration.aucspeed[i]-1));
                    else
                        l_csvline.append(QString::number(SwitchConfiguration.aucspeed[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[19].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[19].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.duplex").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucduplexMode[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[20].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[20].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.auto-crossing").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucautoCrossingstatus[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[21].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[21].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.mdi").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucMdistatus[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[22].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[22].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.eee").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucEEEStatus[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[23].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[23].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.poe.admin-state").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucpoeStatus[i]));
                    //qDebug()<<"poestatus : "<<SwitchConfiguration.aucpoeStatus[i];
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[24].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[24].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.poe.priority").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucpoePriority[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[25].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[25].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.poe.allowed-classes").append(",").append(QString::number(i+1)).append(",");

                    if(SwitchConfiguration.aucpoeAllowedClasses[i][0] != 0xFF)
                        l_csvline.append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i][0]));
                    if(SwitchConfiguration.aucpoeAllowedClasses[i][1] != 0xFF)
                        l_csvline.append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i][1]));
                    if(SwitchConfiguration.aucpoeAllowedClasses[i][2] != 0xFF)
                        l_csvline.append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i][2]));
                    if(SwitchConfiguration.aucpoeAllowedClasses[i][3] != 0xFF)
                        l_csvline.append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i][3]));
                    if(SwitchConfiguration.aucpoeAllowedClasses[i][4] != 0xFF)
                        l_csvline.append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i][4]));

                    stream << l_csvline + "\n";
                    totalLine++;
                    //qDebug() << l_csvline;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        if(validateConfigDB[26].ucAllowedProductLine & g_CurrentProductInfo.m_ucproductLine)
        {
            if(validateConfigDB[26].ucAllowedProductType & g_CurrentProductInfo.m_ucproductType)
            {
                for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)
                {
                    l_csvline.append("port.poe.override").append(",").append(QString::number(i+1)).append(",");
                    l_csvline.append(QString::number(SwitchConfiguration.aucpoeAllowedConsumptionOverride[i]));
                    stream << l_csvline + "\n";
                    totalLine++;
                    l_csvline.clear();
                    if(i > g_CurrentProductInfo.m_ucnoOfPort)
                        break;
                }
            }
        }

        l_csvline.append("file.end").append(",").append("0").append(",").append(QString::number(totalLine+1));
        stream << l_csvline;// + "\n";

        //qDebug() << "Total Line " << totalLine;

        stream.flush();
        file.close();

    }
}

/***********************************************************************
Function Name			:	MainWindow::setupGreyedOutParameters()
Function/DLD ID         :   SWR_MW_20
Purpose of Function		:   setup greyout of GUI
Author/Date     		: 	DALTON
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :   Port type 0-No ports Selected
                                1-TP port
                                2-TP-PoE port
                                3-Fiber port
************************************************************************/
void MainWindow::setupGreyedOutParameters(SELECTED_PORT_TYPE eSelectedPortType )
{
    if (stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId >= 100)   // TODO_MH: better definition of OCT8TX devices
    {
        ui->label_psuAlarm1->setDisabled(true);
        ui->label_psuAlarm2->setDisabled(true);
        ui->comboBox_psuAlarm1->setDisabled(true);
        ui->comboBox_psuAlarm2->setDisabled(true);
    }
    else
    {
        ui->label_psuAlarm1->setEnabled(true);
        ui->label_psuAlarm2->setEnabled(true);
        ui->comboBox_psuAlarm1->setEnabled(true);
        ui->comboBox_psuAlarm2->setEnabled(true);
    }


    QVariant V("-");
    switch(eSelectedPortType)
    {
    case NO_PORT_SELECTED:
        ui->label_portAdminState->setDisabled(true);
        ui->comboBox_adminState->setDisabled(true);

        ui->label_linkAlarm->setDisabled(true);
        ui->comboBox_alarmLink->setDisabled(true);

        if(ui->comboBox_autoNeg->currentIndex() == 1)
        {

            ui->label_speed->setDisabled(true);
            ui->comboBox_speed->setDisabled(true);

            if(ui->comboBox_speed->isEnabled()== false)
            {
                ui->comboBox_speed->setItemData(2,V,Qt::UserRole - 1);//user wont be able to select "-"
                //ui->comboBox_speed->setCurrentIndex(2);
            }

            ui->label_autoCrossing->setDisabled(true);
            ui->comboBox_autoCrossing->setDisabled(true);

            ui->label_duplexMode->setDisabled(true);
            ui->comboBox_duplexMode->setDisabled(true);

            ui->label_mdiState->setDisabled(true);
            ui->comboBox_mdiState->setDisabled(true);
        }
        else
        {
            ui->label_speed->setEnabled(true);
            ui->comboBox_speed->setEnabled(true);

            //ui->comboBox_speed->setCurrentIndex(1);


            ui->label_autoCrossing->setEnabled(true);
            ui->comboBox_autoCrossing->setEnabled(true);

            ui->label_duplexMode->setEnabled(true);
            ui->comboBox_duplexMode->setEnabled(true);

            if(ui->comboBox_autoCrossing->currentIndex() == 1)
            {
                ui->label_mdiState->setDisabled(true);
                ui->comboBox_mdiState->setDisabled(true);
            }
            else
            {
                ui->label_mdiState->setEnabled(true);
                ui->comboBox_mdiState->setEnabled(true);
            }
        }

        ui->label_flowControl->setDisabled(true);
        ui->comboBox_flowControl->setDisabled(true);

        ui->label_broadcastStormProtection->setDisabled(true);
        ui->comboBox_broadcastStormProtection->setDisabled(true);

        ui->label_broadcastStormThreshold->setDisabled(true);
        ui->spinBox_broadcastStormThreshold->setDisabled(true);

        ui->label_multicastStormProtection->setDisabled(true);
        ui->comboBox_multicastStormProtection->setDisabled(true);

        ui->label_multicastStormThreshold->setDisabled(true);
        ui->spinBox_multicastStormThreshold->setDisabled(true);

        ui->label_jumboFrames->setDisabled(true);
        ui->comboBox_jumboFrames->setDisabled(true);

        // Possible Issue Fix 30072 - making QoS Trust Mode global
//        ui->label_qosThrustMode->setDisabled(true);
//        ui->comboBox_qosTrustMode->setDisabled(true);


        ui->label_portpriority->setDisabled(true);
        ui->comboBox_portpriority->setDisabled(true);

        ui->label_eee->setDisabled(true);
        ui->comboBox_eee->setDisabled(true);

        ui->label_poeAdminState->setDisabled(true);
        ui->comboBox_poeAdminState->setDisabled(true);

        ui->label_poePriority->setDisabled(true);
        ui->comboBox_poePriority->setDisabled(true);

        ui->label_allowedPoEClasses->setDisabled(true);
        ui->lineEdit_allowedPoEClasses->setDisabled(true);

        ui->label_allowedPoEOverride->setDisabled(true);
        ui->label_allowedPoEOverride_2->setDisabled(true);
        ui->label_allowedPoEOverride_info->setVisible(false);
        ui->label_allowedPoEOverride_info2->setVisible(false);
        ui->toolButton_allowedPoEOverride_info->setVisible(false);
        ui->spinBox_allowedPoEOverride->setSpecialValueText("-");
        ui->spinBox_allowedPoEOverride->setDisabled(true);
        break;

    case TP_FE_PORT_SELECTED:
    case TP_GE_PORT_SELECTED:
    case TP_FE_POE_PORT_SELECTED:
    case TP_GE_POE_PORT_SELECTED:
        ui->label_portAdminState->setEnabled(true);
        ui->comboBox_adminState->setEnabled(true);

        if (stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId >= 100)   // TODO_MH: better definition of OCT8TX devices
        {
            ui->label_linkAlarm->setDisabled(true);
            ui->comboBox_alarmLink->setDisabled(true);
        }
        else
        {
        ui->label_linkAlarm->setEnabled(true);
        ui->comboBox_alarmLink->setEnabled(true);
        }

        ui->label_autoNeg->setEnabled(true);
        ui->comboBox_autoNeg->setEnabled(true);

        if(ui->comboBox_autoNeg->currentIndex() == 1)
        {

            ui->label_speed->setDisabled(true);
            ui->comboBox_speed->setDisabled(true);

            if(ui->comboBox_speed->isEnabled()== false)
            {
                ui->comboBox_speed->setItemData(2,V,Qt::UserRole - 1);//user wont be able to select "-"
                //ui->comboBox_speed->setCurrentIndex(2);
            }

            ui->label_autoCrossing->setDisabled(true);
            ui->comboBox_autoCrossing->setDisabled(true);

            ui->label_duplexMode->setDisabled(true);
            ui->comboBox_duplexMode->setDisabled(true);

            ui->label_mdiState->setDisabled(true);
            ui->comboBox_mdiState->setDisabled(true);
        }
        else
        {
            ui->label_speed->setEnabled(true);
            ui->comboBox_speed->setEnabled(true);

            //ui->comboBox_speed->setCurrentIndex(1);


            ui->label_autoCrossing->setEnabled(true);
            ui->comboBox_autoCrossing->setEnabled(true);

            ui->label_duplexMode->setEnabled(true);
            ui->comboBox_duplexMode->setEnabled(true);

            if(ui->comboBox_autoCrossing->currentIndex() == 1)
            {
                ui->label_mdiState->setDisabled(true);
                ui->comboBox_mdiState->setDisabled(true);
            }
            else
            {
                ui->label_mdiState->setEnabled(true);
                ui->comboBox_mdiState->setEnabled(true);
            }
        }

        ui->label_flowControl->setEnabled(true);
        ui->comboBox_flowControl->setEnabled(true);

        ui->label_broadcastStormProtection->setEnabled(true);
        ui->comboBox_broadcastStormProtection->setEnabled(true);

        if(ui->comboBox_broadcastStormProtection->currentIndex() == 1)
        {
            ui->label_broadcastStormThreshold->setEnabled(true);
            ui->spinBox_broadcastStormThreshold->setEnabled(true);
        }
        else
        {
            ui->label_broadcastStormThreshold->setDisabled(true);
            ui->spinBox_broadcastStormThreshold->setDisabled(true);
        }

        ui->label_multicastStormProtection->setEnabled(true);
        ui->comboBox_multicastStormProtection->setEnabled(true);

        if(ui->comboBox_multicastStormProtection->currentIndex() == 1)
        {
            ui->label_multicastStormThreshold->setEnabled(true);
            ui->spinBox_multicastStormThreshold->setEnabled(true);
        }
        else
        {
            ui->label_multicastStormThreshold->setDisabled(true);
            ui->spinBox_multicastStormThreshold->setDisabled(true);
        }

        if(stProductData[ui->comboBox_productSelection->currentIndex()].m_canhandleJumbo == PRODUCT_ABLE_JUMBO) //Fix 30585: Jumboframe setting enabled only for GE and particular FE (SPIDER-PL-20-06T1Z6Z6Z6 - ID 27, SPIDER-PL-20-07T1M2M299 - ID 30, SPIDER-PL-20-07T1S2S299 - ID 31)
        {
            ui->label_jumboFrames->setEnabled(true);
            ui->comboBox_jumboFrames->setEnabled(true);
        }
        else                                                    //Fix 30585: Jumboframe setting enabled only for GE and particular
        {
            ui->label_jumboFrames->setDisabled(true);
            ui->comboBox_jumboFrames->setDisabled(true);
        }

        if(eSelectedPortType == TP_GE_PORT_SELECTED || eSelectedPortType == TP_GE_POE_PORT_SELECTED)
        {
            if(ui->comboBox_autoNeg->currentIndex() == 1)
            {
                ui->label_eee->setEnabled(true);
                ui->comboBox_eee->setEnabled(true);
            }
            else
            {
                ui->label_eee->setDisabled(true);
                ui->comboBox_eee->setDisabled(true);
            }
        }
        else
        {
            ui->label_eee->setDisabled(true);
            ui->comboBox_eee->setDisabled(true);
        }

        //should be already enabled after Fix Issue 30072
        //ui->label_qosThrustMode->setEnabled(true);
        //ui->comboBox_qosTrustMode->setEnabled(true);

        if(ui->comboBox_qosTrustMode->currentIndex()==0)
        {
            ui->label_portpriority->setEnabled(true);
            ui->comboBox_portpriority->setEnabled(true);
        }
        else
        {
            ui->label_portpriority->setDisabled(true);
            ui->comboBox_portpriority->setDisabled(true);
        }


        if((g_CurrentProductInfo.m_ucproductLine & PRODUCT_LINE_POE)&&(eSelectedPortType == TP_GE_POE_PORT_SELECTED || eSelectedPortType ==  TP_FE_POE_PORT_SELECTED))
        {
            ui->label_poeAdminState->setEnabled(true);
            ui->comboBox_poeAdminState->setEnabled(true);

            if(ui->comboBox_poeAdminState->currentIndex() == 1)
            {
                ui->label_poePriority->setEnabled(true);
                ui->comboBox_poePriority->setEnabled(true);

                ui->label_allowedPoEClasses->setEnabled(true);
                ui->lineEdit_allowedPoEClasses->setEnabled(true);

                if(ui->lineEdit_allowedPoEClasses->text() == "0,1,2,3,4")
                {
                    ui->label_allowedPoEOverride->setEnabled(true);
                    ui->label_allowedPoEOverride_2->setEnabled(true);
                    ui->label_allowedPoEOverride_info->setVisible(true);
                    ui->label_allowedPoEOverride_info2->setVisible(true);
                    ui->toolButton_allowedPoEOverride_info->setVisible(true);
                    ui->toolButton_allowedPoEOverride_info->setEnabled(true);
                    ui->spinBox_allowedPoEOverride->setEnabled(true);
                }
                else
                {
                    ui->label_allowedPoEOverride->setDisabled(true);
                    ui->label_allowedPoEOverride_2->setDisabled(true);
                    ui->label_allowedPoEOverride_info->setVisible(true);
                    ui->label_allowedPoEOverride_info2->setVisible(true);
                    ui->toolButton_allowedPoEOverride_info->setVisible(true);
                    ui->toolButton_allowedPoEOverride_info->setEnabled(true);
                    ui->spinBox_allowedPoEOverride->setValue(0);
                    ui->spinBox_allowedPoEOverride->setDisabled(true);
                }
            }
            else
            {
                ui->label_poePriority->setDisabled(true);
                ui->comboBox_poePriority->setDisabled(true);

                ui->label_allowedPoEClasses->setDisabled(true);
                ui->lineEdit_allowedPoEClasses->setDisabled(true);

                ui->label_allowedPoEOverride->setDisabled(true);
                ui->label_allowedPoEOverride_2->setDisabled(true);
                ui->label_allowedPoEOverride_info->setVisible(true);
                ui->label_allowedPoEOverride_info2->setVisible(true);
                ui->toolButton_allowedPoEOverride_info->setVisible(true);
                ui->toolButton_allowedPoEOverride_info->setEnabled(true);
                ui->spinBox_allowedPoEOverride->setSpecialValueText("-");
                ui->spinBox_allowedPoEOverride->setDisabled(true);
            }
        }
        else
        {
            ui->label_poeAdminState->setDisabled(true);
            ui->comboBox_poeAdminState->setDisabled(true);
            ui->comboBox_poeAdminState->setCurrentIndex(0);

            ui->label_poePriority->setDisabled(true);
            ui->comboBox_poePriority->setDisabled(true);
            ui->comboBox_poePriority->setCurrentIndex(0);

                ui->label_allowedPoEClasses->setDisabled(true);
                ui->lineEdit_allowedPoEClasses->setDisabled(true);
            ui->lineEdit_allowedPoEClasses->setText("");

            ui->label_allowedPoEOverride->setDisabled(true);
            ui->label_allowedPoEOverride_2->setDisabled(true);
            ui->spinBox_allowedPoEOverride->setDisabled(true);
            ui->spinBox_allowedPoEOverride->setSpecialValueText("-");

            if(g_CurrentProductInfo.m_ucproductLine & PRODUCT_LINE_POE)
            {
                ui->label_allowedPoEOverride_info->setVisible(true);
                ui->label_allowedPoEOverride_info2->setVisible(true);
                ui->toolButton_allowedPoEOverride_info->setVisible(true);
                ui->toolButton_allowedPoEOverride_info->setEnabled(true);
            }
            else
            {
                ui->label_allowedPoEOverride_info->setVisible(false);
                ui->label_allowedPoEOverride_info2->setVisible(false);
                ui->toolButton_allowedPoEOverride_info->setVisible(false);
                ui->toolButton_allowedPoEOverride_info->setEnabled(false);
            }

        }
        break;

    case FIBER_FE_PORT_SELECTED:
    case FIBER_GE_PORT_SELECTED:
        ui->label_flowControl->setEnabled(true);
        ui->comboBox_flowControl->setEnabled(true);

        ui->label_portAdminState->setEnabled(true);
        ui->comboBox_adminState->setEnabled(true);

        if(stProductData[ui->comboBox_productSelection->currentIndex()].m_canhandleJumbo == PRODUCT_ABLE_JUMBO) //Fix 30585: Jumboframe setting enabled only for GE and particular FE (SPIDER-PL-20-06T1Z6Z6Z6 - ID 27, SPIDER-PL-20-07T1M2M299 - ID 30, SPIDER-PL-20-07T1S2S299 - ID 31)
        {
            ui->label_jumboFrames->setEnabled(true);
            ui->comboBox_jumboFrames->setEnabled(true);
        }
        else                                                    //Fix 30585: Jumboframe setting enabled only for GE and particular
        {
            ui->label_jumboFrames->setDisabled(true);
            ui->comboBox_jumboFrames->setDisabled(true);
        }

        ui->label_broadcastStormProtection->setEnabled(true);
        ui->comboBox_broadcastStormProtection->setEnabled(true);

        if(ui->comboBox_broadcastStormProtection->currentIndex() == 1)
        {
            ui->label_broadcastStormThreshold->setEnabled(true);
            ui->spinBox_broadcastStormThreshold->setEnabled(true);
        }
        else
        {
            ui->label_broadcastStormThreshold->setDisabled(true);
            ui->spinBox_broadcastStormThreshold->setDisabled(true);
        }

        ui->label_multicastStormProtection->setEnabled(true);
        ui->comboBox_multicastStormProtection->setEnabled(true);

        if(ui->comboBox_multicastStormProtection->currentIndex() == 1)
        {
            ui->label_multicastStormThreshold->setEnabled(true);

            ui->spinBox_multicastStormThreshold->setEnabled(true);
        }
        else
        {
            ui->label_multicastStormThreshold->setDisabled(true);
            ui->spinBox_multicastStormThreshold->setDisabled(true);
        }

        ui->label_qosThrustMode->setEnabled(true);
        ui->comboBox_qosTrustMode->setEnabled(true);

        if(ui->comboBox_qosTrustMode->currentIndex()==0)
        {
            ui->label_portpriority->setEnabled(true);
            ui->comboBox_portpriority->setEnabled(true);

        }
        else
        {
            ui->label_portpriority->setDisabled(true);
            ui->comboBox_portpriority->setDisabled(true);
        }

        if (stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId >= 100)   // TODO_MH: better definition of OCT8TX devices
        {
            ui->label_linkAlarm->setDisabled(true);
            ui->comboBox_alarmLink->setDisabled(true);
        }
        else
        {
        ui->label_linkAlarm->setEnabled(true);
        ui->comboBox_alarmLink->setEnabled(true);
        }

        ui->label_duplexMode->setEnabled(true);
        ui->comboBox_duplexMode->setEnabled(true);

        ui->label_autoNeg->setDisabled(true);
        ui->comboBox_autoNeg->setDisabled(true);

        ui->label_speed->setDisabled(true);
        ui->comboBox_speed->setDisabled(true);

        if(ui->comboBox_speed->isEnabled()== false)
        {
            ui->comboBox_speed->setItemData(2,V,Qt::UserRole - 1);//user wont be able to select "-"
            //ui->comboBox_speed->setCurrentIndex(2);
        }

        ui->label_poeAdminState->setDisabled(true);
        ui->comboBox_poeAdminState->setDisabled(true);
        ui->comboBox_poeAdminState->setCurrentIndex(0);

        ui->label_autoCrossing->setDisabled(true);
        ui->comboBox_autoCrossing->setDisabled(true);

        ui->label_poePriority->setDisabled(true);
        ui->comboBox_poePriority->setDisabled(true);
        ui->comboBox_poePriority->setCurrentIndex(0);


        ui->label_mdiState->setDisabled(true);
        ui->comboBox_mdiState->setDisabled(true);

        ui->label_eee->setDisabled(true);
        ui->comboBox_eee->setDisabled(true);

        ui->label_allowedPoEClasses->setDisabled(true);
        ui->lineEdit_allowedPoEClasses->setDisabled(true);

        ui->label_allowedPoEOverride->setDisabled(true);
        ui->label_allowedPoEOverride_2->setDisabled(true);
        ui->label_allowedPoEOverride_info->setVisible(false);
        ui->label_allowedPoEOverride_info2->setVisible(false);
        ui->toolButton_allowedPoEOverride_info->setVisible(false);
        ui->toolButton_allowedPoEOverride_info->setEnabled(false);
        ui->spinBox_allowedPoEOverride->setSpecialValueText("-");
        ui->spinBox_allowedPoEOverride->setDisabled(true);
        break;

    default:
        break;
    }
}
/***********************************************************************
Function Name			:	populateSinglePort
Function/DLD ID         :   SWR_MW_21
Purpose of Function		:   setup greyout of GUI
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::populateSinglePort(int siIndex)
{
    int i,k;
    unsigned temp;
    ui->comboBox_adminState->setCurrentIndex(SwitchConfiguration.aucadminState[siIndex]);
    ui->comboBox_alarmLink->setCurrentIndex(SwitchConfiguration.auclinkAlarmStatus[siIndex]);
    //ui->comboBox_speed->setCurrentIndex(SwitchConfiguration.aucspeed[siIndex]-1); // 0-Blank, 1-100Mbps, 2-10Mbps
    ui->comboBox_speed->setCurrentIndex(SwitchConfiguration.aucspeed[siIndex]-1); // 0->Blank, 1->100Mbps, 2->10Mbps, 3->"-"

    //qDebug()<<"combobox_speed_popusingleport: "<<ui->comboBox_speed->currentIndex();
    if(SwitchConfiguration.aucautonegStatus[siIndex] == 1)
        ui->comboBox_autoNeg->setCurrentIndex(1);
    else
        ui->comboBox_autoNeg->setCurrentIndex(0);

    if(SwitchConfiguration.aucautoCrossingstatus[siIndex] == 1)
        ui->comboBox_autoCrossing->setCurrentIndex(1);
    else
        ui->comboBox_autoCrossing->setCurrentIndex(0);

    //qDebug() << "dup" << SwitchConfiguration.aucduplexMode[index];
    if(SwitchConfiguration.aucduplexMode[siIndex] == 2)
        ui->comboBox_duplexMode->setCurrentIndex(1);// 1-HDX, 2-FDX
    else
        ui->comboBox_duplexMode->setCurrentIndex(0);// 1-HDX, 2-FDX

    ui->comboBox_mdiState->setCurrentIndex(SwitchConfiguration.aucMdistatus[siIndex]);
    ui->comboBox_flowControl->setCurrentIndex(SwitchConfiguration.aucflowControlStatus[siIndex]);

    if(SwitchConfiguration.aucbcStormStatus[siIndex] == 1)
        ui->comboBox_broadcastStormProtection->setCurrentIndex(1);
    else
        ui->comboBox_broadcastStormProtection->setCurrentIndex(0);
    ui->spinBox_broadcastStormThreshold->setValue(SwitchConfiguration.aucbcStormThresold[siIndex]);

    if(SwitchConfiguration.aucmcStormStatus[siIndex] == 1)
        ui->comboBox_multicastStormProtection->setCurrentIndex(1);
    else
        ui->comboBox_multicastStormProtection->setCurrentIndex(0);
    ui->spinBox_multicastStormThreshold->setValue(SwitchConfiguration.aucmcStormThresold[siIndex]);

    if(SwitchConfiguration.aucjumboFrameStatus[siIndex] == 1)
        ui->comboBox_jumboFrames->setCurrentIndex(1);
    else
        ui->comboBox_jumboFrames->setCurrentIndex(0);

    ui->comboBox_qosTrustMode->setCurrentIndex(SwitchConfiguration.aucTrustMode[siIndex]);

    ui->comboBox_portpriority->setCurrentIndex(SwitchConfiguration.aucportBasedQoS[siIndex]);

    if(SwitchConfiguration.aucEEEStatus[siIndex] == 1)
        ui->comboBox_eee->setCurrentIndex(1);
    else
        ui->comboBox_eee->setCurrentIndex(0);

    //qDebug() << "Poe Status " << SwitchConfiguration.aucpoeStatus[siIndex];
    if(SwitchConfiguration.aucpoeStatus[siIndex] == 1)
        ui->comboBox_poeAdminState->setCurrentIndex(1);
    else
        ui->comboBox_poeAdminState->setCurrentIndex(0);

    ui->comboBox_poePriority->setCurrentIndex(SwitchConfiguration.aucpoePriority[siIndex] - 1);

    QString l_strindex="";
    //qDebug()<<" poe priority classes 1 port"<<siIndex<<SwitchConfiguration.aucpoeAllowedClasses[siIndex][0];

    for (i=0,temp=0; i<5; i++)
    {
        if (SwitchConfiguration.aucpoeAllowedClasses[siIndex][i] != 0xFF)
            for (k=0; k<5; k++)
            {
                if (SwitchConfiguration.aucpoeAllowedClasses[siIndex][i] == k)
                    temp |= (1<<k);
            }
    }

    //qDebug()<<"temp="<<temp;

    for (k=0, i=0; k<5; k++)
    {
        if (temp & (1<<k))
        {
            if (i==0)
                l_strindex.append(QString::number(k));
            else
                l_strindex.append(",").append(QString::number(k));
            i++;
        }
    }

    //qDebug() << "populateSinglePort " << l_strindex;

    ui->lineEdit_allowedPoEClasses->setText(l_strindex);

    ui->spinBox_allowedPoEOverride->setValue(SwitchConfiguration.aucpoeAllowedConsumptionOverride[siIndex]);

}
/***********************************************************************
Function Name			:	newFile
Function/DLD ID         :   SWR_MW_22
Purpose of Function		:   open new file
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::newFile()
{
    //qDebug() << "Invoked <b>File|New</b>";
    QStringFileNamesLoad.clear();

    /** Write clear GUI function **/ /** MANU 04/05/2015 **/
    ui->label_productImage->setToolTip("");
    ui->lineEdit_serialNumber->setText("");
    clearPortBorder();
    ui->lineEdit_contactName->setText("");
    ui->lineEdit_location->setText("");
    ui->lineEdit_fileRelease->setText("");
    ui->lineEdit_componentId->setText("");

    serialNumber.clear();
    serialNumber.append(ui->lineEdit_serialFix->text()).append("-").append(ui->lineEdit_serialNumber->text());

    radioSelectAll(false);
    radioDeselectAll(true);

    setupGreyedOutParameters(NO_PORT_SELECTED);

    updateBufferfromDefault();
    updteUserInterface();
    populateSinglePort(0);
    radioDeselectAll(true);


    //qDebug() << "Blank with default value New file generated";
}
/***********************************************************************
Function Name			:	open()
Function ID 			:   SWR_MW_23
Purpose of Function		:   Open configuration file
Author/Date     		: 	MANU SINGH - 3/2/2015
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::open()
{
    //qDebug() << "Invoked <b>File|Open</b>";
    QStringFileNamesLoad = QFileDialog::getOpenFileName(this, tr("Open File"),"/path/to/file/",tr("CSV Files (*.csv);;Text files (*.txt);; All files (*.*)"));

    //qDebug()<<"Open button clicked";
    if(!QStringFileNamesLoad.isEmpty())
        readCSVFile(QStringFileNamesLoad);
    else
        return;

    ui->lineEdit_contactName->setText("");
    ui->lineEdit_location->setText("");
    ui->lineEdit_fileRelease->setText("");
    ui->lineEdit_componentId->setText("");
    ui->lineEdit_serialNumber->setText("");serialNumber.clear();
    serialNumber.append(ui->lineEdit_serialFix->text()).append("-").append(ui->lineEdit_serialNumber->text());

    clearPortBorder();
    createNewTable(g_CurrentProductInfo.m_ucnoOfPort);

    radioSelectAll(false);
    radioDeselectAll(true);


    setupGreyedOutParameters(NO_PORT_SELECTED);//og
    populateSinglePort(0);

    updateGlobalParaUserInterface();
    updatePortTableUserInterface();

}
/***********************************************************************
Function Name			:	save
Function/DLD ID         :   SWR_MW_24
Purpose of Function		:   save file
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::save()
{
    //qDebug() << "Invoked <b>File|Save</b>";

    if(QStringFileNamesLoad.isEmpty())
        saveAs();
    else
        saveCSVFile(QStringFileNamesLoad);
}
/***********************************************************************
Function Name			:	saveAs
Function/DLD ID         :   SWR_MW_25
Purpose of Function		:   save file at user defined location
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::saveAs()
{
    //qDebug() << "Invoked <b>File|SaveAs</b>";

    if(NoSaveWhnPrtDisabld() == false)
    {
        if(QMessageBox::Ok == QMessageBox(QMessageBox::Information,"Information","Cannot Save File. All the ports are disabled",QMessageBox::Ok).exec())
        {
            return;
        }
    }
    else
    {
        QString Desktopdir = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
        QString modelName;
        modelName.append( Desktopdir);
        modelName.append("/switch_config_").append(QString::number(stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId));
        modelName.append(".csv");
        QString fileName = QFileDialog::getSaveFileName(
                    this,
                    tr("Save As"),
                    modelName,
                    tr("Comma Separated Values (*.csv)"));

        if(!fileName.isNull())
        {
            saveCSVFile(fileName);
            QStringFileNamesLoad.clear();
            QStringFileNamesLoad = fileName;
        }
    }

}
/***********************************************************************
Function Name			:	saveToUsb
Function/DLD ID         :   SWR_MW_26
Purpose of Function		:   save configuration file on USB
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::saveToUsb()
{
    //qDebug() << "Invoked <b>File|savetoUsb</b>";
    {
        QString modelName;
        modelName.append("switch_config_").append(QString::number(stProductData[ui->comboBox_productSelection->currentIndex()].m_ucProductId));
        modelName.append(".csv");
        QString fileName = QFileDialog::getSaveFileName(
                    this,
                    tr("Save to USB"),
                    modelName,
                    //tr("Comma Separated Values (*.csv);;All Files (*.*)"));
                    tr("Comma Separated Values (*.csv)"));

        if(!fileName.isNull())
        {
            saveCSVFile(fileName);
            QStringFileNamesLoad.clear();
            QStringFileNamesLoad = fileName;
        }
    }
}


/***********************************************************************
Function Name			:	DontSaveWhnDisabled
Function/DLD ID         :   SWR_MW_25
Purpose of Function		:   Does not let the User to save the Configuration when all ports are disabled
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/

bool MainWindow::NoSaveWhnPrtDisabld()
{
    for(int i=0;i<g_CurrentProductInfo.m_ucnoOfPort; i++)
    {
        if(SwitchConfiguration.aucadminState[i] == 1)
        {
            return true;
        }
    }
    return false;
}

/***********************************************************************
Function Name			:	exit
Function/DLD ID         :   SWR_MW_27
Purpose of Function		:   exit application
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::exit()
{
    //qDebug() << "Invoked <b>File|Exit</b>";
    close();
}


/***********************************************************************
Function Name			:	exportReport
Function/DLD ID         :   SWR_MW_28
Purpose of Function		:   export report to PDF
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::exportReport()
{
    //qDebug() << "Invoked <b>Documents|Export</b>";
    QString pdfName = (ui->lineEdit_serialFix->text()).append(ui->lineEdit_serialNumber->text());//.append("_").append(ui->lineEdit_fileRelease->text());
    //qDebug()<<serialNumber;
    //qDebug()<<pdfName;
    QString fileName = QFileDialog::getSaveFileName(this, tr("Save File"),
                                                    pdfName,tr("PDF Document (*.pdf)"));
    if(!fileName.isEmpty())
    {
        if(!fileName.endsWith(".pdf"))
            fileName.append(".pdf");
        CPdfReport pdfReportDocument(ui->comboBox_productSelection->currentIndex(),fileName);
        pdfReportDocument.generatePdfReport();
    }
}
/***********************************************************************
Function Name			:	engLan
Function/DLD ID         :   SWR_MW_29
Purpose of Function		:   Selection of english language
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::engLan()
{
    //qDebug() << "Invoked <b>Language|English</b>";
    QActionEngLanAct->setChecked(true);
    QActionGerLanAct->setChecked(false);
    siLanguageSelection = 0;
}
/***********************************************************************
Function Name			:	gerLan
Function/DLD ID         :   SWR_MW_30
Purpose of Function		:   Selction of german language
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::gerLan()
{
    //qDebug() << "Invoked <b>Language|German</b>";
    QActionGerLanAct->setChecked(true);
    QActionEngLanAct->setChecked(false);
    siLanguageSelection = 1;
}
/***********************************************************************
Function Name			:	onlineHelp
Function/DLD ID         :   SWR_MW_31
Purpose of Function		:   open help file
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::onlineHelp()
{
    //qDebug() << "Invoked <b>Help|OnlineHelp</b>";
    QDir dirpath;
    //QString url;
    QString urlFile;
    urlFile.append("file:///");
    if(!siLanguageSelection)
    {
        urlFile.append(dirpath.currentPath()).append("/HelpEn/");

    }
    else
    {
        //QDesktopServices::openUrl(url.append(dirpath.currentPath()).append("/HelpDe/SpiderProgrammingTool.html"));
        urlFile.append(dirpath.currentPath()).append("/HelpDe/");
    }

    if(siOpenParticularHelp == "SwitchProgrammingTool.html")
        urlFile.append("SwitchProgrammingTool.html");
    else
        urlFile.append(siOpenParticularHelp);
#if 1
//#if LINUX
    QDesktopServices::openUrl(urlFile);
#else
    QWebView *view = new QWebView();
    view->load(QUrl(urlFile));
    view->show();
#endif

}
/***********************************************************************
Function Name			:	webSite
Function/DLD ID         :   SWR_MW_32
Purpose of Function		:   open website link
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::webSite()
{
    //qDebug() << "Invoked <b>Help|website</b>";
    QDesktopServices::openUrl(QUrl(WEBSITE_LINK));
}
/***********************************************************************
Function Name			:	about
Function/DLD ID         :   SWR_MW_33
Purpose of Function		:   Open about dialog box
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::about()
{
    //qDebug() << "Invoked <b>Help|About|Bold</b>";
    ptrAbout = new aboutDialog();
    ptrAbout->setModal(true);
    ptrAbout->exec();
}
/***********************************************************************
Function Name			:	on_comboBox_adminState_currentIndexChanged
Function/DLD ID         :   SWR_MW_34
Purpose of Function		:   Slot for admin state
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_adminState_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,0, QModelIndex());
            //qDebug()<<"admin state0 " << cellSelected.column() << " - " << cellSelected.isValid();
            if((ui->comboBox_adminState->isEnabled()))//& !cellSelected.isValid())//&&(!boolTableClickflag))
            {
                SwitchConfiguration.aucadminState[i] = siIndex;
            }
            QStandardItemModelModels->setData(newIndex, ui->comboBox_adminState->itemText(siIndex), Qt::EditRole);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString str = clickQlabelQLabelPort[i]->styleSheet();
            if(!str.isNull())
            {
                if(str.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,0, QModelIndex());
                    if(ui->comboBox_adminState->isEnabled())
                    {
                        SwitchConfiguration.aucadminState[i] = siIndex;
                        QStandardItemModelModels->setData(newIndex, ui->comboBox_adminState->itemText(siIndex), Qt::EditRole);
                    }
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_alarmLink_currentIndexChanged
Function/DLD ID         :   SWR_MW_35
Purpose of Function		:   Slot for alarm link
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_alarmLink_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,1, QModelIndex());
            if((ui->comboBox_alarmLink->isEnabled()))//&& !cellSelected.isValid())//&&(!boolTableClickflag))
                SwitchConfiguration.auclinkAlarmStatus[i] = siIndex;
            QStandardItemModelModels->setData(newIndex, ui->comboBox_alarmLink->itemText(siIndex), Qt::EditRole);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,1, QModelIndex());
                    if(ui->comboBox_alarmLink->isEnabled())
                        SwitchConfiguration.auclinkAlarmStatus[i] = siIndex;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_alarmLink->itemText(siIndex), Qt::EditRole);
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_speed_currentIndexChanged
Function/DLD ID         :   SWR_MW_36
Purpose of Function		:   Slot for speed
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_speed_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            //i is selected port number
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,3, QModelIndex());     // changed from 2 to 3 -  issue 28935 fix -  Layout of table matching to preferences above
            if(ui->comboBox_speed->isEnabled())
                SwitchConfiguration.aucspeed[i] = siIndex+1;
            QStandardItemModelModels->setData(newIndex, ui->comboBox_speed->itemText(siIndex), Qt::EditRole);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,3, QModelIndex());     // changed from 2 to 3 -  issue 28935 fix -  Layout of table matching to preferences above
                    if(ui->comboBox_speed->isEnabled())
                        SwitchConfiguration.aucspeed[i] = siIndex+1;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_speed->itemText(siIndex), Qt::EditRole);
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_autoNeg_currentIndexChanged
Function/DLD ID         :   SWR_MW_37
Purpose of Function		:   Slot for auto nego
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_autoNeg_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,2, QModelIndex());     // changed from 3 to 2 -  issue 28935 fix -  Layout of table matching to preferences above
            if(ui->comboBox_autoNeg->isEnabled())
            {
                SwitchConfiguration.aucautonegStatus[i] = siIndex;
            }
            if(ui->comboBox_autoNeg->currentIndex() == 1)
            {
                SwitchConfiguration.aucspeed[i] = 3;
                ui->comboBox_speed->setCurrentIndex(SwitchConfiguration.aucspeed[i]-1);
            }
            else
            {
                SwitchConfiguration.aucspeed[i] = 2;
                ui->comboBox_speed->setCurrentIndex(SwitchConfiguration.aucspeed[i]-1);
                //QStandardItemModelModels->setData(3, ui->comboBox_speed->itemText("-"), Qt::UserRole - 1);

            }
            setupGreyedOutParameters(checkTypeofPort(i));
            QStandardItemModelModels->setData(newIndex, ui->comboBox_autoNeg->itemText(siIndex), Qt::EditRole);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,2, QModelIndex());     // changed from 3 to 2 -  issue 28935 fix -  Layout of table matching to preferences above
                    if(ui->comboBox_autoNeg->isEnabled())
                        SwitchConfiguration.aucautonegStatus[i] = siIndex;
                    //qDebug()<<"switchconfig_autoneg of: "<<i<<"port"<<SwitchConfiguration.aucautonegStatus[i];
                    if(ui->comboBox_autoNeg->currentIndex() == 1)
                    {
                        SwitchConfiguration.aucspeed[i] = 3;
                        ui->comboBox_speed->setCurrentIndex(SwitchConfiguration.aucspeed[i]-1);
                    }
                    else
                    {
                        if(SwitchConfiguration.aucspeed[i]==3 || SwitchConfiguration.aucspeed[i]==2)
                        {
                            SwitchConfiguration.aucspeed[i] = 2;                      //JG: added if condition here to fix Issue 29163 - prevent to switch back from 10Mbps(index 1) to 100Mbps (index 2)
                        }
                        //else aucspeed[i] == 1 --> aucspeed not set differently
                        ui->comboBox_speed->setCurrentIndex(SwitchConfiguration.aucspeed[i]-1);
                    }
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_autoNeg->itemText(siIndex), Qt::EditRole);
                    setupGreyedOutParameters(checkTypeofPort(i));
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_autoCrossing_currentIndexChanged
Function/DLD ID         :   SWR_MW_38
Purpose of Function		:   Slot for auto crossing
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_autoCrossing_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,5, QModelIndex());     // changed from 4 to 5 -  issue 28935 fix -  Layout of table matching to preferences above
            if((ui->comboBox_autoCrossing->isEnabled()))//&& !cellSelected.isValid())//&&(!boolTableClickflag))
                SwitchConfiguration.aucautoCrossingstatus[i] = siIndex;
            QStandardItemModelModels->setData(newIndex, ui->comboBox_autoCrossing->itemText(siIndex), Qt::EditRole);
            setupGreyedOutParameters(checkTypeofPort(i));//TP_PORT_SELECTED);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,5, QModelIndex());     // changed from 4 to 5 -  issue 28935 fix -  Layout of table matching to preferences above
                    if(ui->comboBox_autoCrossing->isEnabled())
                        SwitchConfiguration.aucautoCrossingstatus[i] = siIndex;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_autoCrossing->itemText(siIndex), Qt::EditRole);
                    setupGreyedOutParameters(checkTypeofPort(i));//TP_PORT_SELECTED);
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_duplexMode_currentIndexChanged
Function/DLD ID         :   SWR_MW_38
Purpose of Function		:   Slot for duplex mode
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_duplexMode_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,4, QModelIndex());     // changed from 5 to 4 -  issue 28935 fix -  Layout of table matching to preferences above
            if((ui->comboBox_duplexMode->isEnabled()))//&& !cellSelected.isValid())//&&(!boolTableClickflag))
                SwitchConfiguration.aucduplexMode[i] = siIndex+1;
            QStandardItemModelModels->setData(newIndex, ui->comboBox_duplexMode->itemText(siIndex), Qt::EditRole);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,4, QModelIndex());     // changed from 5 to 4 -  issue 28935 fix -  Layout of table matching to preferences above
                    if(ui->comboBox_duplexMode->isEnabled())
                        SwitchConfiguration.aucduplexMode[i] = siIndex+1;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_duplexMode->itemText(siIndex), Qt::EditRole);
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_mdiState_currentIndexChanged
Function/DLD ID         :   SWR_MW_39
Purpose of Function		:   Slot for mdi state
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_mdiState_currentIndexChanged(int siIndex)
{    
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,6, QModelIndex());
            if(ui->comboBox_mdiState->isEnabled())
            {
                SwitchConfiguration.aucMdistatus[i] = siIndex;
            }
            QStandardItemModelModels->setData(newIndex, ui->comboBox_mdiState->itemText(siIndex), Qt::EditRole);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,6, QModelIndex());
                    if(ui->comboBox_mdiState->isEnabled())
                    {
                        SwitchConfiguration.aucMdistatus[i] = siIndex;
                    }
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_mdiState->itemText(siIndex), Qt::EditRole);
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_flowControl_currentIndexChanged
Function/DLD ID         :   SWR_MW_40
Purpose of Function		:   Slot for flow control
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_flowControl_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,7, QModelIndex());
            if(ui->comboBox_flowControl->isEnabled())
                SwitchConfiguration.aucflowControlStatus[i] = siIndex;
            QStandardItemModelModels->setData(newIndex, ui->comboBox_flowControl->itemText(siIndex), Qt::EditRole);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,7, QModelIndex());
                    if(ui->comboBox_flowControl->isEnabled())
                        SwitchConfiguration.aucflowControlStatus[i] = siIndex;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_flowControl->itemText(siIndex), Qt::EditRole);
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_broadcastStormProtection_currentIndexChanged
Function/DLD ID         :   SWR_MW_41
Purpose of Function		:   Slot for broadcast storm protection
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_broadcastStormProtection_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,8, QModelIndex());
            if(ui->comboBox_broadcastStormProtection->isEnabled())
                SwitchConfiguration.aucbcStormStatus[i] = siIndex;
            QStandardItemModelModels->setData(newIndex, ui->comboBox_broadcastStormProtection->itemText(siIndex), Qt::EditRole);
            setupGreyedOutParameters(checkTypeofPort(i));
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,8, QModelIndex());
                    if(ui->comboBox_broadcastStormProtection->isEnabled())
                        SwitchConfiguration.aucbcStormStatus[i] = siIndex;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_broadcastStormProtection->itemText(siIndex), Qt::EditRole);
                    setupGreyedOutParameters(checkTypeofPort(i));
                    siUpdatePara = 0;
                    //break;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_spinBox_broadcastStormThreshold_valueChanged
Function/DLD ID         :   SWR_MW_42
Purpose of Function		:   Slot for broadcast storm threshold
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   arg1
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_spinBox_broadcastStormThreshold_valueChanged(int siArg1)
{

    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,9, QModelIndex());
            if(ui->spinBox_broadcastStormThreshold->isEnabled())
                SwitchConfiguration.aucbcStormThresold[i] = siArg1;
            QStandardItemModelModels->setData(newIndex, siArg1, Qt::EditRole);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,9, QModelIndex());
                    if(ui->spinBox_broadcastStormThreshold->isEnabled())
                        SwitchConfiguration.aucbcStormThresold[i] = siArg1;
                    QStandardItemModelModels->setData(newIndex, siArg1, Qt::EditRole);
                    siUpdatePara = 0;
                    //break;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_multicastStormProtection_currentIndexChanged
Function/DLD ID         :   SWR_MW_43
Purpose of Function		:   Slot for multicast storm protection
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_multicastStormProtection_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,10, QModelIndex());
            if(ui->comboBox_multicastStormProtection->isEnabled())
                SwitchConfiguration.aucmcStormStatus[i] = siIndex;
            QStandardItemModelModels->setData(newIndex, ui->comboBox_multicastStormProtection->itemText(siIndex), Qt::EditRole);
            setupGreyedOutParameters(checkTypeofPort(i));
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,10, QModelIndex());
                    if(ui->comboBox_multicastStormProtection->isEnabled())
                        SwitchConfiguration.aucmcStormStatus[i] = siIndex;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_multicastStormProtection->itemText(siIndex), Qt::EditRole);
                    setupGreyedOutParameters(checkTypeofPort(i));
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_spinBox_multicastStormThreshold_valueChanged
Function/DLD ID         :   SWR_MW_44
Purpose of Function		:   Slot for multicast storm threshold
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   arg1
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_spinBox_multicastStormThreshold_valueChanged(int siArg1)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,11, QModelIndex());
            if(ui->spinBox_multicastStormThreshold->isEnabled())
                SwitchConfiguration.aucmcStormThresold[i] = siArg1;
            QStandardItemModelModels->setData(newIndex, siArg1, Qt::EditRole);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,11, QModelIndex());
                    if(ui->spinBox_multicastStormThreshold->isEnabled())
                        SwitchConfiguration.aucmcStormThresold[i] = siArg1;
                    QStandardItemModelModels->setData(newIndex, siArg1, Qt::EditRole);
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_jumboFrames_currentIndexChanged
Function/DLD ID         :   SWR_MW_45
Purpose of Function		:   Slot for jumbo frame
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_jumboFrames_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,12, QModelIndex());
            if(ui->comboBox_jumboFrames->isEnabled())
                SwitchConfiguration.aucjumboFrameStatus[i] = siIndex;
            QStandardItemModelModels->setData(newIndex, ui->comboBox_jumboFrames->itemText(siIndex), Qt::EditRole);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,12, QModelIndex());
                    if(ui->comboBox_jumboFrames->isEnabled())
                        SwitchConfiguration.aucjumboFrameStatus[i] = siIndex;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_jumboFrames->itemText(siIndex), Qt::EditRole);
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_qosTrustMode_currentIndexChanged
Function/DLD ID         :   SWR_MW_46
Purpose of Function		:   Slot for qos trust mode
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_qosTrustMode_currentIndexChanged(int siIndex)
{

    siUpdatePara = 1;
    for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort);i++)
    {
        QModelIndex newIndex;
        newIndex = QStandardItemModelModels->index(i,13, QModelIndex());
        if((ui->comboBox_qosTrustMode->isEnabled()))
        {
            SwitchConfiguration.aucTrustMode[i] = siIndex;
            QStandardItemModelModels->setData(newIndex, ui->comboBox_qosTrustMode->itemText(siIndex), Qt::EditRole);
        }
        //test: JG Grey Out Port Priority for trustdot1p & trustDSCP
        QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
        if(!l_strportno.isNull())
        {
            if(l_strportno.contains("2px")&&ui->comboBox_qosTrustMode->currentIndex()==0)
            {
                ui->label_portpriority->setEnabled(true);
                ui->comboBox_portpriority->setEnabled(true);
            }
            else
            {
                ui->label_portpriority->setDisabled(true);
                ui->comboBox_portpriority->setDisabled(true);
            }
        }
        else
        {
            ui->label_portpriority->setDisabled(true);
            ui->comboBox_portpriority->setDisabled(true);
        }
    }

    SwitchConfiguration.globalTrustMode = siIndex;
    siUpdatePara = 0;


    //TEST Issue Fix 30072 - making QoS Trust Mode a global setting
//    if(ui->radioButton_selectAll->isChecked())
//    {
//        siUpdatePara = 1;
//        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort);i++)
//        {
//            QModelIndex newIndex;
//            newIndex = QStandardItemModelModels->index(i,13, QModelIndex());
//            if((ui->comboBox_qosTrustMode->isEnabled()))
//            {
//                SwitchConfiguration.aucTrustMode[i] = siIndex;
//                QStandardItemModelModels->setData(newIndex, ui->comboBox_qosTrustMode->itemText(siIndex), Qt::EditRole);
//            }
//        }
//        siUpdatePara = 0;
//    }
//    else
//    {
//        for(int i=0;i<MAX_NO_OF_PORTS;i++)
//        {
//            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
//            if(!l_strportno.isNull())
//            {
//                if(l_strportno.contains("2px"))
//                {
//                    siUpdatePara = 1;
//                    QModelIndex newIndex;
//                    newIndex = QStandardItemModelModels->index(i,13, QModelIndex());
//                    if(ui->comboBox_qosTrustMode->isEnabled())
//                    {
//                        SwitchConfiguration.aucTrustMode[i] = siIndex;
//                        QStandardItemModelModels->setData(newIndex, ui->comboBox_qosTrustMode->itemText(siIndex), Qt::EditRole);
//                    }
//                    siUpdatePara = 0;
//                }
//            }
//        }
//    }


}

/***********************************************************************
Function Name			:	on_comboBox_portpriority_currentIndexChanged
Function/DLD ID         :   SWR_MW_46
Purpose of Function		:   Slot for Port Priority
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_portpriority_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< g_CurrentProductInfo.m_ucnoOfPort;i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,14, QModelIndex());
            if((ui->comboBox_portpriority->isEnabled()))
            {
                SwitchConfiguration.aucportBasedQoS[i] = siIndex;
                QStandardItemModelModels->setData(newIndex, ui->comboBox_portpriority->itemText(siIndex), Qt::EditRole);
            }
            setupGreyedOutParameters(checkTypeofPort(i));
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,14, QModelIndex());
                    if(ui->comboBox_portpriority->isEnabled())
                    {
                        SwitchConfiguration.aucportBasedQoS[i] = siIndex;
                        QStandardItemModelModels->setData(newIndex, ui->comboBox_portpriority->itemText(siIndex), Qt::EditRole);
                    }
                    siUpdatePara = 0;
                }
            }
        }
    }

}

/***********************************************************************
Function Name			:	on_comboBox_eee_currentIndexChanged
Function/DLD ID         :   SWR_MW_47
Purpose of Function		:   Slot for EEE
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_eee_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            QModelIndex newIndex;
            newIndex = QStandardItemModelModels->index(i,15, QModelIndex());
            if(ui->comboBox_eee->isEnabled())
                SwitchConfiguration.aucEEEStatus[i] = siIndex;
            QStandardItemModelModels->setData(newIndex, ui->comboBox_eee->itemText(siIndex), Qt::EditRole);
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,15, QModelIndex());
                    if(ui->comboBox_eee->isEnabled())
                        SwitchConfiguration.aucEEEStatus[i] = siIndex;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_eee->itemText(siIndex), Qt::EditRole);
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_poeAdminState_currentIndexChanged
Function/DLD ID         :   SWR_MW_48
Purpose of Function		:   Slot for poe admin state
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_poeAdminState_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            if(g_CurrentProductInfo.m_ucproductId == 101 && i == 0)     //port 1 of OCT8TxPoe is non POE
                i++;
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,16, QModelIndex());
                    if(ui->comboBox_poeAdminState->isEnabled())
                        SwitchConfiguration.aucpoeStatus[i] = siIndex;
                    //qDebug()<< " poe status in buffer "<<SwitchConfiguration.aucpoeStatus[i];
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_poeAdminState->itemText(siIndex), Qt::EditRole);
                    setupGreyedOutParameters(checkTypeofPort(i));
                }
            }
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,16, QModelIndex());
                    if(ui->comboBox_poeAdminState->isEnabled())
                        SwitchConfiguration.aucpoeStatus[i] = siIndex;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_poeAdminState->itemText(siIndex), Qt::EditRole);
                    setupGreyedOutParameters(checkTypeofPort(i));
                    siUpdatePara = 0;
                    //break;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_poePriority_currentIndexChanged
Function/DLD ID         :   SWR_MW_49
Purpose of Function		:   Slot for poe priority
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_poePriority_currentIndexChanged(int siIndex)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            if(g_CurrentProductInfo.m_ucproductId == 101 && i == 0)     //port 1 of OCT8TxPoe is non POE
                i++;
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,17, QModelIndex());
                    if(ui->comboBox_poePriority->isEnabled())
                        SwitchConfiguration.aucpoePriority[i] = siIndex+1;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_poePriority->itemText(siIndex), Qt::EditRole);
                }
            }
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,17, QModelIndex());
                    if(ui->comboBox_poePriority->isEnabled())
                        SwitchConfiguration.aucpoePriority[i] = siIndex+1;
                    QStandardItemModelModels->setData(newIndex, ui->comboBox_poePriority->itemText(siIndex), Qt::EditRole);
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	on_lineEdit_allowedPoEClasses_textChanged
Function/DLD ID         :   SWR_MW_50
Purpose of Function		:   Slot for allowed poe classes
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   QString
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_lineEdit_allowedPoEClasses_textChanged(const QString &QStringArg1)
{

    //qDebug()<<"on_lineEdit_allowedPoEClasses_textChanged : "<<QStringArg1;

    if(ui->lineEdit_allowedPoEClasses->isEnabled())
    {
        QString tempString = QStringArg1;
        unsigned char length = tempString.length();
        QChar  tempChar;
        static QString previousString;
        bool validString = true;
        if(length > 2)
        {
            for(int i = 1; i < (length-1); i= i+2)
            {
                if(tempString.at(i) != ',')
                    validString = false;
            }
            if(validString == false)
                ui->lineEdit_allowedPoEClasses->setText(previousString);
        }
        if(length && (validString == true))
        {
            tempChar = tempString.at(length -1);
            if(length > 9)
            {
                tempString.chop(1);
                ui->lineEdit_allowedPoEClasses->setText(tempString);
            }
            else
            {
                if((tempChar == '0') || (tempChar == '1') ||(tempChar == '2') ||(tempChar == '3') ||(tempChar == '4'))
                {
                    if(length > 1 && ((length %2) == 0))
                    {
                        tempString.chop(1);
                        if(!tempString.contains(tempChar))
                            ui->lineEdit_allowedPoEClasses->setText(tempString + "," + tempChar);
                        else
                            ui->lineEdit_allowedPoEClasses->setText(previousString);
                    }
                }
                else if(tempChar == ',')
                {
                    if((length %2) == 0 || (length == 1))
                    {
                        tempString.chop(1);
                        ui->lineEdit_allowedPoEClasses->setText(tempString);
                    }
                }
                else
                {
                    tempString.chop(1);
                    ui->lineEdit_allowedPoEClasses->setText(tempString);
                }
            }

            previousString = ui->lineEdit_allowedPoEClasses->text();

            if(ui->radioButton_selectAll->isChecked())
            {
                siUpdatePara = 1;
                for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
                {
                    if(g_CurrentProductInfo.m_ucproductId == 101 && i == 0)     //port 1 of OCT8TxPoe is non POE
                        i++;
                    QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
                    if(!l_strportno.isNull())
                    {
                        if(l_strportno.contains("2px"))
                        {
                            QModelIndex newIndex;
                            newIndex = QStandardItemModelModels->index(i,18, QModelIndex());
                            if(ui->lineEdit_allowedPoEClasses->isEnabled())
                            {
                                QString temp = ui->lineEdit_allowedPoEClasses->text();
                                for(int j=0;j<8;j++)
                                     SwitchConfiguration.aucpoeAllowedClasses[i][j] = 255;
                                QStringList allowedClassesValue = temp.split(",");
                                for(int j=0;j<allowedClassesValue.length();j++)
                                    SwitchConfiguration.aucpoeAllowedClasses[i][j] = allowedClassesValue[j].toInt();
                            }
							QStandardItemModelModels->setData(newIndex, ui->lineEdit_allowedPoEClasses->text(), Qt::EditRole);
                        }
                    }
                }
                siUpdatePara = 0;
            }
            else
            {
                for(int i=0;i<MAX_NO_OF_PORTS;i++)
                {
                    QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
                    if(!l_strportno.isNull())
                    {
                        if(l_strportno.contains("2px"))
                        {
                            siUpdatePara = 1;
                            QModelIndex newIndex;
                            newIndex = QStandardItemModelModels->index(i,18, QModelIndex());
                            if(ui->lineEdit_allowedPoEClasses->isEnabled())
                            {
                                QString temp = ui->lineEdit_allowedPoEClasses->text();
                                QStringList allowedClassesValue = temp.split(",");
                                for(int j=0;j<8;j++)
                                    SwitchConfiguration.aucpoeAllowedClasses[i][j] = 0xFF;
                                for(int j=0;j<allowedClassesValue.length();j++)
                                    SwitchConfiguration.aucpoeAllowedClasses[i][j] = allowedClassesValue[j].toInt();
                            }
                            QStandardItemModelModels->setData(newIndex, ui->lineEdit_allowedPoEClasses->text(), Qt::EditRole);
                            siUpdatePara = 0;
                        }
                    }
                }
            }
        }
    }
    else
    {
        ui->lineEdit_allowedPoEClasses->setText("-");

        if(ui->radioButton_selectAll->isChecked())
        {
            siUpdatePara = 1;
            for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
            {
                QModelIndex newIndex;
                newIndex = QStandardItemModelModels->index(i,18, QModelIndex());
                if(ui->lineEdit_allowedPoEClasses->isEnabled())
                {
                    if(g_CurrentProductInfo.m_ucproductId == 101 && i == 0)     //port 1 of OCT8TxPoe is non POE
                        i++;
                    QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
                    if(!l_strportno.isNull())
                    {
                        if(l_strportno.contains("2px"))
                        {
                             //QString temp = ui->lineEdit_allowedPoEClasses->text();
                            for(int j=0;j<8;j++)
                                SwitchConfiguration.aucpoeAllowedClasses[i][j] = 255;
                            //QStringList allowedClassesValue = temp.split(",");
//                          for(int j=0;j<allowedClassesValue.length();j++)
//                              SwitchConfiguration.aucpoeAllowedClasses[i][j] = allowedClassesValue[j].toInt();
                        }
                    }
                }
                QStandardItemModelModels->setData(newIndex, ui->lineEdit_allowedPoEClasses->text(), Qt::EditRole);
            }
            siUpdatePara = 0;
        }
        else
        {
            for(int i=0;i<MAX_NO_OF_PORTS;i++)
            {
                QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
                if(!l_strportno.isNull())
                {
                    if(l_strportno.contains("2px"))
                    {
                        siUpdatePara = 1;
                        QModelIndex newIndex;
                        newIndex = QStandardItemModelModels->index(i,18, QModelIndex());
                        if(!ui->lineEdit_allowedPoEClasses->isEnabled())
                        {
                            //QString temp = ui->lineEdit_allowedPoEClasses->text();
                            //QStringList allowedClassesValue = temp.split(",");
                            for(int j=0;j<8;j++)
                               SwitchConfiguration.aucpoeAllowedClasses[i][j] = 0xFF;
                            //for(int j=0;j<allowedClassesValue.length();j++)
                                //SwitchConfiguration.aucpoeAllowedClasses[i][j] = allowedClassesValue[j].toInt();
                        }
                        QStandardItemModelModels->setData(newIndex, ui->lineEdit_allowedPoEClasses->text(), Qt::EditRole);
                        siUpdatePara = 0;
                    }
                }
            }
        }
    }
}


/***********************************************************************
Function Name			:	on_spinBox_allowedPoEOverride_valueChanged
Function/DLD ID         :
Purpose of Function		:   for poe allowed override 
Author/Date     		: 	J.Greiss
Modified by/Date		:
Calls                   :
Inputs                  :   int
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_spinBox_allowedPoEOverride_valueChanged(int siArg1)
{
    if(ui->radioButton_selectAll->isChecked())
    {
        siUpdatePara = 1;
        for(int i=0;i< (g_CurrentProductInfo.m_ucnoOfPort-g_CurrentProductInfo.m_ucnoOfFiberPort);i++)
        {
            if(g_CurrentProductInfo.m_ucproductId == 101 && i == 0)     //port 1 of OCT8TxPoe is non POE
                i++;
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,19, QModelIndex());
                    if(ui->spinBox_allowedPoEOverride->isEnabled())
                        SwitchConfiguration.aucpoeAllowedConsumptionOverride[i] = siArg1;

                    //only show numbers when value is not 0, when 0 show -
                    if(siArg1 == 0)
                        QStandardItemModelModels->setData(newIndex, "-", Qt::EditRole);
                    else
                        QStandardItemModelModels->setData(newIndex, siArg1, Qt::EditRole);
                }
            }
        }
        siUpdatePara = 0;
    }
    else
    {
        for(int i=0;i<MAX_NO_OF_PORTS;i++)
        {
            QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
            if(!l_strportno.isNull())
            {
                if(l_strportno.contains("2px"))
                {
                    siUpdatePara = 1;
                    QModelIndex newIndex;
                    newIndex = QStandardItemModelModels->index(i,19, QModelIndex());
                    if(ui->spinBox_allowedPoEOverride->isEnabled())
                        SwitchConfiguration.aucpoeAllowedConsumptionOverride[i] = siArg1;

                    //only show numbers when value is not 0, when 0 show -
                    if(siArg1 == 0)
                        QStandardItemModelModels->setData(newIndex, "-", Qt::EditRole);
                    else
                        QStandardItemModelModels->setData(newIndex, siArg1, Qt::EditRole);
                    siUpdatePara = 0;
                }
            }
        }
    }
}
/***********************************************************************
Function Name			:	createNewTable
Function/DLD ID         :   SWR_MW_51
Purpose of Function		:   create new table for port parameters
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   int noOfPorts
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::createNewTable(int siNoOfPorts)
{
    if((siNoOfPorts>= 0)&&(siNoOfPorts < MAX_NO_OF_PORTS))
    {

        ui->tableView_portSettings->setDragEnabled(false);
        ui->tableView_portSettings->setTabKeyNavigation(false);
        ui->tableView_portSettings->clearFocus();
        ui->tableView_portSettings->setSelectionMode(QAbstractItemView::SingleSelection);

        QStandardItemModelModels = new QStandardItemModel(siNoOfPorts,MAX_NO_OF_PARAMETERS);//no_of_parameters);
        ui->tableView_portSettings->setModel(QStandardItemModelModels);

        int tablewidth;
#if LINUX
        tablewidth = 85;
#else
        tablewidth = 80;
#endif
        for(int i=0;i<MAX_NO_OF_PARAMETERS;i++)
            ui->tableView_portSettings->setColumnWidth(i,tablewidth);
        QStringList list;
        for(int i=0; i < siNoOfPorts ; i++ )
            list = list << ("Port " + QString::number(i+1));
        QStandardItemModelModels->setVerticalHeaderLabels(list);

        list.clear();


        /* set correct order of headers - regarding port settings in main window above.
         * table columns need to be switched as well! - JG 08.08.2016 - Issue 28935 */

           list=(QStringList() << "Port\nState"       << "Link\nAlarm"
              << "Auto\nNegotiation"              << "Speed"
              << "Duplex\nMode"       << "Auto\nCrossing"
              << "MDI\nState"         << "Flow\nControl"
              << "Broadcast\nMode" << "Broadcast\nThreshold"
              << "Multicast\nMode" << "Multicast\nThreshold"
              << "Jumbo\nFrames"       << "QoS\nTrust\nMode"
              << "Port\nPriority"
              << "Energy\nEfficient\nEthernet"    << "PoE\nState"
              << "PoE\nPriority"       << "PoE\nClasses" << "PoE\nUser Set\nLimit [W]");



        QStandardItemModelModels->setHorizontalHeaderLabels(list);

        ui->tableView_portSettings->verticalHeader()->setFixedWidth(60);

        ComboBoxDelegateComboBox = new ComboBoxDelegate();
        SpinBoxDelegateSpinBox = new SpinBoxDelegate();
        LineEditDelegateLineEdit = new LineEditDelegate();

        connect(ComboBoxDelegateComboBox,SIGNAL(currentValueofCombo(QString)),this,SLOT(currentIndexChangedfromTable(QString)), Qt::UniqueConnection);
        connect(SpinBoxDelegateSpinBox,SIGNAL(currentValueChanged(QString)),this,SLOT(currentIndexChangedfromTable(QString)),Qt::UniqueConnection);
        connect(LineEditDelegateLineEdit,SIGNAL(currentValueChanged(QString)),this,SLOT(currentIndexChangedfromTable(QString)),Qt::UniqueConnection);

        for(int i=0;i<9;i++)
            ui->tableView_portSettings->setItemDelegateForColumn(i,ComboBoxDelegateComboBox);

        ui->tableView_portSettings->setItemDelegateForColumn(9,SpinBoxDelegateSpinBox);
        ui->tableView_portSettings->setItemDelegateForColumn(10,ComboBoxDelegateComboBox);
        ui->tableView_portSettings->setItemDelegateForColumn(11,SpinBoxDelegateSpinBox);
        for(int i=12;i< 18;i++)
            ui->tableView_portSettings->setItemDelegateForColumn(i,ComboBoxDelegateComboBox);
        ui->tableView_portSettings->setItemDelegateForColumn(18,LineEditDelegateLineEdit);
        ui->tableView_portSettings->setItemDelegateForColumn(19,SpinBoxDelegateSpinBox);
        connect(ui->tableView_portSettings, SIGNAL(clicked(QModelIndex)),this,SLOT(currentCellSelected(QModelIndex)),Qt::UniqueConnection);
    }
}
/***********************************************************************
Function Name			:	currentCellSelected
Function/DLD ID         :   SWR_MW_52
Purpose of Function		:   Process current cell selected
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   QModelIndex index
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::currentCellSelected(QModelIndex QModelIndexIndex)
{
    boolTableClickflag = true;
    updatePortTableUserInterface();
    oldValue = QStandardItemModelModels->data(QModelIndexIndex);
    radioSelectAll(false);
    radioDeselectAll(false);
}
/***********************************************************************
Function Name			:	currentIndexChangedfromTable
Function/DLD ID         :   SWR_MW_53
Purpose of Function		:   Process current cell selected
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   QString currentValue
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::currentIndexChangedfromTable(QString QStringCurrentValue)
{
    int row = ui->tableView_portSettings->currentIndex().row();
    int column = ui->tableView_portSettings->currentIndex().column();
    int selectedPort = 0;

    for(int i=0;i<MAX_NO_OF_PORTS;i++)
    {
        QString l_strportno = clickQlabelQLabelPort[i]->styleSheet();
        if(!l_strportno.isNull())
        {
            if(l_strportno.contains("2px"))
                selectedPort = i;
        }
    }
    if(selectedPort != row)
    {
        label_singleclick(row);
    }
    else
    {

    }

    radioSelectAll(false);
    radioDeselectAll(false);

    switch(column)
    {
    case 0:
        if(siUpdatePara)
            return;
        if(ui->comboBox_adminState->isEnabled())
        {
            ui->comboBox_adminState->setCurrentIndex(ui->comboBox_adminState->findText(QStringCurrentValue));
            SwitchConfiguration.aucadminState[row] = ui->comboBox_adminState->currentIndex();
        }
        break;
    case 1:
        if(siUpdatePara)
            return;
        if(ui->comboBox_alarmLink->isEnabled())
        {
            ui->comboBox_alarmLink->setCurrentIndex(ui->comboBox_alarmLink->findText(QStringCurrentValue));
            SwitchConfiguration.auclinkAlarmStatus[row] = ui->comboBox_alarmLink->currentIndex();
        }
        break;
    case 2:
        // order before Layout changes - JG 9.8.2016 - changed from speed to AutoNeg - Issue 28935
        if(siUpdatePara)
            return;
        if(ui->comboBox_autoNeg->isEnabled())
        {
            ui->comboBox_autoNeg->setCurrentIndex(ui->comboBox_autoNeg->findText(QStringCurrentValue));
            SwitchConfiguration.aucautonegStatus[row] = ui->comboBox_autoNeg->currentIndex();
        }
        break;
    case 3:
        // order matching Layout changes - JG 9.8.2016 - changed from AutoNeg to speed - Issue 28935
        if(siUpdatePara)
            return;
        if(ui->comboBox_speed->isEnabled())
        {
            ui->comboBox_speed->setCurrentIndex(ui->comboBox_speed->findText(QStringCurrentValue));
            SwitchConfiguration.aucspeed[row] = ui->comboBox_speed->currentIndex()+1;

        }
        break;
    case 4:
        // order matching Layout changes - JG 9.8.2016 - changed from AutoCrossing to DuplexMode - Issue 28935
        if(siUpdatePara)
            return;
        if(ui->comboBox_duplexMode->isEnabled())
        {
            ui->comboBox_duplexMode->setCurrentIndex(ui->comboBox_duplexMode->findText(QStringCurrentValue));
            SwitchConfiguration.aucduplexMode[row] = ui->comboBox_duplexMode->currentIndex()+1;
        }
        break;
    case 5:
        // order matching Layout changes - JG 9.8.2016 - changed from DuplexMode to Autocrossing - Issue 28935
        if(siUpdatePara)
            return;
        if(ui->comboBox_autoCrossing->isEnabled())
        {
            ui->comboBox_autoCrossing->setCurrentIndex(ui->comboBox_autoCrossing->findText(QStringCurrentValue));
            SwitchConfiguration.aucautoCrossingstatus[row] = ui->comboBox_autoCrossing->currentIndex();
        }
        break;
    case 6:
        if(siUpdatePara)
            return;
        if(ui->comboBox_mdiState->isEnabled())
        {
            ui->comboBox_mdiState->setCurrentIndex(ui->comboBox_mdiState->findText(QStringCurrentValue));
            SwitchConfiguration.aucMdistatus[row] = ui->comboBox_mdiState->currentIndex();
        }
        break;
    case 7:
        if(siUpdatePara)
            return;
        if(ui->comboBox_flowControl->isEnabled())
        {
            ui->comboBox_flowControl->setCurrentIndex(ui->comboBox_flowControl->findText(QStringCurrentValue));
            SwitchConfiguration.aucflowControlStatus[row] = ui->comboBox_flowControl->currentIndex();
        }
        break;
    case 8:
        if(siUpdatePara)
            return;
        if(ui->comboBox_broadcastStormProtection->isEnabled())
        {
            ui->comboBox_broadcastStormProtection->setCurrentIndex(ui->comboBox_broadcastStormProtection->findText(QStringCurrentValue));
            SwitchConfiguration.aucbcStormStatus[row] = ui->comboBox_broadcastStormProtection->currentIndex();
        }
        break;
    case 9:
        if(siUpdatePara)
            return;
        if(ui->spinBox_broadcastStormThreshold->isEnabled())
        {
            ui->spinBox_broadcastStormThreshold->setValue(QStringCurrentValue.toInt());
            SwitchConfiguration.aucbcStormThresold[row] = ui->spinBox_broadcastStormThreshold->value();
        }
        break;
    case 10:
        if(siUpdatePara)
            return;
        if(ui->comboBox_multicastStormProtection->isEnabled())
        {
            ui->comboBox_multicastStormProtection->setCurrentIndex(ui->comboBox_multicastStormProtection->findText(QStringCurrentValue));
            SwitchConfiguration.aucmcStormStatus[row] = ui->comboBox_multicastStormProtection->currentIndex();
        }
        break;
    case 11:
        if(siUpdatePara)
            return;
        if(ui->spinBox_multicastStormThreshold->isEnabled())
        {
            ui->spinBox_multicastStormThreshold->setValue(QStringCurrentValue.toInt());
            SwitchConfiguration.aucmcStormThresold[row] = ui->spinBox_multicastStormThreshold->value();
        }
        break;
    case 12:
        if(siUpdatePara)
            return;
        if(ui->comboBox_jumboFrames->isEnabled())
        {
            ui->comboBox_jumboFrames->setCurrentIndex(ui->comboBox_jumboFrames->findText(QStringCurrentValue));
            SwitchConfiguration.aucjumboFrameStatus[row] = ui->comboBox_jumboFrames->currentIndex();
        }
        break;
    case 13:
        if(siUpdatePara)
            return;
        if(ui->comboBox_qosTrustMode->isEnabled())
        {
            for (int i=0;i<g_CurrentProductInfo.m_ucnoOfPort;i++)

            {
                ui->comboBox_qosTrustMode->setCurrentIndex(ui->comboBox_qosTrustMode->findText(QStringCurrentValue));
                SwitchConfiguration.aucTrustMode[row] = ui->comboBox_qosTrustMode->currentIndex();
                SwitchConfiguration.aucportBasedQoS[i]=0;
                oldValue = 0;


            }
            setupGreyedOutParameters(TP_FE_PORT_SELECTED);
            updatePortTableUserInterface();
        }

        break;

    case 14:
        if(siUpdatePara)
            return;
        if(ui->comboBox_portpriority->isEnabled())
        {
            for (int i=0;i<MAX_NO_OF_PORTS;i++)

            {
                if(ui->comboBox_qosTrustMode->currentIndex()!=0)
                {

                    {
                        ui->comboBox_portpriority->setCurrentIndex(ui->comboBox_portpriority->findText(QStringCurrentValue));
                        SwitchConfiguration.aucportBasedQoS[i]=0;

                    }
                }
                else
                {
                    ui->comboBox_portpriority->setCurrentIndex(ui->comboBox_portpriority->findText(QStringCurrentValue));
                    SwitchConfiguration.aucportBasedQoS[row] = ui->comboBox_portpriority->currentIndex();
                }
            }
            updatePortTableUserInterface();
        }
        break;


    case 15:
        if(siUpdatePara)
            return;
        if(ui->comboBox_eee->isEnabled())
        {
            ui->comboBox_eee->setCurrentIndex(ui->comboBox_eee->findText(QStringCurrentValue));
            SwitchConfiguration.aucEEEStatus[row] = ui->comboBox_eee->currentIndex();
        }
        break;
    case 16:
        if(siUpdatePara)
            return;
        if(ui->comboBox_poeAdminState->isEnabled())
        {
            ui->comboBox_poeAdminState->setCurrentIndex(ui->comboBox_poeAdminState->findText(QStringCurrentValue));
            SwitchConfiguration.aucpoeStatus[row] = ui->comboBox_poeAdminState->currentIndex();
            //qDebug()<<"poestatus in buffer : "<<SwitchConfiguration.aucpoeStatus[row];
        }
        break;
    case 17:
        if(siUpdatePara)
            return;
        if(ui->comboBox_poePriority->isEnabled())
        {
            ui->comboBox_poePriority->setCurrentIndex(ui->comboBox_poePriority->findText(QStringCurrentValue));
            SwitchConfiguration.aucpoePriority[row] = ui->comboBox_poePriority->currentIndex()+1;
        }
        break;
    case 18:
        if(siUpdatePara)
            return;
        if(ui->lineEdit_allowedPoEClasses->isEnabled())
        {
            QString temp = QStringCurrentValue;
            QStringList allowedClassesValue = temp.split(",");
            for(int j=0;j<allowedClassesValue.length();j++)
                SwitchConfiguration.aucpoeAllowedClasses[row][j] = allowedClassesValue[j].toInt();
            ui->lineEdit_allowedPoEClasses->setText(QStringCurrentValue);
        }
        break;
    case 19:
        if(siUpdatePara)
            return;
        if(ui->spinBox_allowedPoEOverride->isEnabled())
        {
            ui->spinBox_allowedPoEOverride->setValue(QStringCurrentValue.toInt());
            SwitchConfiguration.aucpoeAllowedConsumptionOverride[row] = ui->spinBox_allowedPoEOverride->value();
        }
        break;
    default:
        break;
    }
}
/***********************************************************************
Function Name			:	configureDefaultData
Function/DLD ID         :   SWR_MW_54
Purpose of Function		:   Create default buffer
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::configureDefaultData()
{
    // Default is same for all model of product
    // Port value will be same for all ports

    for(int i=0;i <8;i++)
        g_DefaultData.aucreleaseNo[i] = DEFAULT_RELEASEFILE;//'\0';

    g_DefaultData.aucalarmPsu[0] = DEFAULT_AUCALARMPSU1;
    g_DefaultData.aucalarmPsu[1] = DEFAULT_AUCALARMPSU2;
    g_DefaultData.agingTime = DEFAULT_AGEINGTIME;

    g_DefaultData.aucdotp1PcpToTc[0] = DEFAULT_DOTP0;
    g_DefaultData.aucdotp1PcpToTc[1] = DEFAULT_DOTP1;
    g_DefaultData.aucdotp1PcpToTc[2] = DEFAULT_DOTP2;
    g_DefaultData.aucdotp1PcpToTc[3] = DEFAULT_DOTP3;
    g_DefaultData.aucdotp1PcpToTc[4] = DEFAULT_DOTP4;
    g_DefaultData.aucdotp1PcpToTc[5] = DEFAULT_DOTP5;
    g_DefaultData.aucdotp1PcpToTc[6] = DEFAULT_DOTP6;
    g_DefaultData.aucdotp1PcpToTc[7] = DEFAULT_DOTP7;

    g_DefaultData.aucdscpD1D2[0]    = DEFAULT_DSCP0;
    g_DefaultData.aucdscpD1D2[1]    = DEFAULT_DSCP1;
    g_DefaultData.aucdscpD1D2[2]    = DEFAULT_DSCP2;
    g_DefaultData.aucdscpD1D2[3]    = DEFAULT_DSCP3;
    g_DefaultData.aucdscpD1D2[4]    = DEFAULT_DSCP4;
    g_DefaultData.aucdscpD1D2[5]    = DEFAULT_DSCP5;
    g_DefaultData.aucdscpD1D2[6]    = DEFAULT_DSCP6;
    g_DefaultData.aucdscpD1D2[7]    = DEFAULT_DSCP7;
    g_DefaultData.aucdscpD1D2[8]    = DEFAULT_DSCP8;
    g_DefaultData.aucdscpD1D2[9]    = DEFAULT_DSCP9;
    g_DefaultData.aucdscpD1D2[10]    = DEFAULT_DSCP10;
    g_DefaultData.aucdscpD1D2[11]    = DEFAULT_DSCP11;
    g_DefaultData.aucdscpD1D2[12]    = DEFAULT_DSCP12;
    g_DefaultData.aucdscpD1D2[13]    = DEFAULT_DSCP13;
    g_DefaultData.aucdscpD1D2[14]    = DEFAULT_DSCP14;
    g_DefaultData.aucdscpD1D2[15]    = DEFAULT_DSCP15;
    g_DefaultData.aucdscpD1D2[16]    = DEFAULT_DSCP16;
    g_DefaultData.aucdscpD1D2[17]    = DEFAULT_DSCP17;
    g_DefaultData.aucdscpD1D2[18]    = DEFAULT_DSCP18;
    g_DefaultData.aucdscpD1D2[19]    = DEFAULT_DSCP19;
    g_DefaultData.aucdscpD1D2[20]    = DEFAULT_DSCP20;
    g_DefaultData.aucdscpD1D2[21]    = DEFAULT_DSCP21;
    g_DefaultData.aucdscpD1D2[22]    = DEFAULT_DSCP22;
    g_DefaultData.aucdscpD1D2[23]    = DEFAULT_DSCP23;
    g_DefaultData.aucdscpD1D2[24]    = DEFAULT_DSCP24;
    g_DefaultData.aucdscpD1D2[25]    = DEFAULT_DSCP25;
    g_DefaultData.aucdscpD1D2[26]    = DEFAULT_DSCP26;
    g_DefaultData.aucdscpD1D2[27]    = DEFAULT_DSCP27;
    g_DefaultData.aucdscpD1D2[28]    = DEFAULT_DSCP28;
    g_DefaultData.aucdscpD1D2[29]    = DEFAULT_DSCP29;
    g_DefaultData.aucdscpD1D2[30]    = DEFAULT_DSCP30;
    g_DefaultData.aucdscpD1D2[31]    = DEFAULT_DSCP31;
    g_DefaultData.aucdscpD1D2[32]    = DEFAULT_DSCP32;
    g_DefaultData.aucdscpD1D2[33]    = DEFAULT_DSCP33;
    g_DefaultData.aucdscpD1D2[34]    = DEFAULT_DSCP34;
    g_DefaultData.aucdscpD1D2[35]    = DEFAULT_DSCP35;
    g_DefaultData.aucdscpD1D2[36]    = DEFAULT_DSCP36;
    g_DefaultData.aucdscpD1D2[37]    = DEFAULT_DSCP37;
    g_DefaultData.aucdscpD1D2[38]    = DEFAULT_DSCP38;
    g_DefaultData.aucdscpD1D2[39]    = DEFAULT_DSCP39;
    g_DefaultData.aucdscpD1D2[40]    = DEFAULT_DSCP40;
    g_DefaultData.aucdscpD1D2[41]    = DEFAULT_DSCP41;
    g_DefaultData.aucdscpD1D2[42]    = DEFAULT_DSCP42;
    g_DefaultData.aucdscpD1D2[43]    = DEFAULT_DSCP43;
    g_DefaultData.aucdscpD1D2[44]    = DEFAULT_DSCP44;
    g_DefaultData.aucdscpD1D2[45]    = DEFAULT_DSCP45;
    g_DefaultData.aucdscpD1D2[46]    = DEFAULT_DSCP46;
    g_DefaultData.aucdscpD1D2[47]    = DEFAULT_DSCP47;
    g_DefaultData.aucdscpD1D2[48]    = DEFAULT_DSCP48;
    g_DefaultData.aucdscpD1D2[49]    = DEFAULT_DSCP49;
    g_DefaultData.aucdscpD1D2[50]    = DEFAULT_DSCP50;
    g_DefaultData.aucdscpD1D2[51]    = DEFAULT_DSCP51;
    g_DefaultData.aucdscpD1D2[52]    = DEFAULT_DSCP52;
    g_DefaultData.aucdscpD1D2[53]    = DEFAULT_DSCP53;
    g_DefaultData.aucdscpD1D2[54]    = DEFAULT_DSCP54;
    g_DefaultData.aucdscpD1D2[55]    = DEFAULT_DSCP55;
    g_DefaultData.aucdscpD1D2[56]    = DEFAULT_DSCP56;
    g_DefaultData.aucdscpD1D2[57]    = DEFAULT_DSCP57;
    g_DefaultData.aucdscpD1D2[58]    = DEFAULT_DSCP58;
    g_DefaultData.aucdscpD1D2[59]    = DEFAULT_DSCP59;
    g_DefaultData.aucdscpD1D2[60]    = DEFAULT_DSCP60;
    g_DefaultData.aucdscpD1D2[61]    = DEFAULT_DSCP61;
    g_DefaultData.aucdscpD1D2[62]    = DEFAULT_DSCP62;
    g_DefaultData.aucdscpD1D2[63]    = DEFAULT_DSCP63;

    g_DefaultData.aucflowControlStatus = DEFAULT_FLOWCONTROL;
    g_DefaultData.aucadminState = DEFAULT_ADMINSTATE;
    g_DefaultData.aucjumboFrameStatus = DEFAULT_JUMBOFRAME;

    g_DefaultData.aucbcStormStatus = DEFAULT_BCSTORMSTATUS;
    g_DefaultData.aucbcStormThresold = DEFAULT_BCSTORMTH;
    g_DefaultData.aucmcStormStatus = DEFAULT_MCSTORMSTATUS;
    g_DefaultData.aucmcStormThresold = DEFAULT_MCSTORMTH;

    g_DefaultData.aucTrustMode = DEFAULT_TRUSTMODE;
    g_DefaultData.aucportBasedQoS = DEFAULT_PORTPRIORITY;
    g_DefaultData.auclinkAlarmStatus = DEFAULT_LINKALARM;
    g_DefaultData.aucautonegStatus = DEFAULT_AUTONEG;
    g_DefaultData.aucspeed = DEFAULT_SPEED;// 0; // Updated from 0 to 1 bcz of changes in firmware
    g_DefaultData.aucduplexMode = DEFAULT_DUPLEX;// 0; // Updated from 0 to 1 bcz of changes in firmware

    g_DefaultData.aucautoCrossingstatus = DEFAULT_AUTOCROSS;
    g_DefaultData.aucMdistatus = DEFAULT_MDISTATUS;
    g_DefaultData.aucEEEStatus = DEFAULT_EEE;
    // Issue g_DefaultData.aucpoeStatus = DEFAULT_POESTATUS;
    if(g_CurrentProductInfo.m_ucproductLine & PRODUCT_LINE_POE)
        g_DefaultData.aucpoeStatus = 1;
    else
        g_DefaultData.aucpoeStatus = 0;

    g_DefaultData.aucpoePriority = DEFAULT_POEPRIORITY;
    g_DefaultData.aucpoeAllowedClasses[0] = DEFAULT_POEALLOWEDCLASS0;
    g_DefaultData.aucpoeAllowedClasses[1] = DEFAULT_POEALLOWEDCLASS1;
    g_DefaultData.aucpoeAllowedClasses[2] = DEFAULT_POEALLOWEDCLASS2;
    g_DefaultData.aucpoeAllowedClasses[3] = DEFAULT_POEALLOWEDCLASS3;
    g_DefaultData.aucpoeAllowedClasses[4] = DEFAULT_POEALLOWEDCLASS4;
    g_DefaultData.aucpoeAllowedClasses[5] = DEFAULT_POEALLOWEDCLASS5;
    g_DefaultData.aucpoeAllowedClasses[6] = DEFAULT_POEALLOWEDCLASS6;
    g_DefaultData.aucpoeAllowedClasses[7] = DEFAULT_POEALLOWEDCLASS7;
    g_DefaultData.aucpoeAllowedConsumptionOverride = DEFAULT_POEOVERRIDE;

    g_DefaultData.aucportVLANID = DEFAULT_VLANID;

    g_DefaultData.globalTrustMode = DEFAULT_TRUSTMODE;
}
/***********************************************************************
Function Name			:	updateBufferfromDefault
Function/DLD ID         :   SWR_MW_55
Purpose of Function		:   Update buffer from default value
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::updateBufferfromDefault()
{
    configureDefaultData();
    for(int i=0;i<100;i++)
    {
        SwitchConfiguration.auccontactname[i] = '\0';
        SwitchConfiguration.auclocation[i] = '\0';
    }
    for(int i=0;i<9;i++)
        SwitchConfiguration.auccomponentid[i] = '\0';

    for(int i=0;i<8;i++)
        SwitchConfiguration.aucreleaseNo[i] = g_DefaultData.aucreleaseNo[i];

    SwitchConfiguration.aucalarmPsu[0] = g_DefaultData.aucalarmPsu[0];
    SwitchConfiguration.aucalarmPsu[1] = g_DefaultData.aucalarmPsu[1];
    SwitchConfiguration.agingTime = g_DefaultData.agingTime;
    for(int i=0;i<8;i++)
        SwitchConfiguration.aucdotp1PcpToTc[i] = g_DefaultData.aucdotp1PcpToTc[i];
    for(int i=0;i<64;i++)
        SwitchConfiguration.aucdscpD1D2[i] = g_DefaultData.aucdscpD1D2[i];
    for(int i=0;i< g_CurrentProductInfo.m_ucnoOfPort;i++)
    {
        SwitchConfiguration.aucadminState[i] = g_DefaultData.aucadminState;
        SwitchConfiguration.auclinkAlarmStatus[i] = g_DefaultData.auclinkAlarmStatus;
        //SwitchConfiguration.aucspeed[i] = g_DefaultData.aucspeed;//default
        SwitchConfiguration.aucspeed[i] = g_DefaultData.aucspeed+1;
        //qDebug()<<"default switch config "<<SwitchConfiguration.aucspeed[i];
        SwitchConfiguration.aucautonegStatus[i] = g_DefaultData.aucautonegStatus;
        SwitchConfiguration.aucautoCrossingstatus[i] = g_DefaultData.aucautoCrossingstatus;
        SwitchConfiguration.aucduplexMode[i] = g_DefaultData.aucduplexMode;
        SwitchConfiguration.aucMdistatus[i] = g_DefaultData.aucMdistatus;
        SwitchConfiguration.aucflowControlStatus[i] = g_DefaultData.aucflowControlStatus;
        SwitchConfiguration.aucbcStormStatus[i] = g_DefaultData.aucbcStormStatus;
        SwitchConfiguration.aucbcStormThresold[i] = g_DefaultData.aucbcStormThresold;
        SwitchConfiguration.aucmcStormStatus[i] = g_DefaultData.aucmcStormStatus;
        SwitchConfiguration.aucmcStormThresold[i] = g_DefaultData.aucmcStormThresold;
        SwitchConfiguration.aucjumboFrameStatus[i] = g_DefaultData.aucjumboFrameStatus;
        SwitchConfiguration.aucTrustMode[i] = g_DefaultData.aucTrustMode;
        SwitchConfiguration.aucportBasedQoS[i]=g_DefaultData.aucportBasedQoS;
        SwitchConfiguration.aucEEEStatus[i] = g_DefaultData.aucEEEStatus;
        if(g_CurrentProductInfo.m_ucproductId==101 && i==0)     //OCTOPUS 8Tx POE Port1 is non PoE
            SwitchConfiguration.aucpoeStatus[i] = 0;
        else
            SwitchConfiguration.aucpoeStatus[i] = g_DefaultData.aucpoeStatus;
        SwitchConfiguration.aucpoePriority[i] = g_DefaultData.aucpoePriority;
        for(int j=0;j<8;j++)
            SwitchConfiguration.aucpoeAllowedClasses[i][j] = g_DefaultData.aucpoeAllowedClasses[j];
        SwitchConfiguration.aucpoeAllowedConsumptionOverride[i] = g_DefaultData.aucpoeAllowedConsumptionOverride;
        SwitchConfiguration.aucportVLANID[i] = g_DefaultData.aucportVLANID;
        SwitchConfiguration.globalTrustMode = g_DefaultData.globalTrustMode;
    }
}
/***********************************************************************
Function Name			:	updteUserInterface
Function/DLD ID         :   SWR_MW_56
Purpose of Function		:   Update user interface
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::updteUserInterface()
{
    updateGlobalParaUserInterface();
    // Update port parameter
    updatePortTableUserInterface();
}
/***********************************************************************
Function Name			:	updateGlobalParaUserInterface
Function/DLD ID         :   SWR_MW_57
Purpose of Function		:   Update user interface of global parameters and general information
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::updateGlobalParaUserInterface()
{
    ui->lineEdit_contactName->setText(QString::fromLocal8Bit((char*)(SwitchConfiguration.auccontactname)));
    for(int j=0;j<8;j++)
    {
        if( (SwitchConfiguration.aucreleaseNo[j]>=48) && (SwitchConfiguration.aucreleaseNo[j] <58))
        {
            if(j==2)
                temptext.append(".");
            if(j==3)
                temptext.append(".");
            temptext.append(QString::number(SwitchConfiguration.aucreleaseNo[j] - 48));
        }
    }
    ui->lineEdit_fileRelease->setText(temptext);

    ui->lineEdit_location->setText((QString::fromLocal8Bit((char*)(SwitchConfiguration.auclocation))));
    ui->lineEdit_serialFix->setText(fix_serial[ui->comboBox_productSelection->currentIndex()]);//"XXX YYY ZZZ");

    ui->comboBox_psuAlarm1->setCurrentIndex(SwitchConfiguration.aucalarmPsu[0]);
    ui->comboBox_psuAlarm2->setCurrentIndex(SwitchConfiguration.aucalarmPsu[1]);
    ui->lineEdit_agingTime->setText(QString::number(SwitchConfiguration.agingTime));

    // Mapping of 802.1p pending
    /** Will update when dialogbox will open **/

    //Mapping for DSCP pending
    /** Will update when dialogbox will open **/
}
/***********************************************************************
Function Name			:	updatePortTableUserInterface
Function/DLD ID         :   SWR_MW_58
Purpose of Function		:   Update user interface of port table
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::updatePortTableUserInterface()
{
    QModelIndex newIndex;
    //QModelIndex newIndexDash;
    //qDebug() << "Populating Table";
    for(int i = 0; i < g_CurrentProductInfo.m_ucnoOfPort ; i++)
    {
        newIndex = QStandardItemModelModels->index(i,0, QModelIndex());
        siUpdatePara = 1;

        if(SwitchConfiguration.aucadminState[i] == 1)
        {
            QStandardItemModelModels->setData(newIndex, "On", Qt::EditRole);
            //qDebug() << "MainWindow::updatePortTableUserInterface on";
        }
        else
        {
            QStandardItemModelModels->setData(newIndex, "Off", Qt::EditRole);
            //qDebug() << "MainWindow::updatePortTableUserInterface off";
        }
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,1, QModelIndex());
        siUpdatePara = 1;
        if(SwitchConfiguration.auclinkAlarmStatus[i])
            QStandardItemModelModels->setData(newIndex, "On", Qt::EditRole);
        else
            QStandardItemModelModels->setData(newIndex, "Off", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,3, QModelIndex());     // changed from 2 to 3 - issue 28935 - layout fix, table column order accourding preferences above - JG 12.08.2016
        siUpdatePara = 1;
        if(SwitchConfiguration.aucspeed[i] == 2)
            QStandardItemModelModels->setData(newIndex, "100Mbps", Qt::EditRole);

        else if(SwitchConfiguration.aucspeed[i] == 1)
            QStandardItemModelModels->setData(newIndex, "10Mbps", Qt::EditRole);

        else if(SwitchConfiguration.aucspeed[i] == 3)
            QStandardItemModelModels->setData(newIndex, "-", Qt::EditRole );

        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,2, QModelIndex());     // changed from 3 to 2 - issue 28935 - layout fix, table column order accourding preferences above - JG 12.08.2016
        //newIndexDash = QStandardItemModelModels->index(i,2,QModelIndex());
        siUpdatePara = 1;
        //qDebug() << "@Table Pop : " << SwitchConfiguration.aucautonegStatus[i];
        if(SwitchConfiguration.aucautonegStatus[i])
            QStandardItemModelModels->setData(newIndex, "On", Qt::EditRole);

        else
        {
            QStandardItemModelModels->setData(newIndex, "Off", Qt::EditRole);
            //QStandardItemModelModels->setData(newIndexDash, ,Qt::UserRole -1);
        }

        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,5, QModelIndex()); // changed from 4 to 5 - issue 28935 - layout fix, table column order accourding preferences above - JG 12.08.2016
        siUpdatePara = 1;
        if(SwitchConfiguration.aucautoCrossingstatus[i])
            QStandardItemModelModels->setData(newIndex, "On", Qt::EditRole);
        else
            QStandardItemModelModels->setData(newIndex, "Off", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,4, QModelIndex()); //changed from 5 to 4 - issue 28935 - layout fix, table column order accourding preferences above - JG 12.08.2016
        siUpdatePara = 1;
        if(SwitchConfiguration.aucduplexMode[i] == 2)
            QStandardItemModelModels->setData(newIndex, "FDX", Qt::EditRole);
        else if(SwitchConfiguration.aucduplexMode[i] == 1)
            QStandardItemModelModels->setData(newIndex, "HDX", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,6, QModelIndex());
        siUpdatePara = 1;
        if(SwitchConfiguration.aucMdistatus[i] == 1)
            QStandardItemModelModels->setData(newIndex, "MDI", Qt::EditRole);
        else
            QStandardItemModelModels->setData(newIndex, "MDIX", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,7, QModelIndex());
        siUpdatePara = 1;
        if(SwitchConfiguration.aucflowControlStatus[i])
            QStandardItemModelModels->setData(newIndex, "On", Qt::EditRole);
        else
            QStandardItemModelModels->setData(newIndex, "Off", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,8, QModelIndex());
        siUpdatePara = 1;
        if(SwitchConfiguration.aucbcStormStatus[i])
            QStandardItemModelModels->setData(newIndex, "On", Qt::EditRole);
        else
            QStandardItemModelModels->setData(newIndex, "Off", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,9, QModelIndex());
        siUpdatePara = 1;
        QStandardItemModelModels->setData(newIndex, SwitchConfiguration.aucbcStormThresold[i], Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,10, QModelIndex());
        siUpdatePara = 1;
        if(SwitchConfiguration.aucmcStormStatus[i])
            QStandardItemModelModels->setData(newIndex, "On", Qt::EditRole);
        else
            QStandardItemModelModels->setData(newIndex, "Off", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,11, QModelIndex());
        siUpdatePara = 1;
        QStandardItemModelModels->setData(newIndex, SwitchConfiguration.aucmcStormThresold[i], Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,12, QModelIndex());
        siUpdatePara = 1;
        if(SwitchConfiguration.aucjumboFrameStatus[i])
            QStandardItemModelModels->setData(newIndex, "On", Qt::EditRole);
        else
            QStandardItemModelModels->setData(newIndex, "Off", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,13, QModelIndex());
        siUpdatePara = 1;

        if(SwitchConfiguration.aucTrustMode[i] == 0)
            QStandardItemModelModels->setData(newIndex, "untrusted", Qt::EditRole);

        else if(SwitchConfiguration.aucTrustMode[i] == 1)
            QStandardItemModelModels->setData(newIndex, "trustDot1p", Qt::EditRole);

        else if(SwitchConfiguration.aucTrustMode[i] == 2)
            QStandardItemModelModels->setData(newIndex, "trustIpDscp", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,14, QModelIndex());
        siUpdatePara = 1;
        if(SwitchConfiguration.aucportBasedQoS[i] == 0)
            QStandardItemModelModels->setData(newIndex,"0" , Qt::EditRole);
        else if(SwitchConfiguration.aucportBasedQoS[i] == 1)
            QStandardItemModelModels->setData(newIndex, "1", Qt::EditRole);
        else if(SwitchConfiguration.aucportBasedQoS[i] == 2)
            QStandardItemModelModels->setData(newIndex, "2", Qt::EditRole);
        else if(SwitchConfiguration.aucportBasedQoS[i] == 3)
            QStandardItemModelModels->setData(newIndex, "3", Qt::EditRole);
        else if(SwitchConfiguration.aucportBasedQoS[i] == 4)
            QStandardItemModelModels->setData(newIndex, "4", Qt::EditRole);
        else if(SwitchConfiguration.aucportBasedQoS[i] == 5)
            QStandardItemModelModels->setData(newIndex, "5", Qt::EditRole);
        else if(SwitchConfiguration.aucportBasedQoS[i] == 6)
            QStandardItemModelModels->setData(newIndex, "6", Qt::EditRole);
        else if(SwitchConfiguration.aucportBasedQoS[i] == 7)
            QStandardItemModelModels->setData(newIndex, "7", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,15, QModelIndex());
        siUpdatePara = 1;
        if(SwitchConfiguration.aucEEEStatus[i])
            QStandardItemModelModels->setData(newIndex, "On", Qt::EditRole);
        else
            QStandardItemModelModels->setData(newIndex, "Off", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,16, QModelIndex());
        siUpdatePara = 1;
        if(SwitchConfiguration.aucpoeStatus[i])
            //QStandardItemModelModels->setData(newIndex, "-", Qt::EditRole);
            QStandardItemModelModels->setData(newIndex, "On", Qt::EditRole);

        else
            QStandardItemModelModels->setData(newIndex, "Off", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,17, QModelIndex());
        siUpdatePara = 1;
        if(SwitchConfiguration.aucpoePriority[i] == 1)
            //QStandardItemModelModels->setData(newIndex, "-", Qt::EditRole);
            QStandardItemModelModels->setData(newIndex, "Low", Qt::EditRole);
        else if (SwitchConfiguration.aucpoePriority[i] == 2)
            QStandardItemModelModels->setData(newIndex, "High", Qt::EditRole);
        else if (SwitchConfiguration.aucpoePriority[i] == 3)
            QStandardItemModelModels->setData(newIndex, "Critical", Qt::EditRole);
        siUpdatePara = 0;

        newIndex = QStandardItemModelModels->index(i,18, QModelIndex());
        siUpdatePara = 1;
            QString temp;

            if(SwitchConfiguration.aucpoeAllowedClasses[i][0] != 0xFF)
                temp.append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i][0]));
            if(SwitchConfiguration.aucpoeAllowedClasses[i][1] != 0xFF)
                temp.append(",").append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i][1]));
            if(SwitchConfiguration.aucpoeAllowedClasses[i][2] != 0xFF)
                temp.append(",").append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i][2]));
            if(SwitchConfiguration.aucpoeAllowedClasses[i][3] != 0xFF)
                temp.append(",").append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i][3]));
            if(SwitchConfiguration.aucpoeAllowedClasses[i][4] != 0xFF)
                temp.append(",").append(QString::number(SwitchConfiguration.aucpoeAllowedClasses[i][4]));
            if((g_CurrentProductInfo.m_ucproductLine & PRODUCT_LINE_POE) == 0)
            {
                QString temp = "-";
                QStandardItemModelModels->setData(newIndex, temp, Qt::EditRole);
                siUpdatePara = 0;
            }
            else
            {
                QStandardItemModelModels->setData(newIndex,temp,Qt::EditRole);
                siUpdatePara = 0;

            }

        newIndex = QStandardItemModelModels->index(i,19, QModelIndex());
        siUpdatePara = 1;
        if(((g_CurrentProductInfo.m_ucproductLine & PRODUCT_LINE_POE) == 0)|| (SwitchConfiguration.aucpoeAllowedConsumptionOverride[i] == 0))
            temp = "-";
        else
            temp = QString::number(SwitchConfiguration.aucpoeAllowedConsumptionOverride[i]);
        QStandardItemModelModels->setData(newIndex,temp , Qt::EditRole);
        siUpdatePara = 0;
    }
}
/***********************************************************************
Function Name			:	on_radioButton_selectAll_clicked
Function/DLD ID         :   SWR_MW_59
Purpose of Function		:   Slot for select all radio button click
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   bool
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_radioButton_selectAll_clicked(bool boolChecked)
{
    if(boolChecked)
    {
        //Select all port
        clearPortBorder();
        int ports = stProductData[ui->comboBox_productSelection->currentIndex()].m_ucNumberOfPorts - stProductData[ui->comboBox_productSelection->currentIndex()].m_ucNumberOfFiberPorts;
        configData tempbuffer = SwitchConfiguration;
        for(int label_number=0; label_number< ports;label_number++)
        {
            if(g_CurrentProductInfo.m_ucproductId == 101 && label_number == 0)    //Octopus 8Tx PoE: Port1 is non PoE, thus leave out Port 1
                label_number++;
            //update port parameters (not table but regular ui)
            populateSinglePort(label_number);
            clickQlabelQLabelPort[label_number]->setStyleSheet(STYLESHEET_PORTSELECT);
            setupGreyedOutParameters(checkTypeofPort(label_number));
        }
        SwitchConfiguration = tempbuffer;
        updatePortTableUserInterface();
        radioDeselectAll(false);
    }
    else
    {

    }
}
/***********************************************************************
Function Name			:	on_radioButton_deselectAll_clicked
Function/DLD ID         :   SWR_MW_60
Purpose of Function		:   Slot for deselect all radio button click
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   bool
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_radioButton_deselectAll_clicked(bool boolChecked)
{
    if(boolChecked)
    {
        radioSelectAll(false);
        clearPortBorder();
        setupGreyedOutParameters(NO_PORT_SELECTED);
    }
}
/***********************************************************************
Function Name			:	on_tableView_portSettings_clicked
Function/DLD ID         :   SWR_MW_61
Purpose of Function		:   Slot for table click
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   QModelIndex
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_tableView_portSettings_clicked(const QModelIndex &QModelIndexIndex)
{

    if(QModelIndexIndex.row() < MAX_NO_OF_PORTS/*(MAX_TP_PORTS)*/)
    {
        clearPortBorder();
        clickQlabelQLabelPort[QModelIndexIndex.row()]->setStyleSheet(STYLESHEET_PORTSELECT);
        populateSinglePort(QModelIndexIndex.row());
        setupGreyedOutParameters(checkTypeofPort(QModelIndexIndex.row()));
    }
}
/***********************************************************************
Function Name			:	displayErrorLog
Function/DLD ID         :   SWR_MW_62
Purpose of Function		:   Display error log
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::displayErrorLog()
{
    if(boolErrorLog)
    {
        boolCtrlFlag=0;
        ptrDialogErrorLog = new DialogErrorLog();
        ptrDialogErrorLog->setModal(true);
        ptrDialogErrorLog->exec();
        //qDebug() << "displayErrorLog";
        errorList.clear();

    }
}
/***********************************************************************
Function Name			:	on_lineEdit_fileRelease_textEdited
Function/DLD ID         :   SWR_MW_63
Purpose of Function		:   slot for file release number
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   QString
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_lineEdit_fileRelease_textEdited(const QString &QStringarg1)
{
    QString strfilerel = QStringarg1;
    QStringList strfilerel2 = strfilerel.split(".");
    if(strfilerel2.size()>0)
    {
        if(strfilerel2[0].length() <= 0)
        {
            SwitchConfiguration.aucreleaseNo[0]  = 0;
            SwitchConfiguration.aucreleaseNo[1]  = 0;
        }
        else if( strfilerel2[0].length() == 1)
        {
            SwitchConfiguration.aucreleaseNo[0]  = 0;
            SwitchConfiguration.aucreleaseNo[0]  = strfilerel2[0].at(0).toLatin1();
        }
        else
        {
            SwitchConfiguration.aucreleaseNo[0]  = strfilerel2[0].at(0).toLatin1();
            SwitchConfiguration.aucreleaseNo[1]  = strfilerel2[0].at(1).toLatin1();
        }
    }
    if(strfilerel2.size() >1 )
    {
        if(strfilerel2[1].length() == 1)
            SwitchConfiguration.aucreleaseNo[2]  = strfilerel2[1].at(0).toLatin1();
        else
            SwitchConfiguration.aucreleaseNo[2]  = 0;
    }
    if(strfilerel2.size()>2)
    {
        if(strfilerel2[2].length() == 0)
        {
            SwitchConfiguration.aucreleaseNo[3]  = 0;
            SwitchConfiguration.aucreleaseNo[4]  = 0;
        }
        else if( strfilerel2[2].length() == 1)
        {
            SwitchConfiguration.aucreleaseNo[3]  = strfilerel2[2].at(0).toLatin1();
            SwitchConfiguration.aucreleaseNo[4]  = 0;
        }
        else
        {
            SwitchConfiguration.aucreleaseNo[3]  = strfilerel2[2].at(0).toLatin1();
            SwitchConfiguration.aucreleaseNo[4]  = strfilerel2[2].at(1).toLatin1();
        }
    }
}
/***********************************************************************
Function Name			:	on_comboBox_psuAlarm1_currentIndexChanged
Function/DLD ID         :   SWR_MW_64
Purpose of Function		:   slot for psu alarm 1
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   int
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_psuAlarm1_currentIndexChanged(int siIndex)
{
    SwitchConfiguration.aucalarmPsu[0] = siIndex;
}
/***********************************************************************
Function Name			:	on_comboBox_psuAlarm2_currentIndexChanged
Function/DLD ID         :   SWR_MW_65
Purpose of Function		:   slot for psu alarm 2
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   int
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_comboBox_psuAlarm2_currentIndexChanged(int siIndex)
{
    SwitchConfiguration.aucalarmPsu[1] = siIndex;
}
/***********************************************************************
Function Name			:	on_lineEdit_agingTime_textChanged
Function/DLD ID         :   SWR_MW_66
Purpose of Function		:   slot for ageing time
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   QString
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_lineEdit_agingTime_textChanged(const QString &QStringArg1)
{
    //qDebug() << arg1;
    if(QStringArg1.isEmpty())
    {
        SwitchConfiguration.agingTime = 0;
        ui->lineEdit_agingTime->setText(QString::number(SwitchConfiguration.agingTime));
    }
    else
        SwitchConfiguration.agingTime = QStringArg1.toInt();

    ui->lineEdit_agingTime->setText(QString::number(SwitchConfiguration.agingTime));
}
/***********************************************************************
Function Name			:	on_lineEdit_contactName_textEdited
Function/DLD ID         :   SWR_MW_67
Purpose of Function		:   slot for contact name
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   QString
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_lineEdit_contactName_textEdited(const QString &QStringArg1)
{
    for(int i=0;i<100;i++)
        SwitchConfiguration.auccontactname[i] = '\0';
    for(int i=0;i<QStringArg1.length();i++)
        SwitchConfiguration.auccontactname[i] = QStringArg1.at(i).toLatin1();
}
/***********************************************************************
Function Name			:	on_lineEdit_location_textEdited
Function/DLD ID         :   SWR_MW_68
Purpose of Function		:   slot for location
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   QString
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_lineEdit_location_textEdited(const QString &QStringArg1)
{
    for(int i=0;i<100;i++)
        SwitchConfiguration.auclocation[i] = '\0';
    for(int i=0;i<QStringArg1.length();i++)
        SwitchConfiguration.auclocation[i] = QStringArg1.at(i).toLatin1();
}
/***********************************************************************
Function Name			:	radioSelectAll
Function/DLD ID         :   SWR_MW_69
Purpose of Function		:   select all radio button status update
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   bool
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::radioSelectAll(bool boolStatus)
{
    ui->radioButton_selectAll->setAutoExclusive(false);
    ui->radioButton_selectAll->setChecked(boolStatus);
    ui->radioButton_selectAll->setAutoExclusive(true);

}
/***********************************************************************
Function Name			:	radioDeselectAll
Function/DLD ID         :   SWR_MW_70
Purpose of Function		:   Deselect all radio button status update
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   bool
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::radioDeselectAll(bool boolStatus)
{
    ui->radioButton_deselectAll->setAutoExclusive(false);
    ui->radioButton_deselectAll->setChecked(boolStatus);
    ui->radioButton_deselectAll->setAutoExclusive(true);

}
/***********************************************************************
Function Name			:	on_lineEdit_componentId_textEdited
Function/DLD ID         :   SWR_MW_71
Purpose of Function		:   Slot for component id
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   QString
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_lineEdit_componentId_textEdited(const QString &QStringArg1)
{
    for(int i=0;i<9;i++)
        SwitchConfiguration.auccomponentid[i] = '\0';
    for(int i=0;i<QStringArg1.length();i++)
        SwitchConfiguration.auccomponentid[i] = QStringArg1.at(i).toLatin1();
}
/***********************************************************************
Function Name			:	on_lineEdit_serialNumber_textEdited
Function/DLD ID         :   SWR_MW_72
Purpose of Function		:   Slot for serial number
Author/Date     		: 	Manu Singh
Modified by/Date		:
Calls                   :
Inputs                  :   QString
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_lineEdit_serialNumber_textEdited(const QString &QStringArg1)
{
    serialNumber.clear();
    serialNumber.append(ui->lineEdit_serialFix->text()).append("-").append(QStringArg1);
}
/***********************************************************************
Function Name			:	on_pushButton_qosPMapping_clicked()
Function/DLD ID         :   SWR_MW_73
Purpose of Function		:
Author/Date     		: 	MANU SINGH - 27/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_pushButton_qosPMapping_clicked()
{
    ptrDialog8021p = new Dialog8021p;
    if(ptrDialog8021p)
    {
        ptrDialog8021p->setModal(true);
        ptrDialog8021p->exec();
    }

}
/***********************************************************************
Function Name			:	MainWindow::on_pushButton_qosDscpMapping_clicked()
Function/DLD ID         :   SWR_MW_74
Purpose of Function		:
Author/Date     		: 	MANU SINGH - 27/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_pushButton_qosDscpMapping_clicked()
{
    ptrDialogdscp = new DialogDSCP();
    ptrDialogdscp->setModal(true);
    ptrDialogdscp->exec();
}

/***********************************************************************
Function Name			:	MainWindow::on_toolButton_allowedPoEOverride_info_clicked()
Function/DLD ID         :
Purpose of Function		:
Author/Date     		: 	JGreiss - 22/02/2018
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::on_toolButton_allowedPoEOverride_info_clicked()
{
    siOpenParticularHelp = "Editingportparameters.html";
    onlineHelp();
    siOpenParticularHelp = "SwitchProgrammingTool.html";

}

/***********************************************************************
Function Name			:	MainWindow::portUpdate()
Function/DLD ID         :   SWR_MW_77
Purpose of Function		:
Author/Date     		: 	MANU SINGH - 27/02/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::portUpdate(int siLabel_number)
{
    if((siLabel_number>= 0)&&(siLabel_number < MAX_NO_OF_PORTS))
    {

        clearPortBorder();
        clickQlabelQLabelPort[siLabel_number]->setStyleSheet("background-color : transparent;border: 2px solid red");
        populateSinglePort(siLabel_number);
        setupGreyedOutParameters(checkTypeofPort(siLabel_number));

        radioSelectAll(false);
        radioDeselectAll(false);
    }
}

/***********************************************************************
Function Name			:	MainWindow::on_opencsvfile_csvpopup(unsigned char configId)
Function/DLD ID         :   SWR_MW_77
Purpose of Function		:
Author/Date     		: 	MANU SINGH - 15/12/2015
Modified by/Date		:	<yyy  dd\mm\yy>
Calls                   :
Inputs                  :
Return                  :
Remarks                 :
************************************************************************/
void MainWindow::onOpencsvfileCsvpopup(unsigned char configId)
{
    configIdfromcsv = configId;
    ptrDialogConfigID = new DialogConfigID;
    if(ptrDialogConfigID)
    {
        ptrDialogConfigID->setModal(true);
        ptrDialogConfigID->exec();
    }

}


